#
# spec file for package libyui-rest-api
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libyui-rest-api

# DO NOT manually bump the version here; instead, use rake version:bump
Version:        4.3.3
Release:        150400.1.4

%define         so_version 16
%define         bin_name %{name}%{so_version}

BuildRequires:  boost-devel
BuildRequires:  cmake >= 3.10
BuildRequires:  gcc-c++
BuildRequires:  jsoncpp-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  libyui-devel >= %{version}

Summary:        Libyui - REST API plugin, the shared part
License:        LGPL-2.1-only OR LGPL-3.0-only
URL:            http://github.com/libyui
Source:         libyui-%{version}.tar.bz2

%description
This package provides a libyui REST API plugin.

It allows inspecting and controlling the UI remotely via
an HTTP REST API, it is designed for automated tests.


%package -n %{bin_name}
Summary:        Libyui - REST API plugin, the shared part
Requires:       libyui%{so_version}
Requires:       yui_backend = %{so_version}
Provides:       %{name} = %{version}

%description -n %{bin_name}
This package provides a libyui REST API plugin.

It allows inspecting and controlling the UI remotely via
an HTTP REST API, it is designed for automated tests.


%package devel
Summary:        Libyui - REST API header files

Requires:       %{bin_name} = %{version}
Requires:       boost-devel
Requires:       glibc-devel
Requires:       jsoncpp-devel
Requires:       libmicrohttpd-devel
Requires:       libstdc++-devel
Requires:       libyui-devel >= %{version}

%description devel
This package provides a libyui REST API plugin.

This is a development subpackage.


%prep
%setup -q -n libyui-%{version}

%build
pushd %{name}
mkdir build
cd build

export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG $(getconf LFS_CFLAGS)"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG $(getconf LFS_CFLAGS)"

%if %{?_with_debug:1}%{!?_with_debug:0}
CMAKE_OPTS="-DCMAKE_BUILD_TYPE=RELWITHDEBINFO"
%else
CMAKE_OPTS="-DCMAKE_BUILD_TYPE=RELEASE"
%endif

cmake .. \
 $CMAKE_OPTS

make %{?jobs:-j%jobs}
popd

%install
pushd %{name}
cd build
make install DESTDIR="$RPM_BUILD_ROOT"
install -m0755 -d %{buildroot}/%{_libdir}/yui
install -m0755 -d %{buildroot}/%{_docdir}/%{bin_name}/
install -m0644 ../../COPYING* %{buildroot}/%{_docdir}/%{bin_name}/
popd

%post -n %{bin_name} -p /sbin/ldconfig
%postun -n %{bin_name} -p /sbin/ldconfig

%files -n %{bin_name}
%dir %{_libdir}/yui
%{_libdir}/yui/lib*.so.*
%doc %dir %{_docdir}/%{bin_name}
%license %{_docdir}/%{bin_name}/COPYING*

%files devel
%dir %{_docdir}/%{bin_name}
%{_libdir}/yui/lib*.so
%{_includedir}/yui

%changelog
* Tue Mar 15 2022 shundhammer@suse.com
- Fixed release notes dialog in YQWizard clearing content on click
  (bsc#1195158)
- Documented the different ways of displaying release notes in the UI
- 4.3.3
* Thu Mar  3 2022 lslezak@suse.cz
- Update also the stylesheet (theme) for the RichText content when
  changing the UI theme (bsc#1196296)
- 4.3.2
* Wed Feb  9 2022 shundhammer@suse.com
- Made widget style sheet (theme) switching discoverable in the Qt UI:
  Added an icon button to YQWizard
  (jsc#SLE-20564, bsc#1195730)
  More info + screenshots: https://github.com/libyui/libyui/pull/65
- Fixed Qt warning in y2log: QFrame '' already has a layout
- 4.3.1
* Tue Feb  1 2022 shundhammer@suse.com
- Added widget style sheet (theme) switching to Qt UI (jsc#SLE-20564)
  with the Shift-F3 key combination
  More info + screenshots: https://github.com/libyui/libyui/pull/64
- Added UI built-in UI.AskForWidgetStyle()
- Added UI capability HasWidgetStyleSupport (for UI.GetDisplayInfo())
- Bumped SO version to 16
- Fixed gcc 12 warnings (GitHub issue #63)
  (elevated to error by -Werror)
- 4.3.0
* Tue Dec 21 2021 shundhammer@suse.com
- Fix deprecated warning (elevated to error by -Werror)
  for libmicrohttpd's MHD_HTTP_UNPROCESSABLE_ENTITY in rest-api
  (bsc#1193956)
- 4.2.24
* Tue Dec 21 2021 shundhammer@suse.com
- Fixed YQPkg button redraw problem in dark SLE installation theme:
  Use centered button in dialogs with QSizeGrip (bsc#1193808)
- 4.2.23
* Thu Nov 11 2021 lslezak@suse.cz
- Send a proper notify event from the YMultiSelectionBox widget
  when checking a check box via the REST API (bsc#1192574)
- 4.2.22
* Thu Oct 21 2021 mvidner@suse.com
- ncurses: Fix sorting tables by strings (jsc#SLE-17782)
- 4.2.21
* Tue Oct 19 2021 lslezak@suse.cz
- Use the C++17 standard in the *-pkg plugins (libzypp uses that
  standard by default) (related to bsc#1191829)
- 4.2.20
* Mon Oct 18 2021 shundhammer@suse.com
- Fixed crash in NCurses online update when retracted packages
  are present (bsc#1191130)
- 4.2.19
* Fri Oct 15 2021 jeriveramoya@suse.com
- Add debug_label as filter and improve error handling (bsc#1174390)
- 4.2.18
* Wed Oct 13 2021 shundhammer@suse.com
- Fixed empty entries in YQPackageSelector Zypp history window
  (bsc#1191430)
- Added missing textdomain (bsc#1190805)
- 4.2.17
* Tue Aug 24 2021 lslezak@suse.cz
- Fixed using an uninitialized variable, in some situations
  the patch category could be missing in the Qt UI (bsc#1174390)
- 4.2.16
* Fri Aug  6 2021 lslezak@suse.cz
- Fixed displaying empty help text or empty release notes
  in ncurses UI (the real cause of bsc#972548)
- 4.2.15
* Fri Jun  4 2021 mvidner@suse.com
- rest-api: When finding table items by cell value,
  ignore BiDi control chars (bsc#1128091)
- 4.2.14
* Wed Jun  2 2021 shundhammer@suse.com
- Fixed build failure with latest GCC 11.1:
  Added operator delete as counterpart to our custom operator new
  in YWidget (bsc#1186741)
- 4.2.13
* Tue Jun  1 2021 shundhammer@suse.com
- Greatly improved visual appearance of tab widgets in the Qt UI
  (bsc #1186705, GitHub issue #20)
- 4.2.12
* Wed May 26 2021 mvidner@suse.com
- rest-api: fix crash when switching tabs (bsc#1185746)
- 4.2.11
* Mon May  3 2021 shundhammer@suse.com
- Added pkgconfig files for libyui-qt and libyui-ncurses
  for writing extensions of the Qt and NCurses plug-ins
  (GitHub issue #9 / bsc#1139747)
- 4.2.10
* Thu Apr 29 2021 oorlov@suse.com
- Ignore ampersand when search item in YMenuWidget and YDumbTab
  with rest-api (bsc#1139747)
- 4.2.9
* Thu Apr 29 2021 shundhammer@suse.com
- Fixed license headers to use the correct license (LGPL) everywhere
  (bsc#1185443)
- 4.2.8
* Mon Apr 26 2021 shundhammer@suse.com
- Auto-publish C++ API docs (libyui base lib doxygen autodocs)
  as GitHub pages when a PR to master is merged
  (part of bsc#1181653)
  Doc URL: https://libyui.github.io/libyui/api-doc/index.html
- 4.2.7
* Mon Apr 26 2021 shundhammer@suse.com
- Moved CI scripts into new subdir scripts/ to unclutter toplevel dir
  (part of bsc#1181653)
- Renamed ambiguously named script local.sh to local-prefix.sh
- 4.2.6
* Thu Apr 22 2021 shundhammer@suse.com
- Added reference to autodocs (C++ API doc) and more docs
  (part of bsc#1181653)
- 4.2.5
* Thu Apr 15 2021 shundhammer@suse.com
- Added support for $CMAKE_INSTALL_PREFIX for alternate installation dir
  either as -D on the cmake command line or in the environment
  (gh#14, part of bsc#1181653)
- 4.2.4
* Wed Apr 14 2021 shundhammer@suse.com
- Added toplevel build-all script (part of bsc#1181653)
- Revamped toplevel README.md
- Create local include dirs at cmake time to avoid root ownership
  after "make install"
- 4.2.3
* Tue Apr 13 2021 riafarov@suse.com
- Adjust documentation url in libyui-rest-api for the new project
  structure (bsc#1184363)
- 4.2.2
* Thu Apr  8 2021 shundhammer@suse.com
- Cleaned up cmake build environment (part of bsc#1181653):
  - Removed obsolete old .spec and .changes files in each subdir
    (now in toplevel package/ subdir)
  - Removed artificial "install-doc" make target now that the -doc
    subpackages are dropped
- 4.2.1
* Tue Apr  6 2021 shundhammer@suse.com
- Obsolete older -doc packages in all main packages that have them
  to prevent outdated -doc packages being installed (bsc#1184363)
- 4.2.0
* Wed Mar 17 2021 dgonzalez@suse.com
- Remove background opacity from libyui-qt-pkg icons (bsc#1183519)
- 4.1.2
* Fri Mar 12 2021 dgonzalez@suse.com
- Add the missing transparency to the folder-temp.svg icon
  (bsc#1183449).
- 4.1.1
* Tue Mar  9 2021 jlopez@suse.com
- New packaging system.
- From now on, libyui subpackages are built inside the libyui OBS
  package.
- The affected packages are: libyui-qt, libyui-qt-graph,
  libyui-qt-pkg, libyui-ncurses, libyui-ncurses-pkg,
  libyui-rest-api, libyui-qt-rest-api, libyui-ncurses-rest-api,
  libyui-bindings.
- 4.1.0
* Thu Feb 25 2021 shundhammer@suse.com
- Removed dependency on Xlib (bsc#1182663)
- 4.0.3
* Mon Feb 22 2021 shundhammer@suse.com
- Fixed segfault in disk usage list: Removed code for disabled
  columns completely (bsc#1182555)
- 4.0.2
* Mon Feb 15 2021 shundhammer@suse.com
- Adapted to new libyui cmake build environment (bsc#1181653)
- Renamed Makefile.cvs to Makefile.repo
- 4.0.0
* Mon Feb 15 2021 shundhammer@suse.com
- Require libyui-ncurses (bsc#1181653)
- 4.0.1
* Mon Feb 15 2021 shundhammer@suse.com
- Require libyui-ncurses (bsc#1181653)
- 4.0.1
* Mon Feb 15 2021 shundhammer@suse.com
- Require libyui-qt (bsc#1181653)
- 4.0.1
* Mon Feb 15 2021 shundhammer@suse.com
- Require libyui-qt (bsc#1181653)
- 4.0.1
* Mon Feb 15 2021 shundhammer@suse.com
- Require libyui-qt (bsc#1181653)
- 4.0.1
* Thu Feb 11 2021 lslezak@suse.cz
- Added `Ctrl+Alt+Shift+C` keyboard shortcuts for starting special
  configuration console (jsc#PM-1895, jsc#SLE-16263)
- 4.0.1
* Thu Feb 11 2021 lslezak@suse.cz
- Added keyboard shortcuts:
    Ctrl-D Shift-G - start the debugger
    Ctrl-D Shift-C - start the configuration console
    (jsc#PM-1895, jsc#SLE-16263)
- CMake fix: do not create the include/yui symlink if it already
  exists
- 4.0.2
* Wed Feb 10 2021 lslezak@suse.cz
- Added YSpecialKeyEvent to allow sending a special keyboard shortcut
  for configuring the application (jsc#PM-1895, jsc#SLE-16263)
- Added File->Close menu item in the dialog inspector
  (it was not possible to close the inspector when opened during
  installation)
- Require newer cmake (3.17+, version 3.10 is not enough)
- 4.0.1
* Thu Feb  4 2021 shundhammer@suse.com
- In tables with nested items, only open/close branches with [Space],
  don't also send an "Activated" event (bsc#1181789)
- 4.0.1
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 shundhammer@suse.com
- New CMake build environment (bsc#1181653)
- Bumped SO version to 15
- 4.0.0
* Mon Feb  1 2021 lslezak@suse.cz
- Block processing the idle loop after calling the closeUI()
  method (bsc#1181647)
  The terminal was actually still used by the UI after that
  call and there was a race condition if the started application
  after the call also used the terminal.
- 2.57.3
* Mon Jan  4 2021 lslezak@suse.cz
- Fixed build against the latest libmicrohttpd library
  (related to bsc#1173718)
- 0.5.12
* Tue Dec  1 2020 jlopez@suse.com
- Add folder-temp icon (related to jsc#SLE-16313).
- 2.56.4
* Fri Nov 27 2020 riafarov@suse.com
- Create structure to move handlers to separate classes (bsc#1132247)
- 0.2.3
* Thu Nov 26 2020 riafarov@suse.com
- Add activation for YTable (bsc#1139747)
- Create structure to move handlers to separate classes
- 0.2.4
* Thu Nov 26 2020 riafarov@suse.com
- Add activation for YTable (bsc#1139747)
- Create structure to move handlers to separate classes
- 0.5.11
* Wed Nov 25 2020 shundhammer@suse.com
- Fixed OBS-only changes by kkaempf vs. Git master conflicts
- Removed kkaempf's libyui-bindings-2.0.2.patch
  (now included in mvidner's latest commits for 2.1.0)
- 2.1.1
* Tue Nov 24 2020 riafarov@suse.com
- Add activation for Radiobutton (bsc#1139747)
- 0.2.3
* Tue Nov 24 2020 riafarov@suse.com
- Add activation for Radiobutton (bsc#1139747)
- 0.5.10
* Tue Nov 17 2020 fvogt@suse.com
- Fix text and icon overlapping in the pattern header (boo#1176530)
- Improve layout of pattern headers
- 2.48.5
* Tue Nov 17 2020 shundhammer@suse.com
- Added new widgets: YMenuBar, YItemSelector (bsc#1175115)
- 2.1.0
* Tue Nov 17 2020 riafarov@suse.com
- Add support for the child items in the table (bsc#1139747)
- 0.5.9
* Thu Nov 12 2020 shundhammer@suse.com
- Honor menu bar toplevel menu enabled/disabled and visibility state
  (boo#1178394 again)
- 2.56.3
* Wed Nov 11 2020 shundhammer@suse.com
- Higher priority for toplevel menu shortcuts (bsc#1175489)
- Dropped support for openSUSE 13.2 (or earlier) builds in .spec file
- 3.12.2
* Tue Nov  3 2020 shundhammer@suse.com
- Honor menu item enabled/disabled state when rebuilding menu item tree
  (e.g. after keyboard shortcut change) (boo#1178394)
- 2.56.2
* Wed Oct 28 2020 shundhammer@suse.com
- Explicitly set item and line index in NCMultiSelectionBox and
  NCSelectionBox (bsc#1177982, bsc#1177985)
- 2.57.2
* Wed Oct 21 2020 riafarov@suse.com
- Do not set json value to nullptr when YCheckBoxState is
  YCheckBox_dont_care (bsc#1139747)
- 0.5.8
* Thu Oct 15 2020 shundhammer@suse.com
- Fixed menu hotkeys (bsc#1177760)
- 2.57.1
* Thu Oct 15 2020 shundhammer@suse.com
- Added support for OpenItems property for (nested) tables (bsc#1176402)
- 2.56.1
* Thu Oct 15 2020 shundhammer@suse.com
- Added support for OpenItems property for (nested) tables (bsc#1176402)
- 3.12.1
* Fri Oct  9 2020 jlopez@suse.com
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 0.2.2
* Fri Oct  9 2020 jlopez@suse.com
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 0.2.2
* Fri Oct  9 2020 jlopez@suse.com
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 0.5.7
* Fri Oct  9 2020 jlopez@suse.com
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 2.46.6
* Fri Oct  9 2020 jlopez@suse.com
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 2.48.4
* Fri Oct  9 2020 jlopez@suse.com
- Adapt code to changes for nested tables.
- Use new parent lib SO version libyui.so.14 (bsc#1176402).
- 2.50.10
* Fri Oct  9 2020 jlopez@suse.com
- Resolve hotkeys conflicts for widgets with multiple hotkeys.
- Activate the menu hotkeys without using the ALT key.
- Close a menu by using BACKSPACE.
- Allow to use hotkeys to jump between menus.
- Related to bsc#1175489
- Allow to show/hide menus and menu items (related to
  manatools/libyui-mga#1).
- Allow nested items in tables (bsc#1176402).
- Bumped SO version to 14.
- 2.57.0
* Fri Oct  9 2020 jlopez@suse.com
- Resolve hotkeys conflicts for widgets with multiple hotkeys
  (related to bsc#1175489).
- Allow to show/hide menus and menu items (related to
  manatools/libyui-mga#1).
- Allow nested items in tables (bsc#1176402).
- Bumped SO version to 14.
- 2.56.0
* Thu Oct  8 2020 jlopez@suse.com
- Resolve hotkeys conflicts for widgets with multiple hotkeys
  (related to bsc#1175489).
- Allow to show/hide menus and menu items (related to
  manatools/libyui-mga#1).
- Allow nested items in tables (bsc#1176402).
- Bumped SO version to 14.
- 3.12.0
* Thu Oct  1 2020 riafarov@suse.com
- Remove log component from YHttpWidgetsActionHandler header file
  bsc#1177159
- 0.5.6
* Wed Sep 30 2020 kkaempf@suse.com
- fix Factory build, add libyui-bindings-2.0.2.patch
- move to python3-only build
* Thu Sep 17 2020 jeriveramoya@suse.com
- Add item selection in YMenuBar (bsc#1175115)
- 0.5.5
* Wed Sep 16 2020 jlopez@suse.com
- Hide heading of the dialog when no title is defined.
- Related to bsc#1175489.
- 2.55.0
* Wed Sep 16 2020 lslezak@suse.cz
- Fixed compilation in SLE15-SP2 (related to the previous fix
  bsc#1139747)
- 0.5.4
* Fri Aug 28 2020 jeriveramoya@suse.com
- Serialize value for YDateField and YTimeField (bsc#1139747)
- 0.5.3
* Thu Aug 27 2020 mvidner@suse.com
- Fix changing a single cell in a sorted table (bsc#1165388, bsc#1174615)
- 2.56.2
* Wed Aug 12 2020 jlopez@suse.com
- Handle hot-keys for top level menu options.
- Related to bsc#1175115.
- 2.56.1
* Tue Aug 11 2020 jlopez@suse.com
- Add MenuBar widget (bsc#1175115).
- Bump SO version to 13.
- 2.56.0
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 0.2.1
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 2.50.9
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 0.2.1
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 2.46.5
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 2.48.3
* Tue Aug 11 2020 shundhammer@suse.com
- Added MenuBar widget (bsc#1175115)
- Bumped SO version to 13
- 2.54.0
* Tue Aug 11 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.13 (bsc#1175115)
- 0.5.2
* Tue Aug 11 2020 shundhammer@suse.com
- Added MenuBar widget (bsc#1175115)
- Bumped SO version to 13
- 3.11.0
* Fri Jul 31 2020 mvidner@suse.com
- Fix build by porting NCURSES_CXX_IMPEXP from upstream
  (bsc#1174759).
- 2.55.1
* Tue Jul  7 2020 riafarov@suse.com
- Handle MHD result as int or enum depending on libmicrohttpd version
  (libmicrohttpd>=0.9.71 uses enum)
- 0.5.1
* Mon Jun  8 2020 riafarov@suse.com
- Trigger update on YCombobox, YSelectionBox, YInputField,
  YMultiSelectionBox (bsc#1139747)
- Add support for YDateField and YTimeField
- Allow setting text in editable YComboBox
- Allow selecting row in the table by row id
- Return json format consistently
- Add support for YCheckBoxFrame widget
- Allow reusing port if YUI_REUSE_PORT=1
- Add json serialization for YBarGraph
- 0.5.0
* Mon Jun  8 2020 riafarov@suse.com
- Trigger update on YCombobox, YSelectionBox, YInputField,
  YMultiSelectionBox (bsc#1139747)
- Add support for YDateField and YTimeField
- Add support for YCheckBoxFrame
- 0.2.0
* Mon Jun  8 2020 riafarov@suse.com
- Trigger update on YCombobox, YSelectionBox, YInputField,
  YMultiSelectionBox (bsc#1139747)
- Add support for YDateField and YTimeField
- Add support for YCheckBoxFrame
- 0.2.0
* Fri Jun  5 2020 riafarov@suse.com
- Make itemAt method public for YSelectionWidget (bsc#1132247)
- 3.10.1
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 0.1.2
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 0.1.2
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 2.50.8
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 2.46.4
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 2.48.2
* Thu Jun  4 2020 shundhammer@suse.com
- Use new parent lib SO version libyui.so.12 (bsc#1172513)
- 0.4.1
* Thu Jun  4 2020 shundhammer@suse.com
- Added autoWrap to label widget (bsc#1172513)
- Bumped SO version to 12
- 2.55.0
* Thu Jun  4 2020 shundhammer@suse.com
- Added autoWrap to label widget (bsc#1172513)
- Bumped SO version to 12
- 2.53.0
* Thu Jun  4 2020 shundhammer@suse.com
- Added autoWrap to label widget (bsc#1172513)
- Bumped SO version to 12
- 3.10.0
* Wed May 27 2020 jreidinger@suse.com
- Fix ruby bindings when build as non-gem (bsc#1172158)
- 2.0.2
* Tue May 26 2020 dmulder@suse.com
- Modify spec file to build python3 package
- 2.0.1
* Wed May 20 2020 shundhammer@suse.com
- Fixed compatibility with older (pre-5.15) Qt versions (bsc#1165118)
- 2.48.1
* Wed May 20 2020 shundhammer@suse.com
- Fixed build failures with older Qt versions (pre-5.15) (bsc#1165118)
- 2.52.4
* Tue May 19 2020 shundhammer@suse.com
- Allow vendor change also for distribution upgrade (bsc#1170521)
- 2.50.7
* Tue May 19 2020 aschnell@suse.com
- allow to move graph by dragging mouse (bsc#1171865)
- 2.46.3
* Mon May 18 2020 shundhammer@suse.com
- Allow vendor change also for distribution upgrade (bsc#1170521)
- 2.48.0
* Thu May 14 2020 aschnell@suse.com
- handle multi-line labels (bsc#1171700)
- 2.46.2
* Thu Mar 26 2020 shundhammer@suse.com
- Fixed Qt 5.15-Beta2 deprecated warnings (bsc#1165118)
- 2.47.5
* Tue Mar 24 2020 shundhammer@suse.com
- Fixed Qt 5.15 deprecated warnings (bsc#1165118)
- 2.46.1
* Tue Mar 24 2020 shundhammer@suse.com
- Fixed Qt 5.15 deprecated warnings (bsc#1165118)
- 2.47.4
* Tue Mar 24 2020 shundhammer@suse.com
- Fixed Qt 5.15 deprecated warnings (bsc#1165118)
- 2.52.3
* Mon Feb 17 2020 shundhammer@suse.com
- Added missing gettext init (bsc#1163586)
- 2.52.2
* Mon Feb 17 2020 shundhammer@suse.com
- Removed obsolete old RPM group tags (bsc#1163594)
- 3.9.3
* Mon Feb 17 2020 shundhammer@suse.com
- Removed leftovers of dropping support for RPM group tags (bsc#1163594)
- 2.50.6
* Mon Feb 17 2020 shundhammer@suse.com
- Removed leftovers of dropping support for RPM group tags (bsc#1163594)
- 2.47.3
* Thu Feb  6 2020 shundhammer@suse.com
- Ask user for confirmation for retracted packages (bsc#1162145)
- 2.50.5
* Wed Feb  5 2020 oorlov@suse.com
- Replace hard-coded HTML documentation with the url to the actual
  documentation in project repo
- Add "/version" endpoint to access to API version
- Use /v1/ prefix in URL path while accessing resources
- 0.4.0
* Fri Jan 24 2020 mfilka@suse.com
- bsc#1154694
  - do not crash UI when terminal window is too tight for table
- 2.54.5
* Thu Jan 23 2020 igonzalezsosa@suse.com
- Add an option to include a "Search Online" option in the
  package selector (jsc#SLE-9109).
- 2.50.4
* Wed Jan 22 2020 shundhammer@suse.com
- Handle retracted packages (jsc#SLE-11211)
- 2.50.3
* Fri Jan 17 2020 igonzalezsosa@suse.com
- Add an option to include a "Search Online" option in the
  package selector (jsc#SLE-9109).
- 3.9.2
* Thu Jan 16 2020 igonzalezsosa@suse.com
- Add an Online Search option to the Extras menu (jsc#SLE-9109).
- 2.47.2
* Tue Jan 14 2020 shundhammer@suse.com
- Handle retracted packages (jsc#SLE-11211)
- 2.47.1
* Fri Dec 20 2019 aschnell@suse.com
- handle new sort-key when sorting tables (bsc#1140018)
- 2.52.1
* Thu Dec 19 2019 aschnell@suse.com
- handle new sort-key when sorting tables (bsc#1140018)
- 2.54.4
* Wed Dec 18 2019 aschnell@suse.com
- added sort key to table cell (bsc#1140018)
- 3.9.1
* Mon Dec 16 2019 aschnell@suse.com
- update selected item in table when changing sorting only if
  multiselection mode is off (bsc#1159098)
- 2.54.3
* Mon Dec 16 2019 aschnell@suse.com
- sort new table content (unless keep-sorting flag is set) (part
  of bsc#1140018 and part of #1159177)
- update selected item in table when changing sorting (bsc#1159098)
- 2.54.2
* Fri Dec 13 2019 aschnell@suse.com
- adapted to changes in libyui-ncurses (needed for bsc#1159177)
- 2.50.2
* Fri Dec 13 2019 aschnell@suse.com
- save flag for reverse sorting in SortStrategyBase (needed for
  bsc#1159177)
- 2.54.1
* Wed Dec 11 2019 lslezak@suse.cz
- Added multiversion package list to the package classification
  filter (related to the bsc#1155132)
- 2.50.1
* Tue Dec 10 2019 riafarov@suse.com
- Increase SO version to 11 (bsc#1132247)
- 2.46.0
* Tue Dec 10 2019 riafarov@suse.com
- Increase SO version to 11 (bsc#1132247)
- 2.50.0
* Tue Dec 10 2019 riafarov@suse.com
- Increase SO version to 11 (bsc#1132247)
- 2.47.0
* Mon Dec  9 2019 lslezak@suse.cz
- Partially restore the "Package Groups" view, display only special
  package groups (orphaned, unneeded, multiversion,... packages)
  (bsc#1155132)
- 2.46.11
* Mon Dec  9 2019 riafarov@suse.com
- Add support to operate on many widgets with rest-api (bsc#1132247)
- Increase SO version to 11
- 2.52.0
* Wed Dec  4 2019 schubi@suse.de
- Added a banner on the upper/right side of the YaST layout.
  The label can be set by the environment variable YAST_BANNER
  (jsc#SLE-9424).
- 2.51.7
* Mon Dec  2 2019 mvidner@suse.com
- Do not require graphviz-devel for the doc package (bsc#1157916)
- 2.45.5
* Fri Nov 29 2019 riafarov@suse.com
- Add support to operate on many widgets with rest-api (bsc#1132247)
- Support column index when selecting a row
- Update documentation
- Increase SO version to 11
- 0.3.0
* Fri Nov 29 2019 riafarov@suse.com
- Add support to operate on many widgets with rest-api (bsc#1132247)
- Increase SO version to 11
- 2.54.0
* Fri Nov 29 2019 riafarov@suse.com
- Add support to operate on many widgets with rest-api (bsc#1132247)
- Increase SO version to 11
- 3.9.0
* Thu Nov 28 2019 aschnell@suse.com
- Respect backslashes (graphviz escString) in texts (bsc#1157916)
- 2.45.4
* Thu Nov 28 2019 shundhammer@suse.com
- Fixed Qt 5.14 deprecated warnings (bsc#1155550)
- 2.46.10
* Thu Nov 28 2019 shundhammer@suse.com
- Fixed Qt 5.14 deprecated warnings (bsc#1155550)
- 2.51.6
* Wed Nov 20 2019 shundhammer@suse.com
- Prevent crash on [PrintScreen] of a main window (bsc#1157170)
- 2.51.5
* Thu Nov 14 2019 shundhammer@suse.com
- Mirror layout direction in Farsi (bsc#1156437)
- 2.51.4
* Thu Nov 14 2019 shundhammer@suse.com
- Implemented CustomStatusItemSelector widget (bsc#1084674)
- 2.53.2
* Wed Nov 13 2019 shundhammer@suse.com
- Don't use tab in string literal
  (bsc#1084674)
- 3.8.5
* Mon Nov 11 2019 hellcp@mailbox.org
- Switch to native rpm boolean dependency syntax (boo#1156428)
* Thu Nov  7 2019 shundhammer@suse.com
- Support item status getting and setting for ItemSelector
  (bsc#1084674)
- 3.8.4
* Thu Nov  7 2019 shundhammer@suse.com
- Left-align ItemSelector toggle and icon if using custom status values,
  but items without description (bsc#1084674)
- 2.51.3
* Wed Nov  6 2019 jreidinger@suse.com
- do not complain about vendor change when switching repo
  (bsc#1149391,bsc#1065584)
- 2.46.9
* Thu Oct 31 2019 shundhammer@suse.com
- Support custom status values (int, not just boolean) in ItemSelector
  (bsc#1084674)
- 2.51.2
* Thu Oct 31 2019 shundhammer@suse.com
- Support custom status values (int, not just bool) in ItemSelector
  (bsc#1084674)
- 3.8.3
* Wed Oct 23 2019 shundhammer@suse.com
- Don't enforce an initial selection for SingleItemSelector
  (bsc#1084674)
- 3.8.2
* Thu Oct 17 2019 lslezak@suse.cz
- 2.46.8
* Mon Oct 14 2019 shundhammer@suse.com
- Fix build failure with older boost (bsc#1084674)
- 2.53.1
* Tue Oct  8 2019 tchvatal@suse.com
- Try to sort out a bit the package using spec-cleaner
- Use the distribution %%cmake macros that define all the various
  compilation flags/etc.
- Use %%cmake_build that will allow us later to switch from make
  to ninja on distribution level
* Tue Oct  8 2019 tchvatal@suse.com
- Remove Group view pane as it is based on the rpm group tag
  indirectly via packagekit (fate#326485).
* Thu Sep 26 2019 shundhammer@suse.com
- Implemented ItemSelector widget (bsc#1084674)
- 2.53.0
* Tue Sep 24 2019 shundhammer@suse.com
- Icon support for ItemSelector widget (bsc#1084674)
- 2.51.1
* Mon Sep 23 2019 shundhammer@suse.com
- Added CurrentItem property to new ItemSelector widget for consistency
  (bsc#1084674)
- 3.8.1
* Thu Sep 19 2019 shundhammer@suse.com
- Added ItemSelector widget (bsc#1084674)
- 3.8.0
* Wed Sep 18 2019 riafarov@suse.com
- Increase SO version to 11 (bsc#1132247)
- 0.1.1
* Wed Sep 18 2019 riafarov@suse.com
- Increase SO version to 11 (bsc#1132247)
- 0.1.1
* Wed Sep 18 2019 shundhammer@suse.com
- Implemented ItemSelector widget (bsc#1084674)
- 2.51.0
* Fri Sep 13 2019 aschnell@suse.com
- handle new libyui feature dealing with scrollbar position
  of RichText widget (bsc#1150498)
- 2.52.1
* Thu Sep 12 2019 mvidner@suse.com
- Make scroll-up mean zoom-in (bsc#1149158)
- 2.45.3
* Thu Sep 12 2019 aschnell@suse.com
- handle new libyui feature dealing with scrollbar position
  of RichText widget (bsc#1150498)
- 2.50.6
* Thu Sep 12 2019 aschnell@suse.com
- Allow to get and set scrollbar position of RichText widget
  (bsc#1150498)
- 3.7.0
* Fri Sep  6 2019 lslezak@suse.cz
- Added a new generic dependency to force upgrade from all previous
  versions (e.g. from libyui-qt-pkg9 to libyui-qt-pkg10)
  (bsc#1148622)
- 2.46.7
* Thu Sep  5 2019 lslezak@suse.cz
- Added a new generic dependency to force upgrade from all previous
  versions (e.g. from libyui-ncurses-pkg9 to libyui-ncurses-pkg10)
  (bsc#1148622)
- 2.49.1
* Mon Sep  2 2019 mvidner@suse.com
- pollEventInternal/UI.PollInput would produce no events (bsc#1139967)
- 2.50.5
* Fri Jun 28 2019 lslezak@suse.cz
- Split the libyui-rest-api plugin to separate Qt and Ncurses parts
  (bsc#1139747)
- IPv6 support
- HTTP Basic Auth support (set the user name and password via the
  YUI_AUTH_USER and YUI_AUTH_PASSWD environment variables)
- 0.2.0
* Fri Jun 28 2019 lslezak@suse.cz
- Send the notify events also when some widgets are changed via the
  REST API (CheckBox, RadioButton, InputField) (bsc#1139747)
- 2.52.0
* Tue Jun 25 2019 lslezak@suse.cz
- Initial version, split the libyui-rest-api plugin to separate
  Qt and Ncurses parts (bsc#1139747)
- 0.1.0
* Tue Jun 25 2019 lslezak@suse.cz
- Initial version, split the libyui-rest-api plugin to separate
  Qt and Ncurses parts (bsc#1139747)
- 0.1.0
* Tue Jun 25 2019 lslezak@suse.cz
- Split the libyui-rest-api plugin to separate Qt and Ncurses parts
  (bsc#1139747)
- 3.6.0
* Tue Jun 18 2019 schubi@suse.de
- Adding explanation for temporary menue options. (bsc#1137034)
- 2.46.6
* Tue May 28 2019 schubi@suse.de
- Clarify license to lgpl-2.1 and lgpl-3 (bsc#1136407).
- 2.46.5
* Thu May  9 2019 hellcp@mailbox.org
- Allow for full customization of the steps (boo#1134575)
- 2.50.4
* Tue May  7 2019 shundhammer@suse.com
- Fixed empty labels in graph elements (bsc#1130502):
  Proper replacement for obsolete QPainter::initFrom()
- 2.45.2
* Tue May  7 2019 shundhammer@suse.com
- Check for correct Qt version to fix build with Qt 5.13 (bsc#1130502)
- 2.46.4
* Tue May  7 2019 shundhammer@suse.com
- Check for correct Qt version to fix build with Qt 5.13 (bsc#1130502)
- 2.50.3
* Mon Apr 29 2019 shundhammer@suse.com
- Fixed segfault in pkg changes dialog (bsc#1132980)
- 2.46.3
* Tue Apr 23 2019 lslezak@suse.cz
- Spec file cleanup, use %%cmake macros
* Thu Apr 18 2019 lslezak@suse.cz
- Backward compatibility fix to ensure it still compiles in
  Leap 15.0 (related to bsc#1130502)
- 2.46.2
* Thu Apr 18 2019 lslezak@suse.cz
- Backward compatibility fix to ensure it still compiles in
  Leap 15.0 (related to bsc#1130502)
- 2.50.2
* Wed Apr 17 2019 shundhammer@suse.com
- Fixed obsolete warnings when building against Qt 5.13 (bsc#1130502)
- 2.45.1
* Wed Apr 17 2019 shundhammer@suse.com
- Fixed obsolete warnings when building against Qt 5.13 (bsc#1130502)
- 2.46.1
* Wed Apr 17 2019 lslezak@suse.cz
- Adapt to the latest libyui base library (REST API extension)
- Bump the .so version to 10 to be compatible with the other
  libyui packages (bsc#1132247)
- 2.51.0
* Wed Apr 17 2019 shundhammer@suse.com
- Fixed obsolete warnings when building against Qt 5.13 (bsc#1130502)
- 2.50.1
* Fri Apr 12 2019 riafarov@suse.com
- Bump the .so version to 10 to be compatible with the other libyui
  packages (bsc#1132247)
- 2.45.0
* Thu Apr 11 2019 lslezak@suse.cz
- Bump the .so version to 10 to be compatible with the other
  libyui packages (bsc#1132247)
- 2.46.0
* Thu Apr 11 2019 lslezak@suse.cz
- Bump the .so version to 10 to be compatible with the other
  libyui packages (bsc#1132247)
- 2.49.0
* Tue Mar 19 2019 riafarov@suse.com
- Add changes required for the libyui-testframework (bsc#1132247)
- 2.50.0
* Wed Mar 13 2019 hellcp@mailbox.org
- Add icons for partitioner (boo#1118521)
- 2.49.16
* Tue Mar 12 2019 shundhammer@suse.com
- Revert to previous initial status column width (bsc#1127708)
- 2.45.27
* Wed Feb 27 2019 shundhammer@suse.com
- Use YQUI icon loader in YQImage whenever possible
  (bsc#1119688, bsc#1122174)
- 2.49.15
* Thu Feb 14 2019 hellcp@mailbox.org
- Fix icon display to new libyui-qt function (boo#1125424)
- 2.45.26
* Thu Jan 10 2019 shundhammer@suse.com
- Fixed segfault in YQTableItem icon (bsc#1121083)
- 2.49.14
* Thu Dec 20 2018 riafarov@suse.com
- Initial commit (bsc#1132247)
- 0.1.0
* Thu Dec 20 2018 riafarov@suse.com
- Add changes required for the libyui-rest-api (bsc#1132247)
- 3.5.0
* Tue Dec 18 2018 shundhammer@suse.com
- YImage: Fall back to compiled-in Qt resources (bsc#1119688)
- 2.49.13
* Tue Dec 18 2018 aschnell@suse.com
- log QIcon::themeName (for bsc#1119688)
- 2.49.12
* Sat Dec 15 2018 hellcp@mailbox.org
- Make icons pop out from any background (boo#1115949)
- 2.45.25
* Wed Dec 12 2018 lslezak@suse.cz
- libyui-ncurses-tools conflicts with libyui-ncurses8
  (related to bsc#1113291)
- 2.50.4
* Wed Dec  5 2018 hellcp@mailbox.org
- Ship only primary icons with module to avoid conflicts (boo#1118521)
- 2.49.11
* Mon Nov 19 2018 hellcp@mailbox.org
- Fix YQTree's icon loading function (boo#1116562)
- Fix padding on the left caused by deprecated dialog icon
  (boo#1116278)
* Thu Nov 15 2018 hellcp@mailbox.org
- Destroy sidebar where necessary (boo#1115994)
* Tue Nov 13 2018 hellcp@mailbox.org
- Use native icon theme methods (boo#1109378)
- 2.49.8
* Wed Nov  7 2018 shundhammer@suse.com
- Require and link against libQt5Svg (bsc#1114654)
- 2.45.24
* Tue Nov  6 2018 shundhammer@suse.com
- Better error handling for missing icons (bsc#1114654):
  Error message in the y2log plus displaying a small red square for
  missing icons.
- 2.45.23
* Mon Oct 29 2018 hellcp@mailbox.org
- New way of handling emblems with theming support (boo#1109382)
- 2.45.22
* Thu Oct 25 2018 mvidner@suse.com
- Split off libyui-terminal into libyui-ncurses-tools (bsc#1113291)
- 2.50.3
* Tue Oct 23 2018 igonzalezsosa@suse.com
- Remove the RPM Groups view (FATE#326485).
- 2.48.9
* Tue Oct 23 2018 igonzalezsosa@suse.com
- Remove the RPM Groups view (FATE#326485).
- 2.45.21
* Sat Oct 13 2018 hellcp@opensuse.org
- Fix style disappearing from sidebar (boo#1111720)
- 2.49.7
* Wed Sep 19 2018 shundhammer@suse.com
- Enable HiDPI (bsc#1089886)
- 2.49.6
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Mon Aug 20 2018 schubi@suse.de
- Changed dir of COPYING file.
* Mon Jul 30 2018 lslezak@suse.cz
- Update the version to match the other packages (improvement
  for handling big disks, bsc#991090)
- 2.44.9
* Fri Jul 27 2018 lslezak@suse.cz
- Fix for the new FSize class (avoid the 8EiB limit, bsc#991090)
- Update the package version
- 2.48.8
* Thu Jul 26 2018 lslezak@suse.cz
- Update the version to match the other packages (improvement
  for handling big disks, bsc#991090)
- 2.50.2
* Thu Jul 26 2018 lslezak@suse.cz
- Fix for the new FSize class (avoid the 8EiB limit, bsc#991090)
- Update the package version
- 2.45.20
* Thu Jul 26 2018 lslezak@suse.cz
- Fix for the new FSize class (avoid the 8EiB limit, bsc#991090)
- Update the package version
- 2.49.5
* Thu Jul 26 2018 lslezak@suse.cz
- Improved the FSize class to handle arbitrary sizes, use the boost
  multiprecision library instead of `long long` which overflows for
  values > 8EiB (bsc#991090)
- 3.4.2
* Tue Jul  3 2018 lslezak@suse.cz
- Fixes for file systems >8EiB (bsc#991090):
  - Do not display "out of disk space" error at start when such
    a large disk is present in the system
  - Fixed displaying negative disk sizes in the disk usage dialog
- 2.45.19
* Tue Jul  3 2018 lslezak@suse.cz
- Fixes for file systems >8EiB (bsc#991090):
  - Do not display "out of disk space" error at start when such
    a large disk is present in the system
  - Fixed displaying negative disk sizes in the disk usage dialog
- 2.48.7
* Fri Jun 29 2018 mvidner@suse.com
- Added new "Services" filter, displayed only when at least one
  repository service is present (FATE#321043)
* Fri Jun 29 2018 lslezak@suse.cz
- Added new "Services" view, displayed only when at least one
  repository service is present (FATE#321043)
- Display the busy cursor while package filtering is in progress
* Mon Jun 25 2018 aschnell@suse.com
- use long long instead of int for free disk space with MiB base
- 2.45.18
* Mon Jun 25 2018 aschnell@suse.com
- use long long instead of int for free disk space with MiB base
- 2.48.6
* Tue Jun 19 2018 jreidinger@suse.com
- Drop code related to qt solver plugin which is dead for long time
  (bsc#1088759)
- 2.45.17
* Fri May 25 2018 igonzalezsosa@suse.com
- Drop qt5_use_modules (related to bsc#1091286).
- 2.44.8
* Fri May 11 2018 hellcp@opensuse.org
- Fix Gnome's display of titles/icons (boo#1092845)
- 2.49.4
* Wed May  9 2018 mliska@suse.cz
- Fix GCC 8 warning: -Werror=catch-value (boo#1084636).
- 3.4.1
* Mon May  7 2018 igonzalezsosa@suse.com
- Replace qt5_use_modules with target_link_libraries (bsc#1091286).
- 2.45.16
* Mon May  7 2018 igonzalezsosa@suse.com
- Replace qt5_use_modules with target_link_libraries (bsc#1091286).
- 2.44.7
* Mon May  7 2018 igonzalezsosa@suse.com
- Replace qt5_use_modules with target_link_libraries (bsc#1091286).
- 2.49.3
* Wed Apr 18 2018 igonzalezsosa@suse.com
- Use QLibraryInfo to determine the path to Qt translations
  (bsc#1082569).
- 2.49.2
* Tue Feb 27 2018 jreidinger@suse.com
- fix translations for advanced help text (bsc#1083015)
- 2.50.1
* Wed Feb 21 2018 letcp@protonmail.com
- Contribution by LelCP: Add support for icon themes (boo#1081517)
- 2.45.15
* Mon Jan  8 2018 shundhammer@suse.com
- Prevent segfault if an open dialog is left over (bsc#1074596):
  Don't do anything widget related after the QApplication is
  destroyed, in particular not deleting other widgets, even if
  indirectly via YDialog::deleteAllDialogs() in YUI.
  [#] 2.49.1
* Thu Jan  4 2018 shundhammer@suse.com
- Removed is_linetouched() function that clashes with a macro of
  the same name of newer NCurses libs (bsc#1074600)
- 2.50.0
* Mon Dec 18 2017 mvidner@suse.com
- Don't probe X11 display, for better integration
  with Wayland (bsc#1072411)
- 2.48.1
* Wed Nov 15 2017 shundhammer@suse.de
- Send a widget ID with Shift-F6 for automated testing (fate#324098)
- 2.48.0
* Wed Nov 15 2017 shundhammer@suse.de
- Send a widget ID with Shift-F6 for automated testing (fate#324098)
- 2.49.0
* Wed Nov 15 2017 shundhammer@suse.de
- Support for sending a widget ID with Shift-F6 for automated testing
  (fate#324098)
- 3.4.0
* Wed Aug 16 2017 lslezak@suse.cz
- Removed an obsolete non-working Qt initialization hack
  (bsc#1053873)
- 2.47.3
* Tue Aug  8 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- 2.44.6
* Tue Aug  8 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- Reduce build dependencies: Use individual libboost-*-devel
  packages instead of boost-devel (amajer)
- 2.45.14
* Mon Aug  7 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- Reduce build dependencies: Use individual libboost-*-devel
  packages instead of boost-devel (amajer)
- 2.48.5
* Mon Aug  7 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- 2.47.2
* Mon Aug  7 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- Reduce build dependencies: Use individual libboost-*-devel
  packages instead of boost-devel (amajer)
- 2.48.4
* Thu Aug  3 2017 besser82@fedoraproject.org
- CMake 3.9 warns about CMP0028 being obsolete
- 3.3.3
* Tue Jul  4 2017 mfilka@suse.com
- bnc#1047145
  - patch to make the package buildable by gcc7 (by werner@suse.com)
- 2.48.3
* Fri Jun 23 2017 lslezak@suse.cz
- Limit the number of displayed changes (the last 512 entries),
  rendering a huge change log might cause a freeze for long time
  (bsc#1044777)
- 2.45.13
* Tue May  9 2017 snwint@suse.de
- adjustments needed to work with latest ncurses update (bsc#1034922)
- 2.48.2
* Fri Apr 14 2017 besser82@fedoraproject.org
- Add option to enable MGA-Extensions
- Patches from MGA (anaselli) to support external plugins
- 2.0.0
* Fri Apr 14 2017 besser82@fedoraproject.org
- Python3: YItem and YWidget pointers comparison does not work any more
  (gh#libyui/libyui-bindings#26, A. Naselli)
- Python: Python binding missing constant values
  (gh#libyui/libyui-bindings#25, A. Naselli)
- Python: Added an example to show how to fill a YTable using YItemCollection
  (gh#libyui/libyui-bindings#24, A. Naselli)
- CMake: Fix handling of PerlLibs (boo#1113271)
- 1.1.2
* Fri Apr 14 2017 besser82@fedoraproject.org
- Add $(ENV:YUI_PREFERED_BACKEND) to set prefered UI-backend
- Avoid several warnings from CMake
- 3.3.2
* Thu Apr 13 2017 besser82@fedoraproject.org
- Fix detection of Desktop Environments
- 3.3.1
* Thu Apr 13 2017 besser82@fedoraproject.org
- Add YSettings::loadedUI option (gh#libyui/libyui#35)
- Prefer Gtk-UI on Gtk-based desktop enviroments
- Bump SO-name and minor version for API-change
- 3.3.0
* Sun Feb  5 2017 besser82@fedoraproject.org
- Fix crash when shutting down the UI (gh#libyui-libyui-qt#41, bsc#931762)
- Fix a problem with hanging UI
- 2.47.1
* Tue Dec  6 2016 cwh@suse.com
- Sort pkg list case-insensitively (bsc#1012294)
- Prevent double sorting (widget sorts by itself)
- 2.48.4
* Wed Nov 30 2016 gilson.s.s@gmail.com
- Treat RichText non-pair tag cases (gh#libyui-ncurses/issues#33).
- 2.48.1
* Tue Nov 29 2016 shundhammer@suse.de
- Sort pkg list case-insensitively (bsc#1012294)
- 2.45.12
* Tue Nov 29 2016 shundhammer@suse.de
- Made menu hotkey unique for QA (bsc#1012604)
- 2.48.3
* Fri Nov 25 2016 jreidinger@suse.com
- implement shortcut conflicts resolver for menu buttons
  (bsc#940817)
- 3.2.9
* Wed Nov 16 2016 cwh@suse.com
- Add hotkey for help about advanced hotkeys (bsc#1010039)
- 2.48.0
* Wed Nov  9 2016 cwh@suse.com
- Add handler for Shift-F1 to show advanced keyboard shortcuts (bsc#1010039)
- 2.47.0
* Tue Nov  1 2016 jreidinger@suse.com
- avoid duplicate entries in package groups view (bnc#852073)
- 2.45.11
* Mon Oct 24 2016 jreidinger@suse.com
- install qt-pkg if graphical control center and yast2-packager is
  used to prevent crash (bsc#999031)
- 2.45.10
* Mon Oct 17 2016 igonzalezsosa@suse.com
- Add support for @import directive in QSS
  (related to bsc#768112 and bsc#780621)
- 2.46.30
* Fri Oct 14 2016 igonzalezsosa@suse.com
- Rename Y2COLORMODE to Y2ALTSTYLE for consistency
  (related to bsc#768112 and bsc#780621)
- 2.46.29
* Fri Oct 14 2016 jreidinger@suse.com
- Fixed a Wmismatched-tags warning on clang/OSX (gh#libyui/libyui#33)
- 3.2.8
* Fri Oct 14 2016 anaselli@linux.it
- Fix pre-selecting a tree item when adding it, in ncurses
  (gh#libyui/libyui#86, boo#1005889). The very first item would
  be selected, ignoring YTreeItem::setSelected.
- Added ui test before loading extended widget plugin, to avoid
  a crash
* Fri Oct 14 2016 anaselli@linux.it
- Fix pre-selecting a tree item when adding it, in ncurses
  (gh#libyui-ncurses/issues#26, boo#1005889). The very first item
  would be selected, ignoring YTreeItem::setSelected.
- 2.47.7
* Thu Oct 13 2016 igonzalezsosa@suse.com
- Adapt to the latest API change regarding QY2Styler,
  renaming usingHighContrastStyleSheet to usingAlternateStyleSheet
  (related to bsc#780621)
- 2.45.9
* Thu Oct 13 2016 igonzalezsosa@suse.com
- Rename Y2HIGHCONTRAST environment variable to Y2COLORMODE
- Use 'alternate' instead of 'high-contrast'
- Load default style sheet if alternate style sheet does not exist
- All these changes are related to bsc#768112 and bsc#780621
- 2.46.28
* Tue Oct 11 2016 igonzalezsosa@suse.com
- Use the new QY2Styler usingHighContrastStyleSheet instead of
  the old usingVisionImpairedPalette (related to bsc#780621)
- 2.45.8
* Mon Oct 10 2016 igonzalezsosa@suse.com
- Fix high-contrast support (bsc#76811 and related to bsc#780621)
- 2.46.27
* Mon Oct 10 2016 jreidinger@suse.com
- Improve message shown when user want to quit without saving
  changes (bsc#849084)
- 2.45.7
* Sun Sep 25 2016 hrvoje.senjan@gmail.com
- Fix compilation with Qt 5.7 by using non-deprecated classes
  (boo#1001141).
* Wed Sep 21 2016 shundhammer@suse.de
- Force showing widgets that were added after opening a dialog
  (bsc#998593)
- Deliver timeout events only if the delivering dialog is still
  the topmost (can only happen with Ctrl-Shift-Alt key combos)
- 2.46.25
* Wed Sep 14 2016 lslezak@suse.cz
- Added editing abilities to the spy dialog (Ctrl+Shift+Alt+Y
  in the Qt UI) (bsc#998593)
- 3.2.7
* Mon Aug 22 2016 jreidinger@suse.com
- prevent double rendering of content causing segfault in qt and
  slow down elsewhere (bnc#989155)
- 3.2.6
* Mon Aug 22 2016 jreidinger@suse.com
- Do not append new line when content of log view do not change
  (bnc#989155)
- 2.46.24
* Fri May 13 2016 alarrosa@suse.com
- Now Yast requests the focus to the window manager when running
  fullscreen instead of relying on the window manager focus policy
  (bsc#974627)
- 2.46.23
* Tue Apr  5 2016 shundhammer@suse.de
- Show help in wizard widget upon F1 and Alt-H (bnc#973389)
- 2.46.22
* Wed Mar 30 2016 me@besser82.io
- Fix 'Werror=nonnull-compare' for GCC 6 (bsc#964144)
  - Optimizations remove null pointer checks for 'this'
- Clean-up trailing white-space
- 3.2.5
* Fri Jan 29 2016 mvidner@suse.com
- Fixed a compilation error in YTableCell with GCC 6 (bsc#964144).
- 3.2.4
* Thu Jan 28 2016 gs@suse.de
- replace deprecated auto_ptr by unique_ptr (bsc#962744)
- 2.47.6
* Tue Jan 19 2016 mvidner@suse.com
- CSharp: fix a System.EntryPointNotFoundException
  (gh#libyui/libyui-bindings#18, M. Pasotti)
- Perl, Python, Ruby: Fixed item identity comparison
  (gh#libyui/libyui-bindings#15, A. Naselli)
- 1.1.1
* Wed Nov 25 2015 gs@suse.de
- Respect /etc/zypp/zypp.conf settings for options "Allow vendor
  change" and "Cleanup when deleting packages" (bsc#954117)
- 2.45.6
* Tue Nov 17 2015 gs@suse.de
- Allow Ctrl-a and Ctrl-e key navigation for ComboBox, InputField
  and MultiLineEdit widgets (bsc#938814)
- 2.47.5
* Wed Oct  7 2015 jreidinger@suse.com
- Fix unselecting patterns for installation (unify behavior with
  qt packager) (bnc#916568)
- 2.48.2
* Fri Oct  2 2015 lslezak@suse.cz
- fixed styling for the release notes dialog content (bsc#947167)
- 2.46.21
* Tue Sep 22 2015 ancor@suse.com
- Better handling of secondary repository filters when there is
  no enough screen space (bnc#876540)
- 2.45.5
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
- 2.47.4
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep 16 2015 mvidner@suse.com
- Handle QtInfoMsg value in switch; fixes build with Qt 5.5
  (H Senjan, boo#942101).
- so-version bumped to match the main library.
- 2.46.19
* Wed Sep 16 2015 ancor@suse.com
- fixed redirection of stderr and stdout to /dev/null (bnc#943757)
- 2.47.3
* Tue Sep  8 2015 shundhammer@suse.de
- Allow to delete single versions of multiversion packages
  (bsc#943870)
- 2.45.3
* Wed Sep  2 2015 aschnell@suse.com
- bumped so version to match the base library (boo#937026).
- 2.44.4
* Tue Sep  1 2015 schubi@suse.com
- Handle mixed multiversion packages (fate#318778)
- Allow to delete single versions of multiversion packages.
  (bsc#943870)
- 2.48.0
* Fri Aug 28 2015 mvidner@suse.com
- Bump also the required yui_backend
- 3.2.2
* Wed Aug 26 2015 shundhammer@suse.de
- Fixed crash in conflict resolver dialog:
  No longer call libzypp function that always returns null pointer
  (bsc#941398)
- 2.45.2
* Wed Aug 12 2015 shundhammer@suse.de
- Handle mixed multiversion packages (fate#318778)
- Fixed libzypp deprecated warning
- 2.45.1
* Tue Aug  4 2015 gs@suse.de
- don't calculate height of an invisible widget (menu button) to
  prevent segfault (bnc#931154)
- 2.47.2
* Wed Jul 29 2015 besser82@fedoraproject.org
- API-changes imply so-name bump
- 3.2.1
* Tue Jul 21 2015 mvidner@suse.com
- Added a libyui-terminal helper script (boo#937026).
- 2.47.1
* Wed Jul  8 2015 mvidner@suse.com
- Added NCApplication::openUI/closeUI (boo#937026).
- 2.47.0
* Wed Jul  8 2015 mvidner@suse.com
- Added YApplication::openUI/closeUI (boo#937026)
- 3.2.0
* Wed Jul  8 2015 mvidner@suse.com
- Added option "Dependencies/Install Recommended Packages",
  (PKGMGR_RECOMMENDED) (boo#900853).
- Changed "Dependencies/Install Recommeded Packages for Already
  Installed Packages" from an option to a command (boo#902394).
- 2.47.0
* Mon Jun 22 2015 mvidner@suse.com
- Unified option handling with NCurses (FATE#318099)
  - "System verification mode" and "Dependencies/Autocheck"
    moved to /etc/sysconfig/yast2 (PKGMGR_VERIFY_SYSTEM,
    PKGMGR_AUTO_CHECK).
  - made "Cleanup when deleting packages" and "Allow vendor
    change" not persistent.
- Added option Dependencies/Install Recommended Packages,
  (PKGMGR_RECOMMENDED) (boo#900853).
- Changed "Options/Ignore Recommended Packages for Already
  Installed Packages" from an option to a command
  "Extras/Install All Matching Recommended Packages" (boo#902394).
- 2.45.0
* Wed May  6 2015 lslezak@suse.cz
- fixed styling for non-Wizard dialogues (bnc#925882)
- allow styling of the YQMainWinDock object (the main non-Wizard
  window)
- the stylesheet editor (Ctrl+Shift+Alt+s) also works for
  non-Wizard dialogues now
- 2.46.18
* Tue Feb 17 2015 anaselli@linux.it
- NCTimeField input validity check
- NCDateField input validity check
- Implementation of optional widget YTimeField
- Implementation of optional widget YDateField
- new class NCInputText to share code between NCTimeField, NCDateField
  and NCInputField
- 2.46.10
* Tue Feb 10 2015 jsrain@suse.cz
- fix layout of Help and Release Notes buttons (bsc#916814)
  (credits to tgoettlicher)
- 2.46.17
* Tue Feb  3 2015 gs@suse.de
- don't use internal ncurses (_nc_) functions (bnc #915945)
- 2.46.9
* Tue Feb  3 2015 jsrain@suse.cz
- include Help and Release notes buttons in keyboard shortcut
  resolution (bsc#880983)
- 2.46.16
* Fri Jan 30 2015 jsrain@suse.cz
- added keyboard shortcuts to Help and Release Notes buttons
  (bnc#880983)
- 2.46.15
* Wed Jan 21 2015 jsrain@suse.cz
- added QT-specific dialog for displaying release notes
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.44.3
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.46.14
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.46.2
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.46.8
* Tue Jan 20 2015 mvidner@suse.com
- Fix cmake also in the spec file, duh.
* Tue Jan 20 2015 mvidner@suse.com
- Fix cmake also in the spec file, duh.
* Sun Jan 18 2015 besser82@fedoraproject.org
- Replace deprecated Config: with RbConfig: for Ruby 2.2
- Add bindings for Mono / CSharp thanks to Matteo Pasotti
  <matteo@mageia.org>
- Add CMake-switches to enable / disable languages thanks to
  Matteo Pasotti <matteo@mageia.org>
- Shapen-up Mono-bindings to work as expected
- 1.1.0
* Thu Jan 15 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 2.44.8
* Thu Jan 15 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 1.0.6
* Mon Jan 12 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 3.1.5
* Fri Nov  7 2014 anaselli@linux.it
- RichText hyperlinks: return as strings, like Qt and GTK do.
  (gh#libyui/libyui-ncurses#30)
- 2.46.7
* Wed Sep 10 2014 mvidner@suse.com
- Enabled building (but not running) from a non /usr prefix,
  for ci.opensuse.org.
- 1.0.5
* Wed Aug 27 2014 locilka@suse.com
- The default product name should be "SUSE Linux" (bnc#886608)
- 3.1.4
* Tue Aug 26 2014 mvidner@suse.com
- Really added the libqdiagsolver conflict (bnc#870683, bnc#866622).
- 2.44.7
* Mon Aug 25 2014 lslezak@suse.cz
- Detect lib64 in a Debian compatible way, for Travis CI.
* Wed Aug 13 2014 mvidner@suse.com
- Fixed Table(:multiSelection) selecting 1st item when focused
  (bnc#888090).
- 2.46.13
* Mon Jul 28 2014 mvidner@suse.com
- Recommend this package when yast2-packager and libyui-qt are
  installed (bnc#888300)
- 2.44.6
* Mon Jul 28 2014 mvidner@suse.com
- Recommend this package when yast2-packager and libyui-ncurses are
  installed (bnc#888300)
- 2.46.1
* Thu Jul 10 2014 gs@suse.de
- Improve table sorting: interpret numbers correctly (related to
  previous fix for bnc #885653),
  Multiselection table: don't set focus to last line (partial
  bug-fix for bnc #885278)
- 2.46.6
* Wed Jul  9 2014 gs@suse.de
- Table sorting: always sort as strings, don't try interpreting
  as numbers (bnc #885653)
- 2.46.5
* Tue Jul  8 2014 mvidner@suse.com
- Avoid QXcbEventReader crash during library shutdown (bnc#879295).
- 2.46.12
* Fri Jul  4 2014 jreidinger@suse.com
- Do not allow to run it together with libqdiagsolver in qt3
  version (bnc#870683, bnc#866622)
- 2.44.5
* Thu May 29 2014 mvidner@suse.com
- Fix recent ugly fonts in cs_CZ, hu_HU (bnc#879991).
- 2.46.11
* Sat May 24 2014 bjoern.esser@gmail.com
- pull in GPLv3-license, since LGPLv3 is additional rules on top
- 3.1.3
* Sat May 24 2014 bjoern.esser@gmail.com
- clarify license by adding license headers from libyui
- pull in GPLv3-license, since LGPLv3 is additional rules on top
- 2.44.2
* Wed May 21 2014 snwint@suse.de
- fix last font selection fix (bnc #878859)
- 2.46.10
* Tue May 20 2014 mvidner@suse.com
- Fix showing package changelog, version, filelist (bnc#868101).
- 2.44.4
* Mon May 19 2014 snwint@suse.de
- load per-language font info and refresh widget fonts (bnc #866705)
- 2.46.9
* Wed May  7 2014 jsrain@suse.cz
- avoid hiding "Show Relnotes" button when new Wizard window is
  created (bnc#876668)
- 2.46.8
* Thu Apr 17 2014 jsrain@suse.cz
- added title bar with product logo (bnc#868722)
- 2.46.7
* Thu Apr 17 2014 jsrain@suse.cz
- Added handling of logo bar in wizard (bnc#868722)
- 3.1.2
* Wed Apr 16 2014 mvidner@suse.com
- Fix YQUI destruction (bnc#867296).
- 3.1.1
* Mon Apr 14 2014 tgoettlicher@suse.de
- Improve styleability of dialog heading
- 2.46.6
* Wed Apr  9 2014 mvidner@suse.com
- Added YUIOpt_titleOnLeft, YWizardMode_TitleOnLeft (bnc#868859)
- 3.1.0
* Tue Apr  8 2014 mvidner@suse.com
- Enable wizard title on the left instead of on top (bnc#868859).
- 2.46.5
* Tue Apr  8 2014 gs@suse.de
- Display menu (function keys) correctly in non UTF-8 environment
  (bnc #865597)
- 2.46.4
* Mon Mar 31 2014 tgoettlicher@suse.de
- Made BarGraph segment colors stylable (bnc#868268)
- 2.46.4
* Fri Mar 21 2014 mvidner@suse.com
- Fixed "QObject::connect: signal not found in YQCheckBox",
  aka CheckBox not sending notifications (bnc#868374)
- 2.46.3
* Sat Mar 15 2014 anaselli@linux.it
- Fixed YQDateField and YQTimeField notification event
- Fixed YTree item selection during items population,
  old implementation ignored selected items.
- Fixed YQTable item selected slot, if no items were selected
  at creation, first slection was ignored
- 2.46.2
* Wed Mar 12 2014 mvidner@suse.com
- Fixed hard-coded colors and improved code to accept stylesheets.
- Fixed empty icons in the help dialog.
- Removed the tab close button near the upper-right corner:
  confusing.
- (all by tgoettlicher)
- 2.44.3
* Wed Mar 12 2014 mvidner@suse.com
- Fixed "QFSFileEngine::open: No file name specified" (A Naselli)
- make Qt5 BuildRequires fine-grained with pkgconfig (H Senjan)
- 2.46.1
* Mon Mar 10 2014 mvidner@suse.com
- set parent of context menu, to apply style sheets (tgoettlicher)
- 2.46.0
* Mon Mar 10 2014 mvidner@suse.com
- make color of help text search result stylable (tgoettlicher)
- 2.45.4
* Tue Mar  4 2014 mvidner@suse.com
- fix actions in the package context menu (bnc#866038)
- 2.44.2
* Mon Mar  3 2014 mvidner@suse.com
- fixed tab switching in Qt5, for example during package installation
- declared pclass(ptr) macro to help with compile time type checking
  of Qt signals
- 2.45.3
* Fri Feb 28 2014 gs@suse.de
- fixed segfault in tree widget (bnc #866145)
- 2.46.3
* Thu Feb 27 2014 mvidner@suse.com
- Fixed save_y2logs invocation (bnc#866056).
- 2.45.2
* Tue Feb 25 2014 mvidner@suse.com
- merged git and Factory state: the patch is now upstreamed:
  0001-use-cgraph-instead-of-graph-interfaces.patch
- Ported to Qt5
- 2.44.1
* Tue Feb 25 2014 mvidner@suse.com
- Ported to Qt5
- 2.44.1
* Fri Feb 21 2014 mvidner@suse.com
- fontconfig-devel has been a build dependency; something has
  stopped pulling it in for us
- 2.45.1
* Fri Feb 21 2014 mvidner@suse.com
- now building on https://ci.opensuse.org/view/libyui/ !
  - adapted CMake macros for PREFIX != /usr
  - use Rakefile for making srcpackage for OBS
* Thu Feb 13 2014 mvidner@suse.com
- Removed hard-coded background color for pattern headline.
- 2.43.1
* Fri Feb  7 2014 jsrain@suse.cz
- use text version of release notes with NCurses (bnc#862578)
- 3.0.13
* Wed Jan 29 2014 gs@suse.de
- code cleanup concerning text domain
- 2.46.2
* Fri Jan 24 2014 anaselli@linux.it
- Added convertors and incrementers needed at least for Perl
  and python:
  YEvent: toYWidgetEvent toYKeyEvent toYMenuEvent toYCancelEvent
    toYDebugEvent toYTimeoutEvent
  YItem: toYTreeItem toYTableItem
  YItemIterator: toYItem incrYItemIterator
  YTableCellIterator: toYTableCell incrYTableCellIterator
- new Version 1.0.4
* Sun Jan 19 2014 anaselli@linux.it
- NCInputField did not manage ctrl-h (08) and del (0x7f) to delete
  input
- Fixed YTree item selection during items population,
  old implementation ignored selected items.
- 2.46.1
* Mon Jan 13 2014 mvidner@suse.com
- use cgraph interfaces if available, to fix building with
  graphviz 2.30 (dvaleev)
  0001-use-cgraph-instead-of-graph-interfaces.patch
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.43.0
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.46.0
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.43.0
* Tue Jan  7 2014 mvidner@suse.com
- Ported to Qt5
- 2.45.0
* Wed Dec 11 2013 anaselli@linux.it
- added external widget plugin management
- added support for multi plugin loader (one per name)
- Version 3.0.12
* Thu Dec  5 2013 mvidner@suse.com
- adjusted to libyui so version 6
- 2.44.0
* Thu Dec  5 2013 mvidner@suse.com
- adjusted to libyui so version 6
- 2.46.0
* Thu Dec  5 2013 mvidner@suse.com
- Added a new option for YPushButton: YUIOpt_relNotesButton;
  it will pop up a dialog with externally provided release notes.
  (by jsrain)
- Added a generic plugin loader libyui-NAME-[qt|gtk|ncurses]
  to manage user defined external widget (by anaselli)
- 3.0.11
* Mon Dec  2 2013 anaselli@linux.it
- added new file checking for YExternalWidgets plugin management
- new Version 1.0.3
* Wed Nov 20 2013 gs@suse.de
- Fixed typos in help text, rephrase text (bnc #839689)
- Version 2.45.0
* Wed Nov 20 2013 gs@suse.de
- Add 'Requires: glibc-locale' to spec-file (bnc #849255)
- Version 2.45.0
* Mon Nov 11 2013 jsrain@suse.cz
- Added handling of release notes using UI-independent handler
  (fate#314695)
* Wed Oct 16 2013 jsrain@suse.cz
- added possibility to show release notes button in dialog heading
  (fate#314695)
* Fri Sep 27 2013 coolo@suse.com
- supplement libyui-qt (bnc#793893)
* Tue Aug  6 2013 tgoettlicher@suse.de
- Fixed dependencies
- Version 2.44.1
* Tue Aug  6 2013 tgoettlicher@suse.de
- fixed dependencies
- Version 2.43.5
* Tue Aug  6 2013 tgoettlicher@suse.de
- Fixed dependencies
- Version 3.0.10
* Fri Aug  2 2013 tgoettlicher@suse.de
- bnc#831758: fix symbol icons
- Version 2.42.13
* Wed Jul 31 2013 gs@suse.de
- Online Update: show multi version packages correctly
- Version 2.44.4
* Tue Jul 30 2013 tgoettlicher@suse.de
- check pick list and installed obj for package classification
- Version 2.42.12
* Wed Jul 24 2013 tgoettlicher@suse.de
- fixed bnc#752278: ComboBox does not show active item when item
  with empty label is present
- Version 3.0.9
* Wed Jul 24 2013 gs@suse.de
- Online Update: improve help, show column 'Kind' beside 'Name',
  Package Selector: get lists of orphaned, suggested, recommended
  and unneeded packages correctly
- Version 2.44.3
* Tue Jul 16 2013 tgoettlicher@suse.de
- Fix build of libyui-qt-graph
- Version 2.43.4
* Tue Jul 16 2013 tgoettlicher@suse.de
- use zypp setting as default value for "ignore recommended" menu
  entry (bnc#811237)
- Version 2.42.11
* Thu Jul 11 2013 tgoettlicher@suse.de
- fixed style issue in repository view (bnc#765790)
- Version 2.42.10
* Thu Jul 11 2013 gs@suse.de
- Online Update: show irrelevant patches only in list 'All Patches',
  improve handling of the patch status, enhance help text
- Version 2.44.2
* Wed Jul  3 2013 gs@suse.de
- remove webpin search from configuration menu (bnc#821866),
  catch exception of sysconfig write (bnc #827608)
- Version 2.44.1
* Sun Jun 30 2013 anaselli@linux.it
- git describe and git --tags do not always return a git hash
  to avoid cmake failure a check has been introduced with a warning
  message
- skipping also .kdev4 when building source package
* Thu Jun 27 2013 gs@suse.de
- Show and handle multiple versions of packages correctly
  (bnc #822962)
- Version 2.44.0
* Wed Jun 26 2013 tgoettlicher@suse.de
- Fixed build of libyui-qt-graph examples
- Version 3.0.8
* Wed Jun 26 2013 tgoettlicher@suse.de
- fixed libgvc dependency (bnc #825751)
- Version 2.42.7
* Wed Jun 26 2013 tgoettlicher@suse.de
- removed webpin search (bnc#821866)
- Version 2.42.9
* Mon Jun 24 2013 anaselli@linux.it
- fixed the use of -DGIT_VERSION=on
- Version 3.0.7
* Tue Jun 18 2013 gs@suse.de
- NCTable multi selection mode: deselect all items correctly,
  return ValueChanged event on Return
- version 2.44.0
* Sat Jun  1 2013 bjoern.esser@gmail.com
- fix build with graphviz >= 2.30.0
- Version 3.0.6
* Fri May 31 2013 bjoern.esser@gmail.com
- license update: LGPL-2.1 or LGPL-3
- get rid of `/usr/bin/env` in hashbang of examples
- new Version 1.0.2
* Sat May 18 2013 bjoern.esser@gmail.com
- fix build on graphviz >= 2.30.0
  libgraph is gone / superseeded by libcgraph
- Version 2.42.6
* Wed May 15 2013 bjoern.esser@gmail.com
- respect compiler flags of system rpm config when building RELEASE
  by adding -DRESPECT_FLAGS to cmake
- add -DSKIP_LATEX to skip generation of LaTeX-based PDF-generation
  when invoking `make docs`
- Version 3.0.5
* Fri May 10 2013 bjoern.esser@gmail.com
- checking prefix in -doc pkg is obsolete
- use bootstrap.sh for legacy in -doc pkg here, too
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.42.8
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- fixup COPYING*
- Version 2.42.5
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.43.3
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.43.6
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.43.9
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- Version 3.0.4
* Tue May  7 2013 gs@suse.de
- Cast return of setCandidate() to bool (due to libzypp changes)
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues
- Version 2.42.4
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues
- Version 2.43.2
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues
- V 2.43.8
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues with ncurses and qt
- Version 3.0.3
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- V 2.43.5
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- Version 2.42.7
* Mon May  6 2013 bjoern.esser@gmail.com
- Version 2.42.3
- use SONAME from libyui instead of VERSION.cmake
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- Version 2.43.1
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- V 2.43.7
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake if plugin
- bumped up patch-version to 3.0.2
- disabled auto-gen of docs
  INSTALL_DOCS=ON will no longer auto-gen the docs
  added a warning to run "make docs" before "make install"
- add DOC_SUBDIR to CMake-Vars
  some distributions prefer %%{name}-%%{version} over
  %%{name}-%%{soname_major} as doc-subdir.
* Mon May  6 2013 tgoettlicher@suse.de
- Fixed so version
- Version 2.42.6
* Mon May  6 2013 tgoettlicher@suse.de
- fixed so version
- V 2.43.6
* Tue Apr 30 2013 gs@suse.de
- Use YSettings::localeDir() instead of LOCALEDIR (bnc #817588)
- V 2.43.5
* Tue Apr 30 2013 tgoettlicher@suse.de
- Increased version because of changed function names
- Version 3.0.1
* Tue Mar 26 2013 gs@suse.de
- NCCheckBoxFrame:  handle option `invertAutoEnable correctly,
  (bug-fix for authentication problem in iscsi-client bnc #805407)
- V 2.43.4
* Thu Feb 21 2013 gs@suse.de
- Show patch descriptions correctly (bnc #803466)
- V 2.43.4
* Thu Feb 21 2013 gs@suse.de
- NCRichText: bug-fix for text in <pre> tags, patch description is
  shown correctly (bnc #803466)
- V 2.43.3
* Fri Feb  8 2013 tgoettlicher@suse.de
- Code clean-up: removed java-like get-prefix
- Version 2.42.7
* Mon Feb  4 2013 tgoettlicher@suse.de
- Added setLocaleDir(), getLocaleDir()
- Version 2.42.6
* Tue Jan 22 2013 gs@suse.de
- Bug-fix for package search (concerning package summary)
- V 2.43.3
* Sat Jan 19 2013 anaselli@linux.it
- wrong path for Libyui_config.h
* Fri Jan 18 2013 anaselli@linux.it
- fixed to use new YSettings, theme path can be set by program
* Fri Jan 18 2013 anaselli@linux.it
- Fixed YSettings
- Added setThemeDir(), getThemeDir(), setIconsDir() and
  getIconsDir() to YSettings
* Thu Jan 17 2013 tgoettlicher@suse.de
- Fixed endcoding of entries in package history (bnc #775608)
- Version 2.42.5
* Thu Jan 17 2013 tgoettlicher@suse.de
- Fixed encoding of tooltips (bnc# 764025)
- Version 2.42.4
* Mon Jan  7 2013 tgoettlicher@suse.de
- Removed needless loadPluginLib() from header file
- Version 2.42.4
* Fri Jan  4 2013 tgoettlicher@suse.de
- fixed bnc #801311: read locale directory from YSettings
- Version 2.42.5
* Mon Dec 17 2012 tgoettlicher@suse.de
- fixed bnc #793893: storage graph in yast missing
- Version 2.42.3
* Wed Dec 12 2012 gs@suse.de
- Improve help text for recommended packages, fix typos
- V 2.43.2
* Wed Dec 12 2012 ma@suse.de
- Adapt to libzypps new history log parser API.
- Version 2.42.3
* Fri Nov 23 2012 anaselli@linux.it
- changed to calendar popup instead using spin
* Fri Nov  2 2012 anaselli@linux.it
- Reimplemented setApplicationTitle from YApplication
- Used YApplication::applicationTitle() and YApplication::applicationIcon()
  to set title and icon
* Fri Nov  2 2012 anaselli@linux.it
-  NCApplication: Reimplemented setApplicationTitle from YApplication
-  Added the availiability to build a git sha1 versioned package using
  cmake -DGIT_VERSION=on
- V 2.43.2
* Fri Nov  2 2012 anaselli@linux.it
- Added new API to managed application title and icon
- Added the availiability to build a git sha1 versioned package using cmake -DGIT_VERSION=on
* Thu Oct 25 2012 anaselli@linux.it
- YQIMage autoScale implementation
- to build a git sha1 versioned package use cmake -DGIT_VERSION=on
* Wed Oct 24 2012 gs@suse.de
- Save settings from 'Dependency' menu (bnc # 766598)
- V 2.43.1
* Thu Oct 18 2012 gs@suse.de
- NCCheckBoxFrame: respect option `noAutoEnable, bug-fix for
  nested frames
- V 2.43.1
* Thu Oct  4 2012 gs@suse.de
- NCPkgTable: bug-fix for sorting the list of packages
- Show function keys in bottom line correctly
- Version 2.43.0
* Thu Oct  4 2012 gs@suse.de
- NCTablePad: bug-fix for sorting of tables
- NCDialog: code cleanup, setStatusLine() added
- V 2.43.0
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Fri Sep  7 2012 tgoettlicher@suse.de
- V 2.42.2
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Mon Aug 13 2012 cfarrell@suse.com
- license update: GPL-2.0
  SPDX format (http://www.spdx.org/licenses) should be used for spec file
  license field
* Fri Aug 10 2012 kkaempf@suse.com
- Update to 1.0.0 for stand-alone libyui
* Thu Jun 21 2012 gs@suse.de
- Added high contrast color schemes "highcontrast" and "inverted"
  (setting Y2NCURSES_COLOR_THEME in /etc/sysconfig/yast2)
* Tue Jun 19 2012 gs@suse.de
- Fixed crash while starting the package selector (bnc #767619)
* Tue Jun 12 2012 kkaempf@suse.com
- Build stand-alone (without YaST)
* Tue May 15 2012 tgoettlicher@suse.de
- renamed package to libyui-qt
- Version: 2.22.6
* Thu May 10 2012 gs@suse.de
- Improve table sorting: sort numeric columns in numeric order,
  respect locale setting
- V 2.22.3
* Tue May  8 2012 gs@suse.de
- Bug-fix for typo in help text (bnc #759100)
- add filter for recommended, suggested, orphaned or unneeded
  packages ('Package Classification in 'Filter' list)
- respect locale setting when sorting the list of packages
- 2.22.6
* Fri May  4 2012 tgoettlicher@suse.de
- Sort numeric table columns in numeric order
- Version: 2.22.6
* Wed May  2 2012 tgoettlicher@suse.de
- Fixed bnc#753784: YaST help dialogs appear fullscreen
- Version: 2.21.4
* Fri Apr 27 2012 tgoettlicher@suse.de
- Workaround for gcc 4.7 issues
- 2.21.24
* Thu Apr 26 2012 tgoettlicher@suse.de
- Added package group for unneeded packages
- 2.21.23
* Tue Apr 17 2012 gs@suse.de
- Merged text from proof-read
- 2.22.5
* Thu Apr 12 2012 tgoettlicher@suse.de
- Fix build with gcc 4.7.
* Tue Apr 10 2012 aschnell@suse.de
- changed license to GPL-2.0
* Tue Apr 10 2012 tgoettlicher@suse.de
- BuildRequire libxcrypt-devel only for < 12.2
- Version: 2.22.5
* Tue Mar 27 2012 gs@suse.de
- Select correct package version and vendor for update (bnc#704123)
- remove libxcrypt-devel from BuildRequires
- 2.22.4
* Tue Mar 27 2012 gs@suse.de
- remove libxcrypt-devel from BuildRequires
- V 2.22.2
* Fri Mar 23 2012 tgoettlicher@suse.de
- Fixed bnc#704123: When updating packages, same version numbers in different repositories confuse YaST
- Version: 2.21.22
* Wed Mar 21 2012 tgoettlicher@suse.de
- Added shortcut to conflict dialog
- Version: 2.21.21
* Fri Mar 16 2012 tgoettlicher@suse.de
- Fixed bnc#722325: untranslated rpm groups
- Version: 2.21.20
* Fri Mar 16 2012 tgoettlicher@suse.de
- Fixed bnc#722325: untranslated rpm groups
- Version: 2.21.3
* Wed Mar 14 2012 gs@suse.de
- Online Update: possibility to search in patch summary, improve
  formatting of patch descriptions
- 2.22.3
* Tue Mar  6 2012 tgoettlicher@suse.de
- Fixed bnc#691572: Formatting Package Descriptions
- Version: 2.21.19
* Tue Mar  6 2012 gs@suse.de
- Better formatting also for notify messages (bnc #746876)
- 2.22.2
* Thu Mar  1 2012 gs@suse.de
- Better formatting of package and patch descriptions (bnc #691572)
- 2.22.1
* Thu Feb 23 2012 tgoettlicher@suse.de
- Fixed selection Table widget (bnc#746156)
- Version: 2.22.4
* Fri Feb 17 2012 tgoettlicher@suse.de
- Fixed selection and sorting in Table widget (bnc#746156)
- Version: 2.22.3
* Mon Feb 13 2012 gs@suse.de
- NCRichText: interpret html tags inside <pre> </pre>
  (bnc #724119, bnc #737752)
- V 2.22.1
* Wed Feb  8 2012 tgoettlicher@suse.de
- Fixed bnc#731540: fixed auto-scroll in LogView
- Version: 2.22.2
* Thu Jan 19 2012 tgoettlicher@suse.de
- Fixed bnc #734763: yast2 sw_single software management with QT ui
  resets columns in software view when horizontal scrollbar is removed
  (Patch from Frank Schäfer)
- Version: 2.21.18
* Thu Jan 19 2012 tgoettlicher@suse.de
- Fixed bnc#723151: Install all matching debuginfo packages" never
    finds anything-debuginfo-32bit
- Fixed bnc#730007: When updating packages, + keyshortcut doesn't
    always work
- Version: 2.21.17
* Tue Jan 17 2012 gs@suse.de
- Confirmed license
- 2.22.0
* Wed Dec 21 2011 gs@suse.de
- Confirmed license
- V 2.22.0
* Tue Dec 20 2011 tgoettlicher@suse.de
- Confirmed license
- V 2.22.1
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Dec  1 2011 tgoettlicher@suse.de
- Follow links to anchors in YQTextBrowser (bnc #727330)
- V 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Nov 17 2011 tgoettlicher@suse.de
- Fixed bnc#722617: Yast2 package manager does not show icons of some packages
- Version: 2.21.16
* Wed Nov 16 2011 tgoettlicher@suse.de
- Fixed bnc#713343: YaST ncurses help screen is too small
- Version: 2.21.2
* Tue Nov  8 2011 tgoettlicher@suse.de
- Fixed untranslated rpm package groups (bnc #722325)
- Version: 2.21.15
* Fri Nov  4 2011 tgoettlicher@suse.de
- Changed default for "Ignore recommended packages for already installed
  packages" (bnc #716017)
- Version: 2.21.14
* Tue Oct 25 2011 gs@suse.de
- Set action 'Show Summary' correctly (menu 'Configuration',
  'Action after Package Installation')
- 2.21.2
* Mon Oct 24 2011 tgoettlicher@suse.de
- Fixed bnc#725953: Package manager settings are saved but not applied on start
- Version: 2.21.13
* Mon Oct 24 2011 tgoettlicher@suse.de
- Fixed bnc#721810: Disabled option "Ignore recommended packages for already installed
  packages" for update mode
- Version: 2.21.12
* Tue Oct 11 2011 tgoettlicher@suse.de
- Fixed bnc#718197: YaST2 Qt package manager opens RMB context
  menus at a wrong position, usability issue
- Version: 2.21.11
* Fri Oct  7 2011 tgoettlicher@suse.de
- Fixed bnc#718197: context menus at a wrong position
- 2.21.10
* Thu Oct  6 2011 tgoettlicher@suse.de
- Made settings persistant (fate #307220 )
- 2.21.9
* Wed Oct  5 2011 tgoettlicher@suse.de
- Applied Stano's patch to make installation history accessible
  from Yast GUI
- 2.21.8
* Tue Oct  4 2011 tgoettlicher@suse.de
- Don't overwrite wizard's dialog title
- V 2.21.7
* Fri Sep 23 2011 tgoettlicher@suse.de
- removed unversioned Provides/Obsoletes from spec file
- V 2.21.6
* Thu Sep 22 2011 coolo@suse.com
- require yast2-qt-branding
* Tue Sep 20 2011 tgoettlicher@suse.de
- respect stylesheets in dialogs
- V 2.21.5
* Tue Sep 20 2011 tgoettlicher@suse.de
- respect stylesheet in package selector
- 2.21.7
* Wed Aug 17 2011 tgoettlicher@suse.de
- fixed bnc#712191: Yast2 displays Cyrillic .desktop descriptions
- 2.21.6
* Thu Aug  4 2011 lslezak@suse.cz
- run the solver after changing "ignoreAlreadyRecommended" flag
  to reflect the change
* Tue Aug  2 2011 lslezak@suse.cz
- added new ignoreAlreadyRecommended solver option to the options
  submenu (bnc#668588)
- 2.21.5
* Tue Aug  2 2011 lslezak@suse.cz
- added new ignoreAlreadyRecommended solver option to
  the dependencies submenu (bnc#668588)
- 2.21.1
* Thu Jun 30 2011 tgoettlicher@suse.de
- Fixed theme/color palette handling (bnc #637294)
- 2.21.4
* Wed Jun 15 2011 tgoettlicher@suse.de
- Fixed segfault in event handling (bnc #696595)
- V 2.21.4
* Fri May 27 2011 tgoettlicher@suse.de
- Fixed typo (bnc #696514)
- 2.21.3
* Wed May 18 2011 tgoettlicher@suse.de
- Fixed selection in tree widgets (bnc #680107)
- V 2.21.4
* Tue May 17 2011 gs@suse.de
- NCInputField: return event reason 'Activated' on key 'Return'
- V 2.21.3
* Mon May  9 2011 cgiboudeaux@gmx.com
- Add gcc46_build_fix.patch
* Thu Apr 28 2011 tgoettlicher@suse.de
- Enable shadow for wizard title
- V 2.21.3
* Wed Apr 27 2011 tgoettlicher@suse.de
- Added translation markers for RPM fields (bnc #686502)
- 2.21.2
* Wed Apr 27 2011 tgoettlicher@suse.de
- Enabled menu key to show context menu (bnc #681702)
- 2.21.1
* Tue Apr 26 2011 gs@suse.de
- Adjust NCTree params, require latest libyui
- V 2.21.0
* Tue Apr 26 2011 gs@suse.de
- NCTree: use default params for multi selection options
- V 2.21.2
* Thu Apr 21 2011 tgoettlicher@suse.de
- Cleaned-up fix for line breaks in LogView (bnc #684759)
- V 2.21.2
* Tue Apr 19 2011 tgoettlicher@suse.de
- Don't allow recursive selection for non-multiselection widgets
- V 2.21.1
* Mon Apr 18 2011 tgoettlicher@suse.de
- Enable busy cursor for tree widget during time consuming
  operations
- V 2.21.1
* Mon Apr 18 2011 gs@suse.de
- NCTree: option `recursiveSelection added
- V 2.21.1
* Fri Apr 15 2011 tgoettlicher@suse.de
- Added support for recursive selection in tree widgets
- V 2.20.8
* Fri Apr 15 2011 tgoettlicher@suse.de
- Added support for recursive selection in tree widgets
- V 2.20.3
* Tue Apr 12 2011 tgoettlicher@suse.de
- Fixed line breaks in LogView (bnc #684759)
- V 2.20.7
* Wed Mar 16 2011 tgoettlicher@suse.de
- Fixed dependencies (bnc #667938)
- V 2.20.6
* Wed Mar  9 2011 gs@suse.de
- Show block devices in file selection dialog (bnc #661685)
- V 2.21.0
* Tue Mar  8 2011 tgoettlicher@suse.de
- Show block devices in file selection dialog (bnc #661685)
- V 2.20.5
* Thu Feb 24 2011 gs@suse.de
- Bug-fix for bnc #673801 (deselecting items in NCTree with multi
  selection works correctly)
- V 2.20.7
* Mon Feb 21 2011 tgoettlicher@suse.de
- Fixed unselecting items for tree widget (bnc #673801)
- V 2.20.4
* Wed Feb 16 2011 tgoettlicher@suse.de
- Fixed event handling in context menu (bnc #671147)
- V 2.20.3
* Tue Feb 15 2011 gs@suse.de
- Correct color for shortcuts and visible cursor in text entry
  (modified bug-fix for bnc #652240)
- V 2.20.6
* Fri Feb 11 2011 tgoettlicher@suse.de
- Fixed event handling in tree widget
- V 2.20.2
* Fri Feb 11 2011 tgoettlicher@suse.de
- Fixed segfault for currentItem on tree widget
- V 2.20.2
* Wed Feb  9 2011 gs@suse.de
- Require latest libyui
- V 2.20.3
* Wed Feb  9 2011 gs@suse.de
- Bugfixes in NCTree (currentItem works correctly) and
  NCMultiSelection (check for valid pointer), require latest libyui
- V 2.20.5
* Tue Feb  8 2011 tgoettlicher@suse.de
- Added support for currentItem to tree widget
- V 2.20.1
* Tue Feb  8 2011 tgoettlicher@suse.de
- Added support for currentItem to tree widget
- V 2.20.1
* Thu Feb  3 2011 tgoettlicher@suse.de
- Added ValueChanged event to TreeWidget
- V 2.20.0
* Thu Feb  3 2011 tgoettlicher@suse.de
- Fixed dependencies
- 2.20.3
* Thu Feb  3 2011 tgoettlicher@suse.de
- V 2.20.0
* Wed Feb  2 2011 gs@suse.de
- Internal: code cleanup (esp. NCPackageSelector, NCPkgTable),
  require latest libyui
- V 2.20.2
* Wed Feb  2 2011 gs@suse.de
- Add support for multi selection in Tree widget (checkboxes),
  require lastest libyui
- V 2.20.4
* Mon Jan 17 2011 tgoettlicher@suse.de
- Fixed LogView's  scroller
- V 2.19.8
* Fri Jan 14 2011 tgoettlicher@suse.de
- Fixed hanging browse dialogs (bnc #580143)
- V 2.19.7
* Thu Jan 13 2011 tgoettlicher@suse.de
- fixed preselected items in package list (bnc #661743)
- 2.20.2
* Wed Jan 12 2011 tgoettlicher@suse.de
- Fixed LogView's  scroller
- V 2.19.6
* Tue Jan 11 2011 jengelh@medozas.de
- Do away with the unnatural brown color in the progressbar and
  use a SUSE-typical green instead
- V 2.20.3
* Fri Jan  7 2011 tgoettlicher@suse.de
- Fixed incompatibilities caused by checkboxes for treewidgeet
- 2.20.1
* Wed Jan  5 2011 tgoettlicher@suse.de
- Fixed incompatibilities causes by checkboxes for treewidgeet
- V 2.20.2
* Mon Dec 20 2010 tgoettlicher@suse.de
- Added support for check boxes in tree widgets
- V 2.19.5
* Mon Dec 20 2010 tgoettlicher@suse.de
- Added support for check boxes in tree widgets
- V 2.19.2
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 25 2010 gs@suse.de
- Correct color for keyboard shortcut, visible cursor in multi line
  text entry (bug-fix for bnc #652240)
- V 2.20.1
* Mon Nov 22 2010 tgoettlicher@suse.de
- disables native dialogs (bnc #642270)
- V 2.19.4
* Thu Nov 11 2010 gs@suse.de
- Improve help text for status information and adjust status for
  languages
- 2.20.0
* Tue Oct 12 2010 tgoettlicher@suse.de
- fixed bnc #422226: Switching patterns should scroll the
  package list back to the top
- 2.20.1
* Tue Oct 12 2010 gs@suse.de
- NCRichText: bug-fix for pre tag (bnc #484629)
- V 2.20.0
* Mon Oct 11 2010 tgoettlicher@suse.de
- Fixed font dependency (bnc #629892)
- V 2.19.3
* Thu Aug 19 2010 gs@suse.de
- Show error popup if searching for packages throws an exception
  (bnc #615102)
- 2.19.5
* Tue Jul 27 2010 gs@suse.de
- Show all patterns in 'Filter/Patterns' list
  (bug-fix for bnc#624996)
- 2.19.4
* Tue Jul 13 2010 dmacvicar@suse.de
- bnc#621649 patterns with no categories were supposed to be
  displayed at the top, not randomly
- 2.20.0
* Thu Jun 17 2010 tgoettlicher@suse.de
- Fixed left hand to right hand changing (bnc #612030)
- V 2.19.2
* Wed Jun  9 2010 gs@suse.de
- Use ncursesw6-config to get includes for ncurses6 library
- 2.19.3
* Wed May 26 2010 gs@suse.de
- Use ncurses6 library (adjust INCLUDES in Makefile.am, require
  latest yast2-ncurses - bnc #607767)
- 2.19.2
* Wed May 12 2010 gs@suse.de
- Use ncurses6 library (package libncurses6)
- V 2.19.5
* Tue May 11 2010 gs@suse.de
- Add options for dependency solver:
  * cleanup when deleting packages
  * allow vendor change
- 2.19.1
* Fri Apr 30 2010 tgoettlicher@suse.de
- Added solver options:
  * cleanup when deleting packages
  * allow vendor change
- 2.19.2
* Tue Apr 27 2010 gs@suse.de
- NCTextPad: do not append \n after the very last line
  (bnc #573553)
- V 2.19.4
* Tue Apr 20 2010 tgoettlicher@suse.de
- Increased version number
- 2.19.1
* Tue Apr 20 2010 tgoettlicher@suse.de
- increased version number
- V 2.19.1
* Tue Apr 20 2010 tgoettlicher@suse.de
- Fixed untranslated context menu (bnc #580165)
- V 2.18.12
* Wed Apr 14 2010 aschnell@suse.de
- fixed alignment in Table with multi-selection (bnc #596328)
- V 2.19.3
* Fri Apr  9 2010 tgoettlicher@suse.de
- Fixed endless loop in layout algorithm  (bnc #558699)
- V 2.19.1
* Thu Apr  8 2010 tgoettlicher@suse.de
- Fixed LogView auto scroll (bnc #463405)
- V 2.18.11
* Thu Apr  1 2010 tgoettlicher@suse.de
- Fixed bnc #563923: Locked software package gets updated
- 2.18.22
* Thu Apr  1 2010 tgoettlicher@suse.de
- Fixed bnc #48761: yast doesn't respect locks
- 2.18.21
* Sun Mar 21 2010 coolo@novell.com
- fix compilation with latest graphviz
- 2.19.0
* Thu Mar 18 2010 tgoettlicher@suse.de
- Added libqt4 dependency (bnc #589104)
* Thu Mar 18 2010 tgoettlicher@suse.de
- Added libqt4 dependency (bnc #589104)
* Tue Mar  2 2010 coolo@novell.com
- Fixing undefined behaviour that triggers a crash with
  gcc 4.5 (bnc#582088)
- V 2.19.0
* Tue Feb  9 2010 tgoettlicher@suse.de
- added license headers
* Tue Feb  9 2010 tgoettlicher@suse.de
- added license headers
* Tue Feb  9 2010 tgoettlicher@suse.de
- added gpl v2+ license headers
* Mon Jan 18 2010 tgoettlicher@suse.de
- fixed bnc #571200 - filter out 32 bit debuginfo packages
- V 2.18.20
* Mon Jan 11 2010 kmachalkova@suse.cz
- Improved algorithm for double '&&' escaping (this one hopefully
  does not "eat" chars in some Frames anymore - still bnc#559226)
- V 2.19.2
* Mon Dec 21 2009 tgoettlicher@suse.de
- fixed bnc #564321: Alt-P shortcut overloaded in YaST2 Software Management
* Fri Dec 18 2009 ma@suse.de
- Work around 32768 lines limit in ncurses table. (bnc #550733)
- V 2.19.1
* Tue Dec 15 2009 kmachalkova@suse.cz
- Allow escaping '&' characters in string with hotkey support -
  convert 'foo&&bar' to 'foo&bar' (bnc#559226)
- V 2.19.0
* Mon Dec 14 2009 kmachalkova@suse.cz
- Update status of dependent packages when the status of selected
  package changes (redraw corresponding column - bnc#561337)
- 2.19.0
* Tue Dec  8 2009 tgoettlicher@suse.de
- fixed bnc #542830: mouse cursor is busy in context menu
* Fri Dec  4 2009 tgoettlicher@suse.de
- Enabled multiple packages (fate# 305311)
- V 2.18.19
* Tue Dec  1 2009 tgoettlicher@suse.de
- fixed bnc #549868: Mnemonic clash in Software Management
- fixed bnc #554473: UTF-8 Problem
- fixed bnc #558881: Broken accented chars in YaST Qt packager versions tab
* Thu Nov 19 2009 tgoettlicher@suse.de
- fixed orphaned packages View (bnc #551771)
* Thu Nov  5 2009 gs@suse.de
- Start with correct filter view on option `repoMode (repositories)
  and `summaryMode (installation summary) (bnc #548437)
* Fri Oct 23 2009 dmacvicar@suse.de
- allow repository upgrades from the user interface
  (equivalent to zypper dup --from X ) (bnc#548551)
- V 2.18.18
* Thu Oct 22 2009 tgoettlicher@suse.de
- Fixed zypp dependency
- V 2.18.17
* Fri Oct 16 2009 tgoettlicher@suse.de
- Added group for orphaned packages
- V 2.18.16
* Thu Oct  8 2009 tgoettlicher@suse.de
- fixed bnc #539367: YaST Software Management, search function
  not registering secondary enter key.
* Thu Oct  1 2009 tgoettlicher@suse.de
- fixed bnc #543176: YaST2 cites 'supportability: unknown' for all packages
- V 2.18.15
* Mon Sep 28 2009 tgoettlicher@suse.de
- fixed bnc #532518: YaST in translation
- V 2.18.14
* Mon Sep 28 2009 tgoettlicher@suse.de
- fixed bnc #532518: YaST in translation
- V 2.18.10
* Thu Sep 17 2009 tgoettlicher@suse.de
- Applied patch that fixes tabs by Fabien Crespel
- V 2.18.13
* Mon Sep 14 2009 tgoettlicher@suse.de
- Applied patch that fixes sorting by Fabien Crespel
- V 2.18.12
* Tue Sep  8 2009 tgoettlicher@suse.de
- Removed wrong package version from file list and change log view
  (#bnc 528750)
* Wed Aug 26 2009 aschnell@suse.de
- fixed workaround for shared library reference counting problem
  (bnc #530839)
- V 2.18.9
* Mon Aug 17 2009 tgoettlicher@suse.de
- Applied patch from Frank Schaefer that fixes resizing columns
  in tables (bnc #392056)
- V 2.18.8
* Fri Aug 14 2009 tgoettlicher@suse.de
- Applied patch for optimal column width by Frank Schaefer
- V 2.18.11
* Tue Aug 11 2009 tgoettlicher@suse.de
- Fixed hard-coded font size in detail view (bnc #524225)
* Fri Jul 31 2009 tgoettlicher@suse.de
- Added repo priority and vendor to version view (bnc #503185)
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed translations in disk usage list (bnc #445716)
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed highlighting in search dialog (bnc #506813)
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed bnc #499699: position of search button in software management module
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed buggy search in keywords (bnc #470069)
* Wed Jul 29 2009 kmachalkova@suse.cz
- Use YIconLoader to search for icons (add icon search path, use
  findIcon in IconButton widget) (FaTe #306356)
- V 2.18.7
* Tue Jul 28 2009 kmachalkova@suse.cz
- Search for icons in several possible directories (using
  /usr/share/icons/hicolor as fallback) - holds for everything
  derived from SelectionWidget (FaTE #306356)
- V 2.18.8
* Tue Jul 28 2009 tgoettlicher@suse.de
- Fixed closing tab mixes up view (bnc #513845)
* Mon Jul 27 2009 tgoettlicher@suse.de
- applied patch for autosize columns
- patch by Frank Schäfer
- tested by Dave Plater
- bnc #441828
- V 2.18.10
* Wed Jul 22 2009 kmachalkova@suse.cz
- Start webpin client from 'Configuration' menu (FaTE #306928)
* Wed Jul 22 2009 kmachalkova@suse.cz
- Start webpin client from 'Configuration' menu (FaTE #306928)
* Tue Jul 14 2009 aschnell@suse.de
- replaced Recommends in yast2-storage with Supplements in
  yast2-qt-graph (bnc #521545)
* Thu May 28 2009 gs@suse.de
- NCTable/NCTablePad: only sort in reverse order if Ctrl 'o'
  is used for table sorting
- V 2.18.10
* Thu May 28 2009 tgoettlicher@suse.de
- V 2.18.9
* Wed May 27 2009 ma@suse.de
- Remove use of deprecated Package::filenames.
* Wed May 27 2009 ma@suse.de
- Remove use of deprecated Package::filenames.
- 2.18.4
* Wed May 27 2009 gs@suse.de
- Sorting the package list by size works correctly (bnc#437217)
- 2.18.3
* Wed May 27 2009 gs@suse.de
- NCTablePad: add the possibility to set a dedicated sort strategy
  for table sorting (required for bnc #437217)
- V 2.18.9
* Tue May 12 2009 gs@suse.de
- NCAskForFile/NCAskForDirectory: use YUI::widgetFactory() to
  create the layout
* Wed May  6 2009 kmachalkova@suse.cz
- Speeding up scrolling big package lists left/right (bnc#498267)
- 2.18.2
* Wed Apr 29 2009 gs@suse.de
- NCursesWindow: revert the patch which sets back_color_erase to
  FALSE (isn't necessary any longer, see bnc #418613). Except for
  this the improvements from bce_workaround_by_werner.diff remain
  in place.
- V 2.18.8
* Mon Apr 27 2009 gs@suse.de
- Allow empty labels for NCInputField, NCComboBox etc. (bnc#289600)
* Fri Apr 24 2009 tgoettlicher@suse.de
- removed useless matchFiles()
- V 2.18.8
* Fri Apr 17 2009 kmachalkova@suse.cz
- Fixed chaotic behaviour of cursor keys after the table has been
  sorted (Ctrl-O) - bnc#493884
- Improved table sort: sort in reversed order, if the same column
  is selected repeatedly
* Fri Apr  3 2009 tgoettlicher@suse.de
- Fixed confusion caused by patterns (bnc #476965)
- V 2.18.7
* Fri Apr  3 2009 tgoettlicher@suse.de
- Fixed view mode options (summaryMode, youMode) (bnc #490176)
* Thu Apr  2 2009 tgoettlicher@suse.de
- Fixed libzypp dependency
- V 2.18.6
* Mon Mar 30 2009 kmachalkova@suse.cz
- Do not implicitly search for matching keywords (added a new switch
  into search options to include/exclude keywords) (bnc#470069)
* Thu Mar 26 2009 aschnell@suse.de
- fixed certain colors when using styles
* Thu Mar 26 2009 gs@suse.de
- Bugfix for IntField widget: draw the value correctly (was hidden
  in some cases, e.g. in Image Creator, bnc #488757)
- V 2.18.7
* Thu Mar 19 2009 gs@suse.de
- Add name of source package to technical details view
* Tue Mar 17 2009 tgoettlicher@suse.de
- Fixed sort by version (bnc #467871)
* Tue Mar 17 2009 gs@suse.de
- NCRichText widget: bugfixes for text in <pre>...</pre> tags:
  show DOS files correctly, add missing PadNL(), show complete
  license text (bnc #484163),
  only take printable chars into account in method textWidth()
- V 2.18.6
* Fri Mar 13 2009 tgoettlicher@suse.de
- Added name of source package to technical detail view
* Thu Mar 12 2009 tgoettlicher@suse.de
- Fixed confusing system verification mode (bnc #285482)
- V 2.18.5
* Wed Mar 11 2009 kmachalkova@suse.cz
- Added tooltips to BarGraph widget (duplicate segment text in
  a tooltip should the segment become too small)
* Tue Mar 10 2009 tgoettlicher@suse.de
- Fixed frame widget min width (bnc #409143)
* Mon Mar  9 2009 aschnell@suse.de
- added support for context menus
- 2.18.4
* Mon Mar  9 2009 tgoettlicher@suse.de
- Fixed "Unsupported Packages" confirmation when removing unsupported packages (bnc #475186)
* Fri Mar  6 2009 tgoettlicher@suse.de
- Added context menus
- V 2.18.6
* Fri Mar  6 2009 tgoettlicher@suse.de
- Added context menus
- V 2.18.7
* Sun Mar  1 2009 coolo@suse.de
- hopefully last fix ;(
* Thu Feb 26 2009 tgoettlicher@suse.de
- Fixed incorrect sort order in package list (bnc #469203)
* Tue Feb 24 2009 tgoettlicher@suse.de
- Fixed segfault when switching filters and version tab is shown
* Tue Feb 24 2009 aschnell@suse.de
- support newlines in tooltips
* Sun Feb 22 2009 coolo@suse.de
- another fix
- V 2.18.6
* Sun Feb 22 2009 coolo@suse.de
- fix compilation with GCC 4.4
- V 2.18.5
* Fri Feb 20 2009 tgoettlicher@suse.de
- Fixed menubar spacing in wizard (bnc #464088)
* Thu Feb 19 2009 tgoettlicher@suse.de
- Fixed bnc #464152: save file dialog asks twice to replace file
  when the file exists
* Thu Feb 19 2009 kmachalkova@suse.cz
- New menu for launching repo manager and YOU configuration
- New sub-menu for configuring PKGMGR_ACTION_AT_EXIT sysconfig
  variable
- Focus newly created table/input field after switching between filter
  views
- 2.18.1
* Wed Feb 18 2009 coolo@suse.de
- fix compilation with gcc 4.4
- V 2.18.5
* Tue Feb 17 2009 gs@suse.de
- Don't set textdomain to "ncurses" in constructor of NCDialog
  (would overwrite other textdomains) bnc#476245
- V 2.18.4
* Tue Feb 17 2009 aschnell@suse.de
- various minor fixes and improvements
- 2.18.3
* Sun Feb 15 2009 coolo@suse.de
- include stdio to fix compilation with gcc 4.4
* Mon Feb  9 2009 tgoettlicher@suse.de
- Fixed support level wording in description view (bnc #470667)
* Mon Feb  9 2009 gs@suse.de
- Internal changes in NCFileSelection: correct references to
  YTableItems and YTableCells
- V 2.18.3
* Mon Feb  9 2009 sh@suse.de
- Require latest libyui in spec file (API change)
* Mon Feb  9 2009 sh@suse.de
- Require latest libyui in spec file (API change)
- V 2.18.5
* Mon Feb  9 2009 sh@suse.de
- Added virtual destructor for YTableCell for better
  NCFileSelection support
- V 2.18.4
* Wed Feb  4 2009 sh@suse.de
- Save and restore open tabs
- V 2.18.4
* Wed Feb  4 2009 tgoettlicher@suse.de
- Added application icons to description view
- Limited file list to 500 entries
- V 2.18.3
* Wed Feb  4 2009 sh@suse.de
- Added tab context menu (move left, move right, close)
* Thu Jan 29 2009 sh@suse.de
- Use tabs instead of combo box for switching filter views
  See also:
    http://preview.tinyurl.com/tabbed-pkg-browsing
    http://preview.tinyurl.com/tabbed-pkg-browsing-follow-up
- Moved PackageKit package groups filter view to separate class
- Restored RPM groups filter view
- V 2.18.2
* Tue Jan 27 2009 aschnell@suse.de
- added simple user-interaction
- 2.18.2
* Tue Jan 27 2009 aschnell@suse.de
- extended YGraph for simple user-interaction
- V 2.18.3
* Fri Jan 23 2009 aschnell@suse.de
- improved renderer
- 2.18.1
* Tue Jan 20 2009 kmachalkova@suse.cz
- Fixed weird behaviour of left/right arrow keys (bnc#467586)
- Speeding up displaying big lists (repository filter & co.) using
  overloaded addItem from parent class - requires new y2-ncurses
  (bnc#467586)
- 2.18.0
* Tue Jan 20 2009 kmachalkova@suse.cz
- Table widget: two variants of addItem method (all-at-once and
  one-by-one) + YTable::addItems reimplemented in order to speed
  up item insertion (table must not be redrawn on each insert)
  (bnc#467586)
- V 2.18.2
* Fri Jan 16 2009 kkaempf@suse.de
- Fix bnc#427372 once more, YWidgetFactory:createTable was missing
* Thu Jan 15 2009 aschnell@suse.de
- initial version
- 2.18.0
* Thu Jan 15 2009 sh@suse.de
- Workaround for bnc #440101: Double clicks in Oxygen theme
  Now no longer using itemActivated signal, but itemDoubleClicked
* Thu Jan 15 2009 sh@suse.de
- Fixed bnc #427372: Specify class ownership for SWIG bindings
* Wed Jan 14 2009 kmachalkova@suse.cz
- Wizard widget is now derived from QSplitter, replacing former
  QFrame. This makes steps/tree panel collapsible (bnc#460739,
  bnc#445682)
* Wed Jan 14 2009 aschnell@suse.de
- added graph widget
- V 2.18.4
* Wed Jan 14 2009 aschnell@suse.de
- added graph widget
- V 2.18.2
* Tue Jan 13 2009 tgoettlicher@suse.de
- Fixed bnc #445951: Help dialog untranslated
* Mon Jan 12 2009 tgoettlicher@suse.de
- Fixed column widths in patch and language lists (bnc #461177)
* Fri Jan  9 2009 sh@suse.de
- Fixed accumulated margins in "Versions" view for installed
* Fri Jan  9 2009 sh@suse.de
- Fixed bnc #462778: Community repos show up as repo_1, repo_2, etc.
  in Versions view
* Fri Jan  9 2009 tgoettlicher@suse.de
- Fixed bnc #458975: Text cropped in treewidget
- V 2.18.3
* Thu Jan  8 2009 sh@suse.de
- Fixed bnc #464430 - Root tree items always displayed as open
* Wed Jan  7 2009 sh@suse.de
- Fixed bnc #461617: Glyph ArrowLeft / ArrowRight in Arabic
* Wed Jan  7 2009 sh@suse.de
- Fixed bnc #461617: Glyph ArrowLeft / ArrowRight in Arabic
* Tue Jan  6 2009 kmachalkova@suse.cz
- Fixed crash after pressing some keys (left, right, backspace)
  handled by parent class of NCPkgTable (bnc#462961)
- Make matching exact string in package search really exact
  (bnc#459719)
* Fri Jan  2 2009 tgoettlicher@suse.de
- Fixed bnc #442161: don't sort package list after each status change
* Wed Dec 17 2008 sh@suse.de
- Applied kmachalkova's patch for bnc #399599: Search exact match
- V 2.18.1
* Wed Dec 17 2008 tgoettlicher@suse.de
- Added stylesheet editor
- V 2.18.2
* Mon Dec 15 2008 kmachalkova@suse.cz
- Fixed tree items indexing to ensure selecting the correct item
  in modules using navigation tree (bnc#459068)
- V 2.17.12
* Thu Dec 11 2008 tgoettlicher@suse.de
- Fixed bnc #438861: Wizard layout problems for Arabic and Hebrew
- V 2.17.25
* Wed Dec 10 2008 sh@suse.de
- Fixed bnc #457682: Qt-UI interprets HTML-tags in wizard title
- Fixed bnc #457691: HTML tags in slide show install log
- V 2.17.24
* Mon Dec  8 2008 dmacvicar@suse.de
- package selector shows libzypp unsupported packages incorrectly
  (bnc #457214)
- V 2.17.25
* Mon Dec  8 2008 dmacvicar@suse.de
- Fix regression on package selector GUI speed.
  schedule layout of tree items for when the insertion of them
  is finished and we are back in the event loop.
  (bnc #457281)
- V 2.17.24
* Fri Dec  5 2008 dmacvicar@suse.de
- hide the solver information feature if the package is not
  present on the installation media (the popup has no sense there)
  (bnc #450065)
- V 2.17.23
* Thu Dec  4 2008 kmachalkova@suse.cz
- Installed patterns/patches are marked as 'i' (bnc#442484)
- Adjusted switching between pattern states (bnc#445415 for ncurses)
- Enables sorting of pkg tables (partially bnc#437217)
- 2.17.11
* Tue Dec  2 2008 sh@suse.de
- Fixed bnc #450280: Text cut off in repository list
- V 2.17.22
* Fri Nov 28 2008 dmacvicar@suse.de
- fix displaying of automatic changes confirmations and
  unsupported packages confirmations.
- Needs fix in libzypp 5.24.2 so vendor unsupported packagages are
  marked correctly.
- V 2.17.21
* Fri Nov 28 2008 sh@suse.de
- Last fix (bnc #449804) breaks yast2 sysconfig editor - use
  QHeaderView::ResizeToContents instead of QHeaderView::Stretch
- V 2.17.23
* Fri Nov 28 2008 sh@suse.de
- Fixed bnc #449804: Wizard navigation tree always cuts off items
- V 2.17.22
* Wed Nov 26 2008 coolo@suse.de
- convert the image if it does not need scaling (bnc#449150)
- V 2.17.21
* Tue Nov 25 2008 sh@suse.de
- Fixed fix for bnc #447273 (versions missing) that broke fix for
  bnc #441828 (column widths)
- V 2.17.20
* Mon Nov 24 2008 tgoettlicher@suse.de
- Fixed broken version column (bnc #447273)
- V 2.17.19
* Wed Nov 19 2008 sh@suse.de
- Fixed bnc #445415: No packages from patterns installed
- V 2.17.18
* Wed Nov 19 2008 sh@suse.de
- Enforce table keepSorting(): Disable interactive sorting, if set
* Tue Nov 18 2008 sh@suse.de
- Fixed broken version numbers in change log
- V 2.17.17
* Thu Nov 13 2008 sh@suse.de
- Fixed over-wide buttons in dependency problem dialog
* Thu Nov 13 2008 sh@suse.de
- Updated lang_fonts from mfabian for Hebrew (bnc #444296)
- V 2.17.20
* Wed Nov 12 2008 sh@suse.de
- Infrastructure for better table column widths (bnc #441828)
- V 2.17.19
* Wed Nov 12 2008 sh@suse.de
- Improved table column widths (bnc #441828)
  still not perfect, but much better
* Wed Nov 12 2008 sh@suse.de
- Fixed over-wide [OK] button in package selector help
- V 2.17.16
* Fri Nov  7 2008 sh@suse.de
- Updated lang_fonts from mfabian for bnc #438855 (inst fonts)
- V 2.17.18
* Fri Nov  7 2008 kmachalkova@suse.cz
- Sort patterns according to order AND category (bnc#439088)
- 2.17.10
* Thu Nov  6 2008 gs@suse.de
- YOU layout improved (enough space for download size)
- Always update the package table after dependency popup is shown
- Increase width of dependency popup (bnc #441414)
- 2.17.9
* Wed Nov  5 2008 gs@suse.de
- Internal change: delete NCPkgPatchSearch popup correctly
* Wed Nov  5 2008 tgoettlicher@suse.de
- Fixed encoding in description view
* Mon Nov  3 2008 tgoettlicher@suse.de
- Fixed bnc #438680: software installation description not
  refreshed after search
* Fri Oct 31 2008 sh@suse.de
- Fixed bnc #381981: Bad initial size for secondary filters in
  "Repositories" filter view
- V 2.17.15
* Thu Oct 30 2008 tgoettlicher@suse.de
- Fixed QPainter warnings in YQBusyIndicator
- V 2.17.17
* Tue Oct 28 2008 sh@suse.de
- (coolo) Fixed bnc #427632: Steps in wizard not updated
* Fri Oct 24 2008 sh@suse.de
- Fixed bnc #403367: Crash when searching for invalid regex
- V 2.17.14
* Thu Oct 23 2008 kmachalkova@suse.cz
- Added explanation of 'satisfied' (:-)) pattern/language
  status (bnc#432528)
- Exclude readonly directories from the checking of available
  diskspace(bnc#384368)
- 2.17.8
* Thu Oct 23 2008 gs@suse.de
- Add missing method selectItem() to NCComboBox
- V 2.17.11
* Wed Oct 22 2008 gs@suse.de
- Show a "Searching..." popup during package search
- Warning message added to disk error popup
- Internal changes: disk space testing enabled, comments added
* Tue Oct 21 2008 sh@suse.de
- Fixed bnc #436783: Map Amusements/Teaching/* to Education
- De-obfuscated RPM groups <--> PackageKit mapping
- V 2.17.13
* Tue Oct 21 2008 tgoettlicher@suse.de
- Fixed default button (bnc #381187)
- V 2.17.16
* Tue Oct 21 2008 tgoettlicher@suse.de
- Fixed bnc #436716: horizontal scrollbar for TreeWidget
* Thu Oct 16 2008 sh@suse.de
- Fixed bnc #433130: Poor performance in runlevel editor
  (Massive performance drop when inserting items into YQTable)
- V 2.17.15
* Thu Oct 16 2008 sh@suse.de
- Prevent segfaults: Converted QY2Styler to a real singleton
* Wed Oct 15 2008 sh@suse.de
- Added `opt(`confirmUnsupported) for PackageSelector widget
  (bnc #435479)
- V 2.17.12
* Wed Oct 15 2008 sh@suse.de
- Beautified symptoms of crash while DBUS restart (bnc #428125)
- Require latest libyui (API change!)
- V 2.17.14
* Wed Oct 15 2008 sh@suse.de
- Added `opt(`confirmUnsupported) for PackageSelector widget
  (bnc #435479)
- V 2.17.14
* Wed Oct 15 2008 sh@suse.de
- Require latest libyui (API change!)
- V 2.17.10
* Wed Oct 15 2008 sh@suse.de
- Require latest libyui-devel (API change!)
- V 2.17.7
* Wed Oct 15 2008 gs@suse.de
- Remove "/bin/dumpkeys | /bin/loadkeys --unicode" from
  NCApplication::initConsoleKeyboard. The line breaks the
  console keyboard and isn't necessary at all (bnc #433016).
- Call DialogSpy upon Ctrl-d-Shift-y (introspection of the
  topmost dialog)
* Tue Oct 14 2008 sh@suse.de
- Fixed bnc #434042: "Install -devel packages" doesn't work
  with new library package naming scheme
* Mon Oct 13 2008 tgoettlicher@suse.de
- Fixed bnc #434259: Complete quotes for HTML attributes
* Thu Oct  9 2008 sh@suse.de
- Fixed bnc #433914: YQPkgDiskUsageWarningDialog too wide
- V 2.17.11
* Thu Oct  9 2008 sh@suse.de
- Require latest libyui
- V 2.17.13
* Thu Oct  9 2008 sh@suse.de
- Fixed bnc #382202: WM_CLOSE closes window, but leaves y2base
  process running in undefined state
- V 2.17.10
* Thu Oct  9 2008 sh@suse.de
- Prevent segfault when deleting YEventFilters in YDialog dtor
- Prevent segfault in YEventFilter with default args
- V 2.17.13
* Tue Oct  7 2008 sh@suse.de
- Fixed bnc #429030: "Configuration" menu present in installation
- V 2.17.9
* Tue Oct  7 2008 sh@suse.de
- Fixed bnc #421267: Missing newline in exported conflicts list
* Thu Oct  2 2008 sh@suse.de
- Fixed bnc #430392: Typo in error message
* Wed Oct  1 2008 tgoettlicher@suse.de
- Write message to log when client is killed due to X server crash
  bnc #414292
* Wed Oct  1 2008 tgoettlicher@suse.de
- Fixed bnc #418279: export list to text file fails
* Tue Sep 30 2008 sh@suse.de
- Move keyboard focus to default button (if there is one) when
  a dialog opens
* Fri Sep 26 2008 kmachalkova@suse.cz
- Fixed crash in Languages filter: redefined sort function for
  languages so that it does not refer to zypp::ResObjects
  (zypp::Locale isn't one anymore)(bnc#428355)
- V 2.17.8
* Fri Sep 26 2008 tgoettlicher@suse.de
- Fixed bnc #418443: Yast modules windows have no title
- V 2.17.12
* Fri Sep 26 2008 tgoettlicher@suse.de
- Fixed bnc #418443: Yast modules windows have no title
- V 2.17.12
* Wed Sep 24 2008 sh@suse.de
- Require latest libyui (API change!)
- V 2.17.9
* Wed Sep 24 2008 sh@suse.de
- Improved robustness against already-deleted widgets (bnc #421794)
- Require latest libyui
- V 2.17.11
* Wed Sep 24 2008 sh@suse.de
- Improved robustness against already-deleted widgets (bnc #421794)
- V 2.17.11
* Fri Sep 19 2008 sh@suse.de
- Fixed bnc #427370: Segfault in NCFrame called from Python
- Fixed a dozen other similar hazardous pointer uses
- Applied Werner's bce patch (now in SVN) (bnc #423615)
- Fixed bnc #427372: Segfault in empty NCTable
- V 2.17.8
* Wed Sep 17 2008 werner@suse.de
- Add workaround for bce problem, this could be caused by the
  old c++ ncurses interface used in yast2-ncurses (bnc#423615)
* Wed Sep 17 2008 sh@suse.de
- Fixed bnc #399502: Layout for right-to-left languages
- Fixed bnc #396360: Last column in Table widget is too far right
- V 2.17.10
* Wed Sep 17 2008 sh@suse.de
- Fixed reverse layout (for Arabic, Hebrew) in YButtonBox
* Fri Sep 12 2008 sh@suse.de
- Improved resize behaviour of YDialogSpy
* Fri Sep 12 2008 sh@suse.de
- Reduced minimum size of YQTree to reasonable value
* Fri Sep 12 2008 sh@suse.de
- Require latest libyui
- V 2.17.7
* Fri Sep 12 2008 sh@suse.de
- Added widget properties to YDialogSpy
- V 2.17.10
* Fri Sep 12 2008 sh@suse.de
- Now exporting more YWidget base class attributes as properties:
  HWeight, VWeight, HStretch, VStretch
* Fri Sep 12 2008 sh@suse.de
- More graceful "Can't open display" error handling:
  Now probing display before any Qt calls to give clear error msg
- Require latest libyui
- V 2.17.9
* Thu Sep 11 2008 sh@suse.de
- Ask for package licenses, not patch licenses even in online
  update mode
- V 2.17.7
* Thu Sep 11 2008 sh@suse.de
- Require latest libyui
- V 2.17.6
* Thu Sep 11 2008 sh@suse.de
- Added highlighting of currently selected widget in DialogSpy
- Require latest libyui
- V 2.17.8
* Thu Sep 11 2008 sh@suse.de
- Added highlighting for target dialog in YDialogSpy
- V 2.17.9
* Wed Sep 10 2008 sh@suse.de
- Force [Help] button left-aligned in GNOME button order
* Tue Sep  9 2008 sh@suse.de
- Call DialogSpy upon Ctrl-Shift-Alt-Y
  for interactive introspection of the topmost dialog
- V 2.17.7
* Tue Sep  9 2008 sh@suse.de
- Added YDialogSpy for interactive introspection of a widget tree
- V 2.17.8
* Tue Sep  9 2008 sh@suse.de
- Fixed reentrance problems in event handling:
  Moved event handling from YQUI to YQDialog
* Tue Sep  9 2008 sh@suse.de
- Made YEvents more robust against attempts of duplicate deletion
- Stream output (logging) for YEvents
* Fri Sep  5 2008 sh@suse.de
- Fixed bnc #418676: Use title capitalization for groups
* Thu Sep  4 2008 sh@suse.de
- Allow ButtonBox sanity check to be relaxed (bnc #422612)
- V 2.17.7
* Mon Aug 25 2008 tgoettlicher@suse.de
- fate #303458: Simplifiying Software Management
- V 2.17.6
* Fri Aug 22 2008 sh@suse.de
- Check environment variables for button order:
    $DESKTOP_SESSION
    $WINDOWMANAGER
    $Y2_BUTTON_ORDER
- Added command line options (overriding the env vars above):
  - -gnome-button-order
  - -kde-button-order
- V 2.17.6
* Fri Aug 22 2008 sh@suse.de
- Added ButtonBox widget (fate #303446)
- V 2.17.5
* Thu Aug 21 2008 sh@suse.de
- Added YQButtonBox widget (fate #303446)
- Dropped obsolete YFrameBuffer
* Thu Aug 21 2008 sh@suse.de
- Added YButtonBox widget (fate #303446)
- V 2.17.6
* Thu Aug 21 2008 tgoettlicher@suse.de
- Fixed bnc #418606: widgets are not aligned
* Wed Aug 20 2008 gs@suse.de
- Support multi selection in table widget (fate #303492)
  V 2.17.4
* Fri Aug 15 2008 dmacvicar@suse.de
- 2.17.5
- on SLE systems, warn before transaction if it includes
  unsupported software (fate#305057)
  can also be enabled by defining
  YPKG_QT_CONFIRM_UNSUPPORTED_PACKAGES at compile time.
- (fate#120366) search in file list option
* Thu Aug 14 2008 dmacvicar@suse.de
- 2.17.4
- make the versions view scrollable (bnc#409096)
* Wed Aug 13 2008 tgoettlicher@suse.de
- Fixed YQCheckBoxFrame child widget enablement initially wrong (bnc #403126)
* Wed Aug 13 2008 tgoettlicher@suse.de
- Fixed wrong icon when using several wizards (#411579)
* Tue Aug 12 2008 dmacvicar@suse.de
- package list should be sorted locale aware
  (bnc#355255)
* Mon Aug 11 2008 dmacvicar@suse.de
- Fixed bnc#394657 : package selector crashes when
  selecting languages with keyboard
* Thu Aug  7 2008 kkaempf@suse.de
- use rpm macros for Perl and Python directories. Fixes building
  against Python 2.6.
* Wed Aug  6 2008 kmachalkova@suse.cz
- Show "Start repository manager" menu only when requested by
  `opt(`repoMgr) flag i.e. not in installation phase (bnc#381956)
- Added filtering packages by status (bnc#384085)
- Internal changes (YOU help, pkg selector modes)
- 2.17.6
* Tue Aug  5 2008 tgoettlicher@suse.de
- V 2.17.5
* Tue Aug  5 2008 tgoettlicher@suse.de
- Fixed bnc #409612: popup menu during installation becomes
  hidden because of NULL parent
* Tue Jul 29 2008 tgoettlicher@suse.de
- Fixed sorting in Table (bnc #399206)
* Tue Jul 29 2008 tgoettlicher@suse.de
- Fixed bnc #389174: changing packages with keyboard is broken
* Mon Jul 28 2008 tgoettlicher@suse.de
- Fixed case sensitve shortcuts for DumbTab (bnc #411877)
* Wed Jul 23 2008 kmachalkova@suse.cz
- Added pkg search modes (contains, regexp etc.) selection (uses
  zypp::PoolQuery)
- Search view is now default (bnc#404694)
- Reset info text area on switching to/from search filter
* Wed Jul 23 2008 ma@suse.de
- Remove references to obsolete freshens dependencies.
- V 2.17.3
* Wed Jul 23 2008 ma@suse.de
- Remove references to obsolete freshens dependencies.
- 2.17.5
* Mon Jul 21 2008 kmachalkova@suse.cz
- Some look&feel fixes
  * Show locale (language) description
  * Show repository URL in the description area (not in the table)
  * Show how many packages has been found in this search
- Experimental support for patch searching using zypp::PoolQuery
- 2.17.4
* Thu Jul 17 2008 ma@suse.de
- Remove obsolete references to Script/Message/Atom
* Thu Jul 17 2008 ma@suse.de
- Remove obsolete references to Script/Message/Atom
* Wed Jul 16 2008 sh@suse.de
- Added API for fate #303492: Multi selection for table widget
  (just API, not really supporting multi selection yet)
- V 2.17.3
* Tue Jul 15 2008 sh@suse.de
- Implemented fate #303492: Multi selection for table widget
- V 2.17.4
* Tue Jul 15 2008 sh@suse.de
- Implemented fate #303492: Multi selection for table widget
- V 2.17.5
* Mon Jul 14 2008 dmacvicar@suse.de
- feature #302003, show transactions in a better way.
  basically we not only show automatic changes, but
  all changes or only user requested ones.
* Fri Jul 11 2008 sh@suse.de
- Fixed bnc #367023: Keyboard shortcuts for non-ASCII languages
- V 2.17.4
* Fri Jul 11 2008 sh@suse.de
- Fixed bnc #399674: Icons for Auto* actions missing in help
* Fri Jul 11 2008 sh@suse.de
- Fixed bnc #403852: MultiLineEdit doesn't take HTML as plain text
* Wed Jul  9 2008 sh@suse.de
- Fixed bnc #397082: No "[x] View -debugsource packages" menu entry:
  Now toggling -debuginfo and -debugsource simultaneously.
- Added "Install matching -debugsource packages" menu entry
- V 2.17.2
* Tue Jul  8 2008 sh@suse.de
- Enable keyboard shortcuts for YQDumbTab widgets (fate #304890)
- V 2.17.3
* Tue Jul  8 2008 sh@suse.de
- Enable keyboard shortcuts for YDumbTab widgets (fate #304890)
- V 2.17.3
* Tue Jul  8 2008 sh@suse.de
- Fixed massive performance drop when inserting many (3000+)
  YQSelectionBox items
- V 2.17.2
* Thu Jun 26 2008 gs@suse.de
- Improved NCDumbTab widget
  V 2.17.2
* Thu Jun 26 2008 schubi@suse.de
- Added plugin mechanism for displaying grafic solver results.
- V 2.17.1
* Wed Jun 25 2008 kmachalkova@suse.cz
- Focus the button (instead of text area) and make closing the dialog
  possible with single keypress if applicable (bnc#397393)
- Fixed keyboard shortcut (bnc#402349)
- 2.17.3
* Tue Jun 24 2008 gs@suse.de
- NCDumbTab widget is available
* Tue Jun 24 2008 tgoettlicher@suse.de
- prevent that the user deselects all radiobutton items
* Tue Jun 24 2008 sh@suse.de
- Applied bubli's patch for bnc #397393: OK button default focus
* Wed Jun 18 2008 sh@suse.de
- Introduced YEventFilter to improve support for higher-level
  widgets that might send and need to handle internal events
- V 2.17.2
* Tue Jun 17 2008 sh@suse.de
- Fixed bnc #400477: yast2 runlevel takes 40s to switch view
- V 2.17.1
* Wed Jun 11 2008 sh@suse.de
- Introduced YUITerminator to make sure the UI is properly shut
  down in all cases, regardless if called from YCP or plain C++
- V 2.17.1
* Wed Jun 11 2008 kmachalkova@suse.cz
- Use zypp::PoolQuery to filter packages by repositories
- Use zypp::PoolQuery to search in packages
- Search filter: search directly by hitting Enter on search field
- Update label and the description when switching between repositories
  (bnc#397388)
- 2.17.2
* Tue Jun 10 2008 sh@suse.de
- Now using renamed ::setPreferredSize() calls rather than old
  setNiceSize()
- Fixed broken YaST2 logo headers in some source files
- Removed utterly wrong maintainer: ma@suse.de  lines
- V 2.17.1
* Tue Jun 10 2008 sh@suse.de
- Reformatted code according to mandatory YaST2 coding style
- Renamed some ::setNiceSize() methods to ::setPreferredSize()
- V 2.17.1
* Tue Jun 10 2008 gs@suse.de
- Online Update: add preselected patches to the list of
  needed patches
* Thu Jun  5 2008 sh@suse.de
- (coolo) fixed segfault in QY2Styler with secondary wizards during
  installation: bnc #381755, bnc #391856, bug #391947
  (tgoettlicher fixed bnc #397083: help dialog disappears when
  "Help" button is multiple pushed
- V 2.16.54
* Wed Jun  4 2008 gs@suse.de
- Improve dependency popup: show solution details (NCRichText),
  only add NCSpacing if there's enough space
* Wed Jun  4 2008 sh@suse.de
- Added translation marker for "File" menu (bnc #396419)
- V 2.16.48
* Tue Jun  3 2008 tgoettlicher@suse.de
- limited bar width in disk usage list to 100%%
* Thu May 29 2008 sh@suse.de
- Fixed bnc #394525: Proxy settings don't work in installer
- Fixed bnc #379622: CheckBoxFrame( `opt(`invertAutoEnable) )
- V 2.16.53
* Thu May 29 2008 ma@suse.de
- Revert 'fix persistent locks saving (bnc#332853)' because the
  approach is wrong. Persistent locks are saved during commit.
  It's not the UI's task to do this.
- V 2.16.47
* Thu May 29 2008 gs@suse.de
- Show the status of a language pattern and make installation
  possible (bnc #389722)
- 2.16.13
* Wed May 28 2008 kmachalkova@suse.cz
- Do not create pop-up dialogs on the stack (disk space, deps), this
  may lead to segfault (bnc#384471) and/or the latest pop-up being
  always on the top (bnc#384467)
- 2.16.12
* Wed May 28 2008 sh@suse.de
- Fixed bnc #393040: Keyboard shortcuts in main dialogs broken
- V 2.16.52
* Wed May 28 2008 sh@suse.de
- Added YWizard::wizardMode() for bnc #393040
- V 2.16.48
* Wed May 28 2008 sh@suse.de
- Applied Fabien Crespel's patch for repo sorting (bnc #394860)
- V 2.16.46
* Wed May 28 2008 locilka@suse.cz
- New version to follow standard way of submitting YaST packages
  (bnc #394977, bnc #394980, bnc #394504).
- 2.16.45
* Mon May 26 2008 coolo@suse.de
- more font updates from Mike
* Mon May 26 2008 coolo@suse.de
- fix encoding of pattern descriptions
* Mon May 26 2008 dmacvicar@suse.de
- bnc#394504 search kill YaST
* Mon May 26 2008 sh@suse.de
- Fixed bnc #393848: Missing translations in YQWizard help window
- V 2.16.51
* Fri May 23 2008 tgoettlicher@suse.de
- V 2.16.50
* Fri May 23 2008 dmacvicar@suse.de
- if a patch is preselected it will go satisfied
  therefore it will not be shown in the "needed" list.
  Test for patches marked to be installed too.
* Fri May 23 2008 kkaempf@suse.de
- fix widget (pointer) comparison for Perl and Python.
* Wed May 21 2008 dmacvicar@suse.de
- fallback to default icon if no icon is defined in
  a pattern.
* Wed May 21 2008 coolo@suse.de
- fixing theming of pattern selector popups
* Wed May 21 2008 sh@suse.de
- Removed YCP includes
- Removed obsolete testsuite
- Removed yast2-core-devel from BuildRequires in .spec
- V 2.16.28
* Wed May 21 2008 dmacvicar@suse.de
- display the right name for repository list. (bnc#383553)
  patch by Fabien Crespel <fabien@crespel.net>
* Wed May 21 2008 gs@suse.de
- YOU: correct condition for unneeded patches
- 2.16.11
* Tue May 20 2008 kkaempf@suse.de
- Fix requires for perl-yui (bnc#392558)
* Tue May 20 2008 kkaempf@suse.de
- follow naming conventions (bnc#392524). Its now ruby-yui,
  python-yui and perl-yui.
* Tue May 20 2008 gs@suse.de
-  update the pattern status after the initial solver run,
  status for "installed" patterns/patches is ':-)',
  correct help text and action menu for YOU
* Tue May 20 2008 sh@suse.de
- Changed `opt(`warncolor) text color back to black (bnc #384452)
* Mon May 19 2008 dmacvicar@suse.de
- feedback for search (bnc#391406)
- reenable cancel (bnc#350988)
- fix search begins with string (bnc#388601)
- deprecate special selection icons (bnc#392067)
- fix persistent locks saving (bnc#332853)
- 2.16.44
* Mon May 19 2008 tgoettlicher@suse.de
- Fixed bnc #389745: 'Changed Packages' window not centered
* Mon May 19 2008 kkaempf@suse.de
- link against libyui to get all symbols resolved.
  (required to get libyui-bindings work with ncurses)
* Mon May 19 2008 kkaempf@suse.de
- Add examples for Perl and Python
* Mon May 19 2008 dmacvicar@suse.de
- cycle status from autoselected to non-selected instead of
  taboo, as ZYpp supports soft-locks (recommends locks)
  (related to bnc#389739)
* Sat May 17 2008 coolo@suse.de
- fix font handling during installation (bnc#357258)
* Fri May 16 2008 tgoettlicher@suse.de
- Adjust QY2ListView to enable scrolling in wizard (bnc #391048)
* Fri May 16 2008 kkaempf@suse.de
- Also generate Python (libyui-python) and Perl (perl-libyui)
  bindings.
* Fri May 16 2008 tgoettlicher@suse.de
- Fixed YUINoDialogException caused by popup windows
- V 2.16.48
* Thu May 15 2008 sh@suse.de
- Fixed bnc #389744: Missing icons in "symbols help" dialog
- V 2.16.43
* Thu May 15 2008 sh@suse.de
- Moved most XPM icons and YQIconPool to yast2-qt-pkg:
  They are only needed for PackageSelector and related
- V 2.16.47
* Thu May 15 2008 dmacvicar@suse.de
- fix pattern selector unreadable font
  (bnc#381970)
- 2.16.42
* Thu May 15 2008 gs@suse.de
- bugfix for bnc #389761 (correct handling of empty item list in
  NCTree and NCTreePad)
- V 2.16.27
* Thu May 15 2008 tgoettlicher@suse.de
- Fixed focus of popups (#bnc 384905)
* Wed May 14 2008 sh@suse.de
- Fixed bnc #386446: Help button still English
- V 2.16.46
* Wed May 14 2008 tgoettlicher@suse.de
- Improved help popup's usability (bnc #388592)
* Wed May 14 2008 gs@suse.de
- NCDialog internal changes: unneeded logging removed, environment
  variable "Y2NCDBG" restored (was changed to Y2yuiDebug())
* Wed May 14 2008 gs@suse.de
- bugfix for bnc #385872 (don't call YApplication::setLanguage()
  which would overwrite LC_CTYPE),
  correct argument for YNCursesUI::setConsoleFont() (last argument
  is current language not the encoding)
- V 2.16.26
* Tue May 13 2008 dmacvicar@suse.de
- show satisfied non packages as installed selectables
  (bnc#380356)
- 2.16.41
* Tue May 13 2008 kkaempf@suse.de
- Add copyright (gpl 2.0) (bnc#379919)
- Add Ruby examples.
* Tue May 13 2008 tgoettlicher@suse.de
- Fixed setText of YQComboBox (bnc #384713)
* Thu May  8 2008 tgoettlicher@suse.de
- automatically scroll to selected item of YQSelectionBox (bnc #388173)
* Thu May  8 2008 tgoettlicher@suse.de
- fixed strange selection behavior of YQTable (bnc #384658)
* Thu May  8 2008 sh@suse.de
- Don't let Qt override YSelectionBox selection
* Wed May  7 2008 gs@suse.de
- internal changes: remove remainings of old style logging,
  rearrange inclusion of header files
- 2.16.10
* Tue May  6 2008 gs@suse.de
- YOU: filter name for satisfied patches is 'Unneeded' (like qt),
    use enum for patch filters,
- Do the initial solver run before showing the default list
* Mon May  5 2008 kmachalkova@suse.cz
- Improved YOU layout, showing YOU help ( by gs )
- The rest of deprecated libzypp stuff removed (by gs)
- PkgMenuExtras: correct ret. value to fix build (by coolo)
- 2.16.9
* Wed Apr 30 2008 sh@suse.de
- Fixed bnc #379904: More than one radio button checked
- V 2.16.45
* Wed Apr 30 2008 lslezak@suse.cz
- display "Repository" menu only when requested by `opt(`repoMgr)
  option (bnc#381956)
- V 2.16.40
* Wed Apr 30 2008 lslezak@suse.cz
- added repoMgrEnabled() method to YPackageSelector widget
  (repository management is now optional) (bnc#381956)
- V 2.16.47
* Tue Apr 29 2008 sh@suse.de
- Fixed bnc #383672 - Busy cursor in file dialogs
- V 2.16.44
* Mon Apr 28 2008 kmachalkova@suse.cz
- Locale (prev. Language) support + displaying locale-related pkgs
  re-enabled
- Correctly replace filter description area when switching between
  filters (bnc#377857)
- 2.16.8
* Mon Apr 28 2008 dmacvicar@suse.de
- Make transactions concept better visible: use new
  set of icons from jimmac
  (feature #302003)
- 2.16.43
* Sat Apr 26 2008 coolo@suse.de
- resubmit clean tar
* Fri Apr 25 2008 dmacvicar@suse.de
- make rpm groups view use packagekit groups
  with nice icons. Get rid of useless tree
- add list of suggested and recommended packages
  (fate #302039)
- ported search to sat solver search (much faster)
  and implemented (fate #120368) to search for keywords
  enabled by default.
- 2.16.39
* Thu Apr 24 2008 kmachalkova@suse.cz
- Make YQWizard menus work again  - Qt4 uses triggered() signal
  instead of activated() (bnc#367796)
- V 2.16.42
* Wed Apr 23 2008 sh@suse.de
- Fixed segfault when discarding events from foreign dialogs
  (bnc #382771)
- V 2.16.46
* Mon Apr 21 2008 dmacvicar@suse.de
- apply language selections after clicking
  (bnc #381994)
- 2.16.38
* Mon Apr 21 2008 kmachalkova@suse.cz
- Pattern content (required, recommended, suggested pkgs) visible
  again
- Show no. of installed vs. total pkgs for a pattern
- 2.16.7
* Mon Apr 21 2008 jsrain@suse.cz
- fixed textdomain
* Mon Apr 21 2008 jsrain@suse.cz
- added missing textdomain
* Fri Apr 18 2008 sh@suse.de
- Fixed bnc #374851: YQMultiProgressMeter integer overflow
* Fri Apr 18 2008 dmacvicar@suse.de
- make versions widget work (bnc #354983)
- show updates in blue again (bnc #371681)
- allow disabling view of debuginfo and devel pkgs
  (bnc #359155)
- 2.16.37
* Thu Apr 17 2008 dmacvicar@suse.de
- don't reorder patterns when clicking
- enable tooltip for repositories and patterns
* Thu Apr 17 2008 dmacvicar@suse.de
- fix space used when resizing
* Thu Apr 17 2008 coolo@suse.de
- update the steps status (bnc#379539)
* Wed Apr 16 2008 dmacvicar@suse.de
- don't crash using keyboard on languages filter
- 2.16.36
* Wed Apr 16 2008 coolo@suse.de
- "unexcel" package management
- 2.16.35
* Wed Apr 16 2008 coolo@suse.de
- reduce steps flickering
- V 2.16.41
* Wed Apr 16 2008 sh@suse.de
- Deleting events is now automatically handled by YDialog.
  Simply remove all "delete event" calls.
- Introduced uiThreadDestructor() (bnc #346987)
- V 2.16.45
* Tue Apr 15 2008 coolo@suse.de
- fix wizards in wizards
- V 2.16.40
* Tue Apr 15 2008 tgoettlicher@suse.de
- fix dependencies (bnc #377586)
- 2.16.34
* Mon Apr 14 2008 sh@suse.de
- Added new UI capability YQApplication::hasWizardDialogSupport()
- V 2.16.39
* Mon Apr 14 2008 sh@suse.de
- Added dialog type YWizardDialog for main dialogs that will
  contain a wizard (equivalent to YMainDialog if
  YApplication::hasWizardDialogSupport() returns false)
- V 2.16.44
* Mon Apr 14 2008 dmacvicar@suse.de
- don't crash with language right click (bnc #370233)
- show language content
- 2.16.33
* Mon Apr 14 2008 kkaempf@suse.de
- Extended, now sufficient for selection_box1.
* Sun Apr 13 2008 coolo@suse.de
- use only working area on seconday wizards
- V 2.16.38
* Sat Apr 12 2008 coolo@suse.de
- adapt to latest libzypp
* Sat Apr 12 2008 coolo@suse.de
- compile with latest ncurses
- V 2.16.24
* Fri Apr 11 2008 sh@suse.de
- Reverted sub-wizard changes - seems to be a dead end
- V 2.16.37
* Fri Apr 11 2008 sh@suse.de
- Reverted last changes - sub-wizards seem to be a dead end
- V 2.16.43
* Fri Apr 11 2008 kkaempf@suse.de
- Initial version, just enough for 'Hello, world!'
* Thu Apr 10 2008 sh@suse.de
- Added basic support for docked sub-wizards
* Thu Apr 10 2008 sh@suse.de
- Added support for docked sub-wizards
- V 2.16.42
* Wed Apr  9 2008 sh@suse.de
- Fixed bnc #372910: License windows shows in left top
* Wed Apr  9 2008 dmacvicar@suse.de
- fix patch and pattern content
* Wed Apr  9 2008 dmacvicar@suse.de
- fix pattern view display (only missing head font)
* Tue Apr  8 2008 dmacvicar@suse.de
- fixed some Selectable changes
- 2.16.32
* Fri Apr  4 2008 sh@suse.de
- Fixed segfault from overly optimistic assumption that the NCurses UI
  always just runs as a part of YaST2
- V 2.16.22
* Fri Apr  4 2008 sh@suse.de
- Fixed typo widht => width in various function names
- V 2.16.23
* Fri Apr  4 2008 tgoettlicher@suse.de
- fixed frame style of rich text widget (bnc #369685)
* Fri Apr  4 2008 schubi@suse.de
- Fixed ResStatus (needed, satisfied,...)
- 2.16.31
* Thu Apr  3 2008 coolo@suse.de
- adapt to latest libzypp
* Thu Apr  3 2008 dmacvicar@suse.de
- Add unmantained packages filter (fate ##302004)
- 2.16.30
* Thu Apr  3 2008 sh@suse.de
- Build-require latest libyui
- V 2.16.21
* Thu Apr  3 2008 sh@suse.de
- Build-Require latest libyui
- V 2.16.33
* Thu Apr  3 2008 sh@suse.de
- Added YPushButton::setHelpButton() and isHelpButton()
- Automatically show topmost YWidget::helpText() when a help button
  is activated
- V 2.16.41
* Wed Apr  2 2008 tgoettlicher@suse.de
- fixed table widget sorting  (bnc #376046)
* Tue Apr  1 2008 tgoettlicher@suse.de
- Scoll licence dialogs to top (bnc #373910)
* Tue Apr  1 2008 sh@suse.de
- Added "HelpText" property to YWidget for easier support of
  YCP wizard layouts without permanent help panel (fate #303291)
* Tue Apr  1 2008 tgoettlicher@suse.de
- fixed keyboard shortcuts in popup menu (bnc #377098)
- V 2.16.25
* Tue Apr  1 2008 jsrain@suse.cz
- fixed textdomain
* Mon Mar 31 2008 kmachalkova@suse.cz
- Launch repository manager from the menu (Extras) - return `repo_mgr
  symbol from the main `PackageSelector UI loop (FaTE #302517)
- 2.16.6
* Mon Mar 31 2008 tgoettlicher@suse.de
- fixed sort by column for table widget  (bnc #374679)
* Mon Mar 31 2008 tgoettlicher@suse.de
- fixed right and center for table widget (bnc #357693)
* Thu Mar 27 2008 kmachalkova@suse.cz
- UI refactoring branch merged back to trunk
- 2.16.5
* Tue Mar 25 2008 coolo@suse.de
- adapt to libzypp 4.6
- V 2.16.4
* Tue Mar 25 2008 sh@suse.de
- Changed textdomain from "packages-qt" to "qt-pkg" for consistency
* Tue Mar 25 2008 jsrain@suse.cz
- changed textdomain to "qt"
* Thu Mar 20 2008 sh@suse.de
- Added standard file logger (when used independently of YaST2)
- V 2.16.40
* Wed Mar 19 2008 coolo@suse.de
- fix YTable performance (bnc #372316)
* Wed Mar 19 2008 dmacvicar@suse.de
- fix taking screenshots (bnc #361995)
* Wed Mar 19 2008 coolo@suse.de
- fix build against libzypp 4.5
* Tue Mar 18 2008 dmacvicar@suse.de
- make autodeps checkbox and button clickable (bnc #355268)
- make the @System repo show installed packages
  as expected (bnc #370228)
- don't add space between menu bar and the rest
  when resizing (bnc #370231)
* Fri Mar 14 2008 lslezak@suse.cz
- added a new menu entry for starting the repository manager
  (fate#302517)
- V 2.16.28
* Thu Mar 13 2008 sh@suse.de
- Fixed bug #370244: Menu entries about source RPMs
  Moved out all source RPM related menu entries:
  libzypp has no support whatsoever for source RPMs
* Thu Mar 13 2008 kmachalkova@suse.cz
- Set combobox text-area size so it matches the length of its longest
  item (qt&gtk compatibility - bnc#367083)
- 2.16.20
* Tue Mar 11 2008 sh@suse.de
- Fixed bnc #358522: query CurrentItem for DumbTab is broken
* Mon Mar 10 2008 sh@suse.de
- Implemented bnc #364887: Hotkey to dump widget tree
  (It's now Ctrl-Shift-Alt-T)
* Fri Mar  7 2008 sh@suse.de
- Fixed bnc #357607: OpenItems property of Tree widget is broken
- V 2.16.19
* Fri Mar  7 2008 sh@suse.de
- Fixed bnc #357607: OpenItems property of Tree widget is broken
- V 2.16.33
* Thu Mar  6 2008 sh@suse.de
- Fixed bnc #357620: Setting current item broken for tree and table
* Wed Mar  5 2008 sh@suse.de
- Fixed bnc #365999: Shift-F7 affects only UI logging
- V 2.16.39
* Tue Mar  4 2008 sh@suse.de
- Fixed segfault if SelectionBox value is set to nil (bnc #363251)
- Fixed segfault if user clicks in empty area of a SelectionBox
- V 2.16.32
* Tue Mar  4 2008 sh@suse.de
- Conflict with yast2-core < 2.16.38 (before pkg split)
* Fri Feb 29 2008 kmachalkova@suse.cz
- Workaround for missing arrow characters in xterm - use WACS_*ARROW
  (wide version of ACS_*ARROW) in UTF-8 locale (bnc#362634)
- 2.16.18
* Thu Feb 28 2008 kmachalkova@suse.cz
- Enhancement: show module name in window title
  (e.g. YaST - http-server @ host)
* Wed Feb 27 2008 coolo@suse.de
- buildrequire ycp bindings
* Wed Feb 27 2008 sh@suse.de
- Removed obsolete Unicode fonts (now in separate pkg gnu-unifonts)
- V 2.16.31
* Wed Feb 27 2008 coolo@suse.de
- fix build on %%_lib == lib64
* Wed Feb 27 2008 coolo@suse.de
- fix package build
* Wed Feb 27 2008 coolo@suse.de
- adding a require to the devel package
* Wed Feb 27 2008 coolo@suse.de
- fix build without ycp
* Tue Feb 26 2008 sh@suse.de
- Use new cmake support from libyui
- No longer depend on yast2-core etc. for cmake
- V 2.16.30
* Tue Feb 26 2008 sh@suse.de
- Added cmake support for dependent packages
- V 2.16.38
* Tue Feb 26 2008 coolo@suse.de
- fix build without ycp
- hopefully fix popups for real
- fix -auto-fonts
- V 2.16.29
* Mon Feb 25 2008 kmachalkova@suse.cz
- If package selector plugin fails to load, do not fail silently,
  throw YUIPluginException (bnc#363958)
- 2.16.17
* Mon Feb 25 2008 sh@suse.de
- Don't just call exit(1) if there is no qt_pkg plug-in (bnc #363958)
* Mon Feb 25 2008 sh@suse.de
- Added copy of GPL licensing terms (COPYING) (bnc #362646)
- V 2.16.27
* Mon Feb 25 2008 sh@suse.de
- Provide yast2_ui_pkg in .spec file (bnc #363958)
- V 2.16.3
* Mon Feb 25 2008 sh@suse.de
- Provide yast2_ui_pkg in .spec file (bnc #363958)
- V 2.16.26
* Thu Feb 21 2008 sh@suse.de
- Package split off from yast2-core
- V 2.16.37
* Thu Feb 21 2008 coolo@suse.de
- fix slider layout (bnc#363395)
- V 2.16.28
* Wed Feb 20 2008 coolo@suse.de
- remove self made logging, use UI
* Wed Feb 20 2008 sh@suse.de
- Use and accept `opt(`immediate) for tree widget
* Mon Feb 18 2008 sh@suse.de
- NCurses UI no longer depends on libycp or liby2 (Y2Component...)
- V 2.16.16
* Mon Feb 18 2008 sh@suse.de
- Qt-UI now no longer depends on libycp or liby2 (Y2Component...)
- V 2.16.27
* Sat Feb 16 2008 coolo@suse.de
- fix filelist of devel
* Fri Feb 15 2008 coolo@suse.de
- compile against libzypp trunk - language support pending
  (#ifed out - want to make sure it works before we spend
  too much time into it)
* Fri Feb 15 2008 kmachalkova@suse.cz
- Old-style logging replaced by yui logging (sh)
- Removed obsolete YCP stuff (sh)
- yast2-ncurses-pkg and yast2-ncurses-devel split off the main
  package (*-devel is built from the same specfile, *-pkg has
  a package of its own)
- 2.16.15
* Fri Feb 15 2008 coolo@suse.de
- split out yast2-qt-pkg
* Thu Feb 14 2008 coolo@suse.de
- split off the package manager off yast2-qt
* Tue Feb 12 2008 kmachalkova@suse.cz
-  Initial version splitted from yast2-ncurses 2.16.15
-  2.16.0
* Fri Feb  8 2008 tgoettlicher@suse.de
- Made popup dialogs modal
* Fri Feb  8 2008 tgoettlicher@suse.de
- Changed time format in TimeField to yyyy-mm-dd (bnc #359630)
- V 2.16.25
* Tue Feb  5 2008 sh@suse.de
  * Macro recording and playing ins now unified and moved out of the YUI class.
  Use the static functions in the new YMacro class instead now:
  - YMacro::record()
  - YMacro::play()
  ...
  * Moved productName() and setProductName() from YUI to YApplication
* Mon Feb  4 2008 tgoettlicher@suse.de
- Adapted askForSaveFilename to qt4 api (bnc #357998)
- V 2.16.24
* Mon Feb  4 2008 tgoettlicher@suse.de
- Fixed Bug #340898: Selecting specific repository out of sync
- V 2.16.23
* Fri Feb  1 2008 sh@suse.de
- Moved event handling from YUI / YNCursesUI to YDialog / NCDialog
- V 2.16.14
* Fri Feb  1 2008 sh@suse.de
- Moved event handling from Y(Q)UI to Y(Q)Dialog
- V 2.16.22
* Fri Feb  1 2008 tgoettlicher@suse.de
- Run solver on startup of PackageManager in online update mode
  (bug #340898)
- V 2.16.21
* Fri Feb  1 2008 coolo@suse.de
- fix file list
* Thu Jan 31 2008 sh@suse.de
  * Moved event handling from YUI to YDialog:
  - removed YUI::userInput()
  - removed YUI::pollInput()
  - Derived classes now have to implement:
  - YDialog::waitForEventInternal()
  - YDialog::pollEventInternal()
* Thu Jan 31 2008 sh@suse.de
- Simplified dialog handling
- V 2.16.13
* Thu Jan 31 2008 sh@suse.de
- Simplified dialog handling
- V 2.16.20
* Thu Jan 31 2008 kmachalkova@suse.cz
- Align numbers in IntFields to the right margin of the label, not
  to the right margin of the entire screen (bnc#309118)
* Wed Jan 30 2008 sh@suse.de
  * Moved dialog handling from YUI to YDialog:
  - removed YUI::showDialog()
  - removed YUI::closeDialog()
  - Now using YDialog::open() and YDialog::destroy()
  - Derived classes now have to implement:
  - YDialog::openInternal()
  - YDialog::activate()
* Wed Jan 30 2008 coolo@suse.de
- recreate tar to fix build
* Tue Jan 29 2008 sh@suse.de
- YCP-less event handling
- V 2.16.12
* Tue Jan 29 2008 sh@suse.de
- YCP-less event handling
- V 2.16.19
* Tue Jan 29 2008 kmachalkova@suse.cz
- Delete any leftover dialogs (popups, menus) on exit from package
  selector (bnc#354712)
- Moved BusyIndicator widget handling to idleLoop, do not use signals
  as they may freeze yast (libncurses and malloc are not signal-safe)
  (bnc#355562)
- 2.16.11
* Mon Jan 28 2008 sh@suse.de
  * Moved YCP part out of YEvent to new class YCPEvent
  * YUI::runPkgSelection() now returns YEvent * and is pure virtual
* Thu Jan 24 2008 sh@suse.de
  * UI::OpenDialog() now opens error dialog in case of exception
  (using the new mod-ui calls, works for all UIs)
  * UI::UserInput() now opens error dialog in case of exception
  (using the new mod-ui calls, works for all UIs)
* Wed Jan 23 2008 sh@suse.de
- Use new YCP-less logging (part 1)
- V 2.16.18
* Sat Jan 19 2008 sh@suse.de
  * Moved glyph handling from YUI to YApplication,
  now using std::string instead of YCPString and YCPSymbol;
  forget YMyUI::glyph(), implement YMyApplication::glyph()
* Fri Jan 18 2008 kmachalkova@suse.cz
- Running separate UI-thread re-enabled (adjusted idleLoop, file
  descriptor saving/restoring) (bug #164999, FaTE #301899)
- 2.16.10
* Wed Jan 16 2008 tgoettlicher@suse.de
- Added BusyIndicator widget
- 2.16.9
* Wed Jan 16 2008 coolo@suse.de
- disable patch again now that yast2-core is ready
* Tue Jan 15 2008 kmachalkova@suse.cz
- 'Press F1 for Help' in window title is gone
- No Fxx keys help pop-up (all the information moved to the bottom
  status line)
- Fxx key labels rendered in reversed colours
- Improved dependency conflict popup layout (Label (`opt(`outputField
  instead of TextEntry, spacing re-arrangements) (#350238)
* Mon Jan 14 2008 coolo@suse.de
- make it build without new yast2-core to get the pkg fixes
* Mon Jan 14 2008 tgoettlicher@suse.de
- V 2.16.17
* Fri Jan 11 2008 tgoettlicher@suse.de
- BusyIndicator facelift
- V 2.16.16
* Thu Jan 10 2008 tgoettlicher@suse.de
- added BusyIndicator widget (fate #302559)
- V 2.16.15
* Thu Jan 10 2008 coolo@suse.de
- find a brute force way to make patterns selectable
- V 2.16.14
* Wed Jan  9 2008 sh@suse.de
- V 2.16.13
* Mon Jan  7 2008 kmachalkova@suse.cz
- Status line support added ( all quick access Fxx keys are now
  shown in the bottom status line ), help popup not removed yet
- Fixed adding and indexing of combo-box items (#346862 related)
- 2.16.8
* Sat Dec 29 2007 coolo@suse.de
- some fixes in the package selector
* Fri Dec 21 2007 coolo@suse.de
- support `CurrentItem in timezone widget
- fix combobox semantic
- V 2.16.12
* Wed Dec 19 2007 coolo@suse.de
- give the help popup a search function
- support non-padding widgets for backgrounds
- V 2.16.11
* Wed Dec 19 2007 coolo@suse.de
- fix file list
* Tue Dec 18 2007 coolo@suse.de
- implement timezone widget
- moved theming to theme package
- V 2.16.10
* Mon Dec 17 2007 kmachalkova@suse.cz
- Reworked repositories filter: added pref. width/height methods,
  adding items adapted to new NCTable, treat RepoTag as dummy table cell
- Set dialog's default button in showDialog() routine (no further
  magic, 'last one wins' approach)
- Adding table items modified so that it does not use static indexing
  - exchanging table content (`Items) then misbehaves (#343870)
- Fixed displaying of visited RichText hyperlinks in rxvt theme
- 2.16.7
* Wed Dec 12 2007 coolo@suse.de
- merged yast2-qt4 into yast2-qt
- V 2.16.9
* Tue Dec 11 2007 sh@suse.de
- Fixed bug #346129: Too many wizard steps if UTF-8 chars used
* Mon Dec 10 2007 sh@suse.de
  Moved file and directory dialogs from NCursesUI to NCApplication:
  - askForExistingDirectory()
  - askForExistingFile()
  - askForSaveFile()
- Added requires and buildRequires for yast2-core-2.16.15 to .spec
- 2.16.6
* Mon Dec 10 2007 sh@suse.de
- Moved file and directory dialogs from YQUI to YQApplication:
  - askForExistingDirectory()
  - askForExistingFile()
  - askForSaveFile()
- V 2.16.8
* Sun Dec  9 2007 sh@suse.d
  * Moved file and directory dialogs from YUI to YApplication:
  - askForExistingDirectory()
  - askForExistingFile()
  - askForSaveFile()
  * Parameters and return values now all std::string
  * Now return empty string upon user cancel
* Wed Dec  5 2007 sh@suse.de
- Moved main dialog handling out of YQUI and into a new class
  YQMainWinDock
- Don't proactively grab keyboard focus any longer (bug #246934)
- V 2.16.7
* Wed Dec  5 2007 tgoettlicher@suse.de
- Changed conflict dialog to better fit to sat solver's output
* Tue Dec  4 2007 kmachalkova@suse.cz
- Removed reference to printing license text (#327542)
- Set dialog's default button correctly
- 2.16.5
* Tue Dec  4 2007 tgoettlicher@suse.de
- Fixed popup windows without decorations (#345825)
* Mon Dec  3 2007 kmachalkova@suse.cz
- Further changes to package selector (gs)
- NCDialog adapted to new YDialog (sh)
- Correct setValue for CheckBox (do not forget to redraw)
- Do not set focus to default button each time dialog layout is
  recalculated (#343870)
- 2.16.4
* Fri Nov 30 2007 sh@suse.de
- Migrated YQDialog to mod-ui
- V 2.16.6
* Thu Nov 29 2007 sh@suse.de
  * Migrated YDialog
  * Removed YContainerWidget for good
  * Removed legacy YWidget::queryWidget() and YWidget::changeWidget() methods
  * Dropped support for outdated property handling with old
  YWidget::queryWidget() and YWidget::changeWidget() methods
  * Dropped support for outdated YWidget( YWidgetOpt ) constructors
  * Removed unneeded YWidgetOpt fields
  * Added basic default button handling to YDialog and YPushButton
* Tue Nov 27 2007 sh@suse.de
- Moved all YCP related code out of YQWizard
- V 2.16.5
* Tue Nov 27 2007 tgoettlicher@suse.de
- V 2.16.4
* Mon Nov 26 2007 sh@suse.de
  * Migrated YWizard
  * Moved WizardCommand parsing out to YCPWizardCommandParser
  * Added lots of pure virtual functions to YWizard
  * All YCPValue and other YCP related code can now be removed from
    YWizard-derived classes
* Mon Nov 26 2007 kmachalkova@suse.cz
- First version of YCP-less package selector (gs)
- Fixed includes (FSize.h and YRpmGroupsTree.h now in libyui) (sh)
- Delete any leftover dialogs in YNCursesUI destructor
- Require new yast2-core
- 2.16.3
* Mon Nov 26 2007 tgoettlicher@suse.de
- Prevent changed size of partition widget when packageselector's
  window size is changed
* Mon Nov 26 2007 mvidner@suse.cz
- Added missing mode for open(O_CREAT) fixing compilation with glibc-2.7.
* Fri Nov 23 2007 tgoettlicher@suse.de
- fixed unneeded help icon in "please wait" window (#202818)
* Thu Nov 22 2007 sh@suse.de
- Moved setLanguage() and font handling from YQUI to YQApplication
* Thu Nov 22 2007 sh@suse.de
- Moved setLanguage() from YUI to YApplication
* Tue Nov 20 2007 sh@suse.de
- Prevent self-generated events in YQDumbTab
- Fixed cut-off YQInputField labels
- V 2.16.3
* Mon Nov 19 2007 kmachalkova@suse.cz
- Unified terminology: repositories vs. inst.sources (FaTE #302970)
* Mon Nov 19 2007 tgoettlicher@suse.de
- fixed ignored arch selection in package selector (#304966)
- V 2.16.2
* Fri Nov 16 2007 kmachalkova@suse.cz
- The Great Merge [tm] - merged mod-ui branch into the trunk
- 2.16.2
* Fri Nov 16 2007 sh@suse.de
- Merged mod-ui branch to trunk
- V 2.16.1
* Tue Nov 13 2007 sh@suse.de
  * Migrated YDumbTab
  * YDumbTab now inherits YSelectionWidget
* Sun Nov 11 2007 sh@suse.de
  * Enforced creating YWidget and derived classes with new (on the heap)
  * Ported YDownloadProgress
* Thu Nov  8 2007 sh@suse.de
  * Ported YBarGraph
  * Ported YPartitionSplitter
* Mon Nov  5 2007 sh@suse.de
  * Ported default function key handling
* Tue Oct 30 2007 sh@suse.de
  * Renamed YTime -> YTimeField
  * Renamed YDate -> YDateField
  * Ported YTimeField
  * Ported YDateField
* Tue Oct 30 2007 kmachalkova@suse.cz
- Explicitely set foreground (font) color to white for rxvt theme
  (do not display black font on black background) (#336060)
- 2.16.1
* Mon Oct 29 2007 sh@suse.de
  * Moved opaque 'data' void pointer from YTreeItem / YTableItem
  to YItem base class
* Thu Oct 25 2007 sh@suse.de
  * Changed YTable header handling (bubli's request):
  - Constructor now gets YTableHeader object
  - no more setHeader() and setAlignment functions - get rid of them
  - use columns(), header(), alignment() in the constructor to set up columns
* Tue Oct 23 2007 kmachalkova@suse.cz
- Added missing includes to compile with gcc 4.3
- Removed sources of gcc 4.3 operator priority warnings
- 2.16.0
* Wed Oct 10 2007 sh@suse.de
  * Ported MenuButton
  - Now derived from YSelectionWidget
  - Added support for replacing (all!) items
  - QueryWidget can now return the complete item term
  - Added support for icons in menu entries
  - Added YMenuEvent( YMenuEntry * ) constructor
  - Derived classes can use YMenuItem::index() as a unique ID
    or use YMenuItem::data() and YMenuItem::setData() to store
    a custom pointer to some other class.
  Look at YQMenuButton for a sample implementation.
* Tue Oct  9 2007 sh@suse.de
  * Ported LogView
* Mon Oct  8 2007 sh@suse.de
  * Added support for QueryWidget(`id(...), `Items ) for SelectionWidgets:
  - SelectionBox
  - ComboBox
  - MultiSelectionBox
  - Tree
  - Table
  * Ported IntField
* Fri Oct  5 2007 sh@suse.de
  * Ported Table
  - now based on SelectionWidget
  - much streamlined with the other selection widgets
  - QueryWidget can now return the complete item term
    as well as individual cells
  Look at YQTable for a sample implementation.
* Fri Sep  7 2007 kmachalkova@suse.cz
- Display install notify message only if package is marked for
  installation, disregard update (#308410)
- 2.15.27
* Mon Sep  3 2007 sh@suse.de
- Limit pkg popups to screen size even with substandard resolutions
  (bug #300632: dialogs too big on PS3)
- V 2.15.16
* Wed Aug 29 2007 tgoettlicher@suse.de
- wizard shows titlebar depending on existence of title-bar-gradient.png
- r40568
- V 2.15.15
* Mon Aug 27 2007 sh@suse.de
- Fixed bug #297637: Repository names not shown in Package Manager
- V 2.15.14
* Fri Aug 24 2007 kmachalkova@suse.cz
- Smaller (vertical) default size of MultiLineEdit widget (partly
  [#292282])
- Redirecting stdout/stderr to log is now separate function
- 2.15.26
* Thu Aug 23 2007 kmachalkova@suse.cz
- Display repository name instead of product name in package selector
  (#296782)
* Wed Aug 22 2007 kmachalkova@suse.cz
- Correct setValue for CheckBoxFrame (added missing Redraw() call)
  (#301370)
- Display repository name instead of product name in package
  selector (#296782)
- 2.15.25
* Wed Aug 15 2007 jsuchome@suse.cz
- Messages back from proofreading
- 2.15.12
* Wed Aug 15 2007 jsuchome@suse.cz
- messages from proofread merged back
- 2.15.24
* Fri Aug 10 2007 mvidner@suse.cz
- Finished integrating Feature #120292, UI as a namespace callable
  from yast2-*-bindings.
- 2.15.11
* Fri Aug 10 2007 mvidner@suse.cz
- Finished integrating Feature #120292, UI as a namespace callable
  from yast2-*-bindings.
- 2.15.23
* Fri Aug 10 2007 kmachalkova@suse.cz
- Removed redefinition of '<<' DiskUsageCounter operator, it is now
  defined directly in libzypp
* Wed Aug  8 2007 kmachalkova@suse.cz
- Added text referring to whereabouts of the license text to
  license agreement popup (FaTE #302018)
- V 2.15.10
* Mon Aug  6 2007 kmachalkova@suse.cz
- Added text referring to whereabouts of the license text to lic.
  agreement popup (FaTE #302018)
- Show Filter: <product summary> after filling the repository list
  - by gs
- 2.15.22
* Mon Aug  6 2007 mvidner@suse.cz
- Adapted to changes in yast2-core needed for making UI callable from
  yast2-*-bindings.
- 2.15.21.1
* Mon Aug  6 2007 mvidner@suse.cz
- Adapted to changes in yast2-core needed for making UI callable from
  yast2-*-bindings.
- 2.15.7.1
* Fri Aug  3 2007 sh@suse.de
- Fixed bug #295485: Text cut off in MultiSelectionBox
  (in repository names in that bug)
- Fixed bug #189267: Unlocalized text in online update
- V 2.17.9
* Thu Aug  2 2007 sh@suse.de
- V 2.17.8
- Fate #302052: Restrict patches view to show only update stack
  patches if there are any
* Tue Jul 24 2007 sh@suse.de
- Fixed bug #285915: Can't cancel package search
- Consistent naming scheme: inst source -> repository
* Thu Jul 19 2007 kmachalkova@suse.cz
- Make repositories list popup work (FaTE #301810 - part II) -
  show repositories (and their products), show packages for selected
  repository
- Added dejagnu to BuildRequires (needed to run testsuite during pkg
  build)
- Changed kbd shortcut to prevent duplicates (bug #289771) - by gs
- 2.15.21
* Tue Jul 17 2007 kmachalkova@suse.cz
- Require new libzypp (>= 3.11.8)
- Changes from libzypp refactoring branches merges back to trunk
* Tue Jul 17 2007 kmachalkova@suse.cz
- Require new libzypp (>= 3.11.8)
- Correct svn merge from refactoring branch
* Mon Jul 16 2007 mvidner@suse.cz
- fixed changelog duplicates
* Mon Jul 16 2007 kmachalkova@suse.cz
- Added repositories list popup (FaTE #301810 - part II) - does
  not do anything useful yet
* Fri Jul 13 2007 sh@suse.de
  * Ported MultiProgressMeter
  - now using float values internally to safeguard against huge numbers
* Tue Jul 10 2007 sh@suse.de
- Don't over-simplify whitespace (replacing newlines with blanks)
  in dependency problem reports
- V 2.15.7
* Fri Jul  6 2007 sh@suse.de
  * Ported YTree
* Fri Jul  6 2007 ma@suse.de
- Adapt to new libzypp. Installation sources were replaced by
  repositories.
- V 2.15.6
* Wed Jul  4 2007 gs@suse.de
- adapted to libzypp-3.10
- 2.15.20
* Tue Jul  3 2007 sh@suse.de
  * Ported YMultiLineEdit
  - renamed text()    -> value()
  - renamed setText() -> setValue()
  - new: YMultiLineEdit::defaultVisibleLines() (use this in preferredHeight() )
  * Ported YProgressBar
  - renamed setProgress() -> setValue()
* Mon Jul  2 2007 sh@suse.de
  * Ported simple YSelectionWidgets (major rewrite):
  - YSelectionBox
  - YComboBox
  - YMultiSelectionBox
  Most (almost all?) of the selection handling went to the YSelectionWidget
  base class. The concrete UI implementations have to implement 2 pure virtual
  functions each - see the respective header files. See the YQ sample
  implementations for more details.
  * YComboBox now also supports icons.
* Fri Jun 29 2007 sh@suse.de
  * Added YSelectionBox::immediateMode() and setImmediateMode()
  as a replacement for YWidgetOpt.immediateMode
  * Added YSelectionBox::shrinkable() and setShrinkable()
  as a replacement for YWidgetOpt.shrinkable
* Wed Jun 27 2007 sh@suse.de
  * YPackageSelector:
  * added modeFlags parameter (summarizing all the YWidgetOpts)
  * added mode checking functions:
  - bool testMode()
  - bool onlineUpdateMode()
  - bool updateMode()
  - ...
  * Dropped long-obsolete floppyDevice parameter
  * YPackageSelectorPlugin:
  * added modeFlags parameter
  * Factories:
  * added modeFlags parameter for PackageSelector etc.
  * now calling the YPackagePlugin from the factory create...() functions
* Wed Jun 27 2007 sh@suse.de
  * YImage:
  * Dropped support for creating an image from a YCPByteblock
  * Dropped support for fallback label (was never used in NCurses anyway)
  * Dropped support for `opt(`tiled)
  * Moved YWidgetOpt stuff to YImage methods
* Tue Jun 26 2007 sh@suse.de
  * Renamed YWidget::getNotify() -> YWidget::notify()
  Replace with:
  perl -p -i -e 's/getNotify/notify/g' *.cc pkg/*.c
  * Added function key methods for NCurses F-key support:
  - YWidget::functionKey()
  - YWidget::hasFunctionKey()
  - virtual YWidget::setFunctionKey
  Since YWidgetOpt is no longer passed to constructors, NCurses should use
  those new functions instead.
  YWidget::setFunctionKey() is called from YCPDialogParser after the widget is
  created, so either use the new function in the keyboard handlers or overwrite
  YWidget::setFunctionKey().
  * YCheckBox:
  - getValue() -> value()
  - no longer just boolean values, now using YCheckBoxState enum: _on, _off, _dont_care
  - YCheckBox constructor doesn't accept an initiallyChecked value any more
    (but derived classes should so the widgetFactory can pass it on easily)
* Mon Jun 25 2007 sh@suse.de
  * Renamed YTextEntry -> YInputField
  For YCP, TextEntry is (and will remain) still a valid widget name.
  `InputField is the new default name, though.
* Mon Jun 25 2007 sh@suse.de
  * changed nicesize() to preferredWidth() and preferredHeight(), both returning int, not long
  see longer explanations on top
  * virtual YWidget::setSize() now has int params, no longer long
  see longer explanations on top
* Fri Jun 22 2007 sh@suse.de
  * added pure virtual YWidgetFactory::createSpacing()
  Removed from derived factories:
  - YWidgetFactory::createHStretch() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createVStretch() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createHSpacing() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createVSpacing() is no longer virtual and now returns a YSpacing
  * Droppped HVStretch widget
* Thu Jun 21 2007 sh@suse.de
  * Dropped YColoredLabel
  * Moved widget term parsing stuff to separate class YCPDialogParser
  * YUI::widgetWithId() is now YCPDialogParser::findWidgetWithId()
  !!! the default for throwing exceptions is now reverted: It now throws by default!
  - >  YUI::widgetWithId( someId, true )  -> YCPDialogParser::findWidgetWithId( someId )
  - >  YUI::widgetWithId( someId )        -> YCPDialogParser::findWidgetWithId( someId, false )
  - >  YUI::widgetWithId( someId, false ) -> YCPDialogParser::findWidgetWithId( someId, false )
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Thu Jun 21 2007 sh@suse.de
  * YRichText:
  virtual setText() -> virtual setValue()
  virtual getText() -> virtual value()
  setText() is still there, but no longer virtual - implement setValue() instead!
  new (instead of YWidgetOpt() ):
  - bool plainTextMode() const;
  - virtual void setPlainTextMode( bool on = true );
  - bool autoScrollDown() const;
  - virtual void setAutoScrollDown( bool on = true );
  - bool shrinkable() const;
  - void setShrinkable( bool shrinkable = true );
* Wed Jun 20 2007 sh@suse.de
  * Parameter YRadioButtonGroup now obsolete:
  YRadioButtons traverse the YWidget hierarchy upwards to find
  their parent YRadioButtonGroup. There is no more need to pass
  the YRadioButtonGroup as a parameter through all kinds of
  calls.
  This had cluttered the API for a long time.
  * Got rid of all YCP data types in all widget classes:
  * YCPString		-> std::string
  * YCPInteger	-> int
  * YCPBoolean	-> bool
  * In function parameters, std::string is generally passed as const std::string & .
  * All widgets: No longer implementing changeWidget() / queryWidget() directly,
  now using setProperty() / getProperty().
  Reason: No more YCP depencency in YWidget derived classes.
  See YRadioButton or YTextEntry for examples.
  * All widgets: widgetClass() now returns const char *, no longer char *
  (gcc had already complained in abuild about this)
  auto-replace this with:
  perl -p -i -e 's/virtual char \*widgetClass/virtual const char *widgetClass/' *.h
  * All widgets: nicesize() was replaced by preferredWidth() and preferredHeight().
  Both return an int, not a long like nicesize() did: int is plenty for pixel
  coordinates, and it's a LOT less hassle.
  The rationale for splitting up nicesize() (and giving it an English name, no
  longer German_en) was that in 95%% of all cases the first thing an
  implementation does is something like
    if ( dim == YD_HORIZ )
    // calculate width
    else
    // calculate height
  If you must (though this is discouraged), you can still reimplement
    int YWidget::preferredSize( YUIDimension dim )
  which now by default calls preferredWidth() and preferredHeight().
  Use the perl scripts from ~sh/Export/ for easier transition:
  (but by all means do "svn ci" immediately before so you can easily revert):
    mod-ui-change-nicesize-header *.h
    mod-ui-change-nicesize-src *.cc
  This doesn't do the work completely, but it's a good starting point.
  * All widgets: The parameters of YWidget::setSize() are now int, no longer long.
  The reasoning is the same as with long nicesize() vs. int preferredWidth().
  Use the perl scripts from ~sh/Export/ for easier transition:
  (but by all means do "svn ci" immediately before so you can easily revert):
    mod-ui-change-setSize-header *.h
    mod-ui-change-setSize-src *.cc
  This should do the trick, but make sure to double-check what it did.
  * All widgets:
  Most 'long' function parameters and return values are now 'int',
  including (but not restricted to):
  * widget sizes
  * widget positions
  * layout weights
  gcc should complain about missing places. Also remember to check for '%%ld' in
  y2debug() etc. calls and replace most of them with '%%d'.
  * Factories:
  * Derived UIs now are required to implement:
  * YWidgetFactory * createWidgetFactory()
  * YOptionalWidgetFactory * createOptionalWidgetFactory()
  * Moved widget creation methods to factories
  * New header file YTypes.h for simple types to reduce header file interdependencies:
  Now it's often no longer necessary to #include YAlignment.h or YWidget.h
  * YUI:
  * YUI::currentDialog() is now moved to static YDialog::currentDialog()
  * New: YApplication
  The idea of this class is to bundle all the "misc UI functionality" methods.
  See YApplication.h for details.
  * YDialog:
  * YUI::currentDialog() is now moved to YDialog::currentDialog()
  * YDialog::currentDialog() now throws exceptions by default (unless bool param == true),
    i.e. there is no more need to check for a 0 pointer after currentDialog()
    (but exceptions need to be caught somewhere)
  * YSplit:
  * renamed to YLayoutBox
  * YRadioButton:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * value is now bool		, no longer YCPBoolean
  * label is now std::string	, no longer YCPString
  * YCPString getLabel()			-> std::string label()
  * void setLabel( YCPString )		-> setLabel( std::string )
  * virtual YCPBoolean getValue()		-> virtual bool value()
  * virtual void setValue( YCPBoolean )	-> virtual void setValue( bool )
  * new method: useBoldFont()  (instead of YWidgetOpt::boldFont() )
  * new method: boldFont()
  * YTextEntry:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * label is now std::string	, no longer YCPString
  * passwordMode is now passed directly in the constructor, not only via YWidgetOpt
  * passwordMode is now a member, no longer avaliable only from YWidgetOpt
  * Renamed getText()	-> value(),
  * Renamed setText()	-> setValue()
  * virtual YCPString getText()		-> virtual std::string value()
  * virtual void setText( YCPString )		-> virtual void setValue( std::string )
  * getLabel() -> label()
  * virtual setValidChars( YCPStrng )		-> virtual setValidChars( std::string )
  * virtual setInputMaxLength( YCPInteger )	-> virtual setInputMaxLength( int )
  * overloaded virtual setInputMaxLength( int ) is now required to call
    YTextEntry::setInputMaxLength() at its end
  * YPushButton:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * label is now std::string	, no longer YCPString
  * YReplacePoint:
  * now derived from YSingleChildContainerWidget
  * removed YWidget::isReplacePoint() / YReplacePoint::isReplacePoint()
  * no more YContainerWidget::childAdded(),
    reimplement YReplacePoint::showChild() instead.
  * YRadioButtonGroup:
  * no more std::vector<YRadioButton *> buttons,
    use iterators with buttonsBegin() and buttonsEnd() instead
  * YWidgetFactory:
  * createHeading()	is no longer virtual - remove from derived factory
  * createOutputField() is no longer virtual - remove from derived factory
* Thu Jun 14 2007 kmachalkova@suse.cz
- Use environment variable Y2NCURSES_COLOR_THEME to set color theme
  of UI (FaTE #301893)
- Added new rxvt theme (for rxvt-style terminals)
- 2.15.19
* Thu Jun  7 2007 kmachalkova@suse.cz
- Do not add extra vertical space to CheckBoxFrame widget (expand
  only horizontally so that check box fits in)
- 2.15.18
* Wed Jun  6 2007 gs@suse.de
- Online Update/Package Installation: allow status change and show
  correct version of patch packages, add installed packages to the
  list of package versions, replace obsolete transactResKind() by
  resolvePool()
* Thu May 31 2007 gs@suse.de
- Load library libpy2ncurses_pkg as plugin
* Tue May 29 2007 kmachalkova@suse.cz
- Removed obsolete save/load selection stuff + related NCPkgPopupFile
  class - replaced by save/load pkgs & patterns (FaTE #300729)
- Improved usability of cancel dialog in pkg manager (#274774)
- Fix disappearing 'Etc./All Packages List' submenu after unchecking
  AutoDependency Check
- Place all popup dialogs in pkg manager to the centre of the screen
  and calculate their size relatively to the screen size (if applicable)
  (#275610)
- 2.15.17
* Wed May 23 2007 gs@suse.de
- Package Installation: check the partition size to prevent
  division by zero during disk space calculation (bug #270836)
* Wed May 16 2007 gs@suse.de
- Move all files related to package installation to subdir 'pkg'
  and create a separate library libpy2ncurses_pkg (not yet loaded
  as a plugin).
* Thu May 10 2007 kmachalkova@suse.cz
- Replace &#xy; elements in richtext by their ascii character
  equivalents (#269919)
- Calculate license agreement & notify text popup size and position
  relatively to the current screen size (#269918)
- 2.15.16
* Wed May  2 2007 gs@suse.de
- Disable child widgets of a NCCheckBoxFrame correctly (bug #268352)
* Thu Apr 26 2007 kmachalkova@suse.cz
- For containter (Box) and alignment (Left, Right,...) widgets
  enable/disable all the children recursively (#256707)
- 2.15.15
* Mon Apr 23 2007 kmachalkova@suse.cz
- Really correct setting of current item in ComboBox widget :-)
  consider also `opt(`editable) combos (#233593)
* Mon Apr 23 2007 sh@suse.de
- Load qt_pkg plugin for PatternSelector widget, too
- V 2.15.5
* Thu Apr 19 2007 gs@suse.de
- Enable/disable the RadioButtons in a RadioButtonGroup correctly
  (bug #168770)
- ncurses-devel added to BuildRequires
- 2.15.14
* Thu Apr 19 2007 kmachalkova@suse.cz
- Package selector: added filter for languages (zypp::Language) -
  beta version (FaTE #301810 - part I)
* Thu Apr 19 2007 gs@suse.de
- Inform the user that all dependencies/the system are/is OK after
  a check from 'Etc.' menu (bug #249281)
* Mon Apr 16 2007 sh@suse.de
- Added qt_pkg plugins to file list
- V 2.15.4
* Fri Apr 13 2007 sh@suse.de
  Merged mod-ui branch changes back to trunk (r37143:37466):
- Reorganized source directory layout:
  - Header files now in same directory as .cc files
  - Moved package selection related sources to separate subdir src/pkg
- Load package selection stuff upon demand as plugin
  (saves 2 MB VmRSS if no PackageSelector needed)
  [see also Fate #302119]
- V 2.15.3
* Mon Mar 26 2007 sh@suse.de
- Fixed bug #251215: "Save screenshot to" not translated
* Wed Mar 21 2007 kmachalkova@suse.cz
- Correct pkg/pattern/patch state transition from S_AutoInstall to
  S_Taboo on toggle with SPACE key (#254816)
- Do not set state to S_Install if no candidate is available
- 2.15.13
* Fri Mar  9 2007 sh@suse.de
- PackageSelector/PatternSelector no longer use zypp::transactResKind()
  to emulate what a real solver run might do, now always does a real
  solver run which is no longer painfully slow with recent
  solver improvements.
- Auto-solving on by default in PackageSelector
- V 2.15.2
* Thu Mar  8 2007 gs@suse.de
- Don't throw away keys from the input buffer after a ValueChanged or
  SelectionChanged event but save them e.g. for input in TextEntry,
  MultiLineEdit or to scroll in lists ( bug #245476 )
- 2.15.12
* Wed Mar  7 2007 kmachalkova@suse.cz
- Tree widget: handle arrows and HOME/END keys in compatible way
  with other widgets (#251216)
* Tue Mar  6 2007 kmachalkova@suse.cz
- initscr() code is back - needed for running yast clients from
  scripts with no terminal associated (#248864)
- 2.15.11
* Fri Mar  2 2007 kmachalkova@suse.cz
- Replaced 'Solve' label with 'OK -- Try again' in pkg manager (to
  be compatible with Qt), enhanced help text (#213602)
- 2.15.10
* Thu Mar  1 2007 gs@suse.de
- Replace &product; in RichText widget correctly (bug #247845)
* Thu Feb 22 2007 gs@suse.de
- Online Update: Add column with patch version and show the version in
  the description window (bug #239829)
- 2.15.9
* Wed Feb 21 2007 kmachalkova@suse.cz
- Show 'automatic changes' popup when any pkgs are selected for
  installation by 'verify system' call (#239750)
- Remember pkgs already marked for automatic installation by 'verify
  system' and do not show them in 'automatic changes' popup again
- 2.15.8
* Tue Feb 20 2007 sh@suse.de
- Fixed bug #239829 (again): Show patch version in patches list
- V 2.15.1
* Thu Feb 15 2007 sh@suse.de
- Fixed bug #148469: Exclude -debuginfo and -devel pkgs on demand
- V 2.14.7
* Wed Feb 14 2007 kmachalkova@suse.cz
- Use generic xterm/vt100 termifo in case required terminfo is missing
  (#235954)
- Removed obsolete initscr() code
- 2.15.7
* Tue Feb  6 2007 mvidner@suse.cz
- Prefixized font patch check.
* Tue Feb  6 2007 kmachalkova@suse.cz
- Correct setting of current item in ComboBox widget (#233593)
* Thu Feb  1 2007 gs@suse.de
- Online Update: Show patch name (ID) in patches list (bug #239829)
- 2.15.6
* Thu Feb  1 2007 sh@suse.de
- Merged SLE10-SP1 branch changes back to trunk:
  - Fixed bug #239829: Show patch name (ID) in patches list
- V 2.14.6
* Wed Jan 31 2007 sh@suse.de
- Merged SLE10-SP1 branch changes back to trunk:
  - Fixed bug #187322: Ignore solver errors in patch mode
    at first solver run
  - Fixed bug #232522: Added inst src URL to pkg versions view
  - Fixed bug #152997: Install progress icons
- V 2.14.5
* Wed Jan 24 2007 sh@suse.de
- Merged SLE10-SP1 branch changes back to trunk:
  - Fixed bug #218669: Broken UTF8 chars in pkg to text file export
  - Fixed bug #227409: Add installed packages to text file export
  - Fixed bug #229368: comparison with string literal
  - Added Qt-UI support for feature #301178: verify installed system
  - Added CheckBoxFrame widget for feature #5673
  - Implemented feature #300729: Saving of patterns and packages
- V 2.14.4
* Wed Jan 17 2007 kmachalkova@suse.cz
- Substitute right arrows back for tab characters when querying
  content of MultiLineEdit widget (mostly) (#142509)
- 2.15.5
* Tue Jan 16 2007 gs@suse.de
- Spec file: Requires: libzypp >= 2.12.1
- Improve CheckBoxFrame widget (related to Fate #5673)
- Add argument to verifySystem() call (related to Fate #301178)
* Fri Jan 12 2007 gs@suse.de
- CheckBoxFrame widget added (Fate #5673)
* Wed Jan 10 2007 kmachalkova@suse.cz
- Added functionality to export/import list of all packages and
  patterns to xml file (FaTE #300729)
- 2.15.4
* Thu Jan  4 2007 kmachalkova@suse.cz
- Added functionality to update list of pkgs if newer version is
  available (#227043)
- Improved switching between states of pkgs (install->don't install
  update->don't update) (partly #204072)
- 2.15.3
* Tue Dec 12 2006 gs@suse.de
- Package Installation: add functionality 'Verify System' to Etc./
  Dependencies menu (Fate #301178)
- Online Update: patch searching ability added to Filter menu
  (Fate #153197)
- 2.15.2
* Tue Dec  5 2006 kmachalkova@suse.cz
- Added RunInTerminal UI builtin for running external programs in
  the same terminal
- 2.15.1
* Tue Dec  5 2006 kmachalkova@suse.cz
- Use the same color palette - 8 colors - for all terminals (thanks
  to tiwai) (#221614)
- Highlight keyboard shortcuts in mono theme (#224892)
- 2.15.0
* Wed Nov 29 2006 kmachalkova@suse.cz
- Display updated patches also in 'installable' view (not only in
  'installed' one) (#223416)
- 2.14.4
* Fri Nov 24 2006 kmachalkova@suse.cz
- Reverted fix for refreshing screen in installation (#199256)
- More space for filter description in package selector (#222549)
- 2.14.3
* Thu Nov 23 2006 sh@suse.de
- Fixed bug #223416: Updated patches not visible in default view
- V 2.14.3
* Tue Nov 21 2006 sh@suse.de
- V 2.14.2
- Fixed bug #222505 (left-handed mouse)
* Fri Nov 10 2006 sh@suse.de
- Merged SLE-10-SP1-Branch to trunk (r31627:34245)
- V 2.14.1
* Tue Nov  7 2006 gs@suse.de
- Package Installation/Online Update: added support for resolver
  test case generation, additional entry 'Etc.' menu (Fate #300756)
- 2.14.2
* Thu Nov  2 2006 gs@suse.de
- Online update: Improved list of relevant patches (bug #168758)
- 2.14.1
* Tue Oct 31 2006 sh@suse.de
- Improved bugfix for bug #183735 (display only relevant patches
  by default): Also display patches that are satisfied, but
  not installed yet
- Fixed bug #189134: Show description of initial patch / pkg
- Override patch category tooltips with "Dependencies broken" or
  "Dependencies satisfied" in patch list
- V 2.13.73
* Tue Oct 31 2006 kmachalkova@suse.cz
- (Temporary) fix for refreshing screen during the installation
  (#199256)
- Adjusted spec to require libzypp >=2.7.0 (zypp::ui::PatternContent)
- 2.14.0
* Mon Oct 30 2006 sh@suse.de
- Consistent handling of isSatisfied and isBroken for bug #173488
- Added real "isSatisfied" icon
- V 2.13.72
* Mon Oct 30 2006 gs@suse.de
- Package Installation: Fold hidden patterns into parents (Fate #301229)
- Online Update: show list of installable (relevant) patches
  (bug # 168758)
- 2.13.47
* Fri Oct 27 2006 sh@suse.de
- Added missing icon to dist tarball
- V 2.13.71
* Thu Oct 26 2006 sh@suse.de
- Fixed bug #162164: pattern detection does not work
- Fixed bug #173488: Status satisfied for a patch is displayed like
  uninstalled
- V 2.13.70
* Thu Oct 26 2006 sh@suse.de
- Fixed bug #183735 - YOU should display only relevant patches by
  default
- V 2.13.69
* Wed Oct 25 2006 sh@suse.de
- Implemented feature #300756: Added support for resolver test
  case generation (PackageSelector -> "Extras" menu)
- V 2.13.68
* Tue Oct 24 2006 sh@suse.de
- Implemented feature #120142: View installed products
- Implemented feature #301229: Fold hidden patterns into parents
- V 2.13.67
* Thu Oct 12 2006 sh@suse.de
- Implemented feature #301222: Easy access to updating all packages
- V 2.13.66
* Wed Oct 11 2006 gs@suse.de
- Online Update: Allow deletion of patches (bug #208694)
  Package Installation: change status to delete if '-' is pressed,
  use %% key to reset taboo status (bug #204072)
- 2.13.46
* Tue Oct 10 2006 gs@suse.de
- Package Installation: Show low disk space warning similiar to
  QT version (FaTE #300548)
- 2.13.45
* Wed Oct  4 2006 sh@suse.de
- Fixed bug #208694: Allow deleting patches
  (only the patch meta data will be deleted, packages will remain
  the same!)
- V 2.13.65
* Tue Oct  3 2006 jsrain@suse.cz
- added missing files to Makefile.am
- 2.13.64
* Fri Sep 29 2006 sh@suse.de
- V 2.13.63
- Fixed bug #205059: CapsLock warning in password fields
* Wed Sep 27 2006 kmachalkova@suse.cz
- Better displaying of visited hyperlinks in NCRichText (#144428)
- 2.13.44
* Fri Sep 22 2006 sh@suse.de
- Allow pattern categories to be collapsed
- V 2.13.62
* Mon Sep 18 2006 kmachalkova@suse.cz
- Improved HTML parser in NCRichText (header, paragraph and list
  handling) (FaTE #3124)
- 2.13.43
* Thu Sep 14 2006 gs@suse.de
- Package Installation: default entry in filter menu is 'Patterns'
- 2.13.42
* Thu Sep 14 2006 kmachalkova@suse.cz
- Adding ncursesw autoconf check to configure.in.in to ensure
  portability to other distros (#201705)
* Thu Sep 14 2006 gs@suse.de
- Package Installation: search in the "provides" tag of the installed
  package (bug #180232)
* Wed Sep 13 2006 sh@suse.de
- Applied patch from Ricardo Cruz <rpmcruz@clix.pt>
  for new UI::Beep() built-in
* Wed Sep 13 2006 sh@suse.de
- Applied patch from Ricardo Cruz <rpmcruz@clix.pt>
  for new UI::Beep() built-in
* Tue Sep 12 2006 gs@suse.de
- Package Installation: show details of package and pattern
  dependencies (bug #178494, bug #201745)
- 2.13.41
* Thu Aug  3 2006 mvidner@suse.cz
- Added a configure-time check for the X font directory.
- 2.13.61
* Tue Jun 27 2006 sh@suse.de
- Fixed bug #188018: Patch description: Text in angle brackets
* Tue Jun 20 2006 gs@suse.de
- Online Update: don't show the patch size (bug #186100);
  show the patch summary, if available, else the name of the patch
  (bug #186209).
- 2.13.40
* Mon Jun 12 2006 mvidner@suse.cz
- Fixed the previous fix not to pass milliseconds to usleep.
- 2.13.39
* Mon Jun 12 2006 visnov@suse.cz
- If there is no active widget and we are running against timeout,
  really timeout (#182982)
- 2.13.38
* Fri Jun  9 2006 visnov@suse.cz
- Redraw the screen after updating the text entry value (#167609)
- 2.13.37
* Fri Jun  2 2006 gs@suse.de
- Online Update: make resetting of status Taboo and Protected
  possible (related to bug #174476)
- 2.13.36
* Wed May 31 2006 sh@suse.de
- V 2.13.60
- Fixed bug #179679: Untranslated text in file dialogs
* Tue May 30 2006 gs@suse.de
- Added support for licenses for patches (bug #174476)
- 2.13.35
* Wed May 24 2006 sh@suse.de
- V 2.13.59
- Added support for licenses for patches (bug #174476)
* Mon May 22 2006 gs@suse.de
- Check whether the window pointer is valid in ::wCreate
  to prevent a segfault if the terminal is too small
  (bug #175920)
- 2.13.34
* Fri May 19 2006 gs@suse.de
- Package Installation: Sort the pattern list (bug #176603)
- 2.13.33
* Thu May 18 2006 kkaempf@suse.de
- adapt to libzypp 1.0.0 api
- require libzypp >= 1.0.0
- V 2.13.58
* Thu May 18 2006 kkaempf@suse.de
- adapt to libzypp 1.0.0 api
- require libzypp >= 1.0.0
- 2.13.32
* Wed May 17 2006 gs@suse.de
- Package Installation/Online Update: Install correct package if the user
  requests a certain package version, i.e. changing the "candidate".
  Add view 'Versions' to Online Update 'Information' menu.
  (bug #164487)
- 2.13.31
* Wed May 10 2006 sh@suse.de
- Set package to "update" or "install" if user selects a different
  version in the "Versions" tab of the package selector
  (workaround for bug #164487: can't downgrade using a patch)
- V 2.13.57
* Wed May 10 2006 gs@suse.de
- Package Installation dialag: Create appropriate 'Filter' menu
  with 'Patterns' or 'Selections' (bug #171024, bug #173885)
- 2.13.30
* Tue May  9 2006 sh@suse.de
- Fixed bug #173122: Easter egg crashes the installation
- V 2.13.56
* Tue May  9 2006 gs@suse.de
- show "Automatic Changes List" correctly (bug #152700)
- 2.13.29
* Tue May  9 2006 sh@suse.de
- Fixed bug #173865: No "automatic changes" dialog upon "Accept"
  in Qt package selector
- V 2.13.55
* Thu May  4 2006 gs@suse.de
- messages from proofread merged back
- 2.13.28
* Thu May  4 2006 sh@suse.de
- V 2.13.54
- Messages back from proofreading
* Wed May  3 2006 gs@suse.de
- Online Update: show text "No patches available" if the patch list is empty
- 2.13.27
* Fri Apr 28 2006 sh@suse.de
- V 2.13.53
- Disabled patches view in package selector (non-YOU-mode)
  to avoid problems with kernel and ZYPP patches
  (patches view is still available upon F2 keypress)
* Tue Apr 25 2006 sh@suse.de
- Fixed bug #168904: Changing "all in this list" status in pkg lists
  takes too long
- V 2.13.52
* Tue Apr 25 2006 gs@suse.de
- bugfix for #167565 - UI: deselecting one preselected pattern deselects
  everything (add transactResKind( zypp::ResTraits<zypp::Product>::kind )
- 2.13.26
* Tue Apr 25 2006 schubi@suse.de
- Bug 167565 - UI: deselecting one preselected pattern deselects everything
  Added transactResKind( zypp::ResTraits<zypp::Product>::kind ) in solveResolvableCollections
* Mon Apr 24 2006 gs@suse.de
- bugfix for list of problematic update items (add installed
  packages to SelMapper to show packages marked auto-delete)
- Online Update: don't show label 'Installable Patches'
- 2.13.25
* Mon Apr 24 2006 sh@suse.de
- V 2.13.51
- Add installed pkg to SelMapper to fix "update problems" list
  (required for pkgs that are not available and marked auto-delete)
* Fri Apr 21 2006 gs@suse.de
- list of problematic update items added
- handle Auto status for patches
- 2.13.24
* Thu Apr 20 2006 sh@suse.de
- V 2.13.50
- Re-implemented list of problematic packages during update
* Thu Apr 20 2006 gs@suse.de
- Don't show the "Automatic Changes" list in Online Update mode
- 2.13.23
* Thu Apr 20 2006 sh@suse.de
- Ask for confirmation to abandon changes if a language is changed
* Thu Apr 20 2006 mvidner@suse.cz
- Catch exceptions when calling package management code (#166278).
- 2.13.22
* Thu Apr 20 2006 mvidner@suse.cz
- Catch exceptions when calling package management code (#166278).
- Adapted for libzypp in a nonstandard prefix.
- 2.13.49
* Wed Apr 19 2006 gs@suse.de
- set status of packages correctly (Bug 164365)
- do an initial solver run also in YOU mode
- sort the list of patches, show edition of patch packages
- 2.13.21
* Tue Apr 18 2006 sh@suse.de
- V 2.13.48
- Added infrastructure to fix bug #164869: Duplicate "Accept" button
  in pattern selector
* Thu Apr 13 2006 schubi@suse.de
- Bug 164365 - build 906: Deselecting a selection, all packages are still selected
* Wed Apr 12 2006 gs@suse.de
- also set status to Taboo in case of AutoInstall and to Protected
  in case of AutoUpdate (bugfix for bugfix bug #163827)
- 2.13.20
* Tue Apr 11 2006 gs@suse.de
- check for pending licenses (bug #163827)
- 2.13.19
* Mon Apr 10 2006 gs@suse.de
- Fixed inconsistent propagation of installation status of packages
  that belong to selections, patterns, languages etc.
- show/check dependencies also in YOU mode
- 2.13.18
* Fri Apr  7 2006 sh@suse.de
- v 2.13.45
- Fixed bug #163827: Special package licenses not shown in weird cases
- Fixed inconsistent propagation of installation status of packages
  that belong to selections, patterns, languages etc.
* Fri Apr  7 2006 gs@suse.de
- solve pattern/selection dependencies correctly (bug #161400),
  show architecture in versions view
- 2.13.17
* Tue Apr  4 2006 sh@suse.de
- V 2.13.45
- Fixed bug #161400: Switching between alternative patterns
- Migrated from Resolver::transactResObject() to
  Resolver::transactResKind() for all higher-level YQPkg*Lists
* Fri Mar 31 2006 sh@suse.de
- V 2.13.44
- Fixed bug #161860: Pattern selector layout out of proportion
* Fri Mar 31 2006 sh@suse.de
- Fixed bug #152700: Automatic changes dialog displays garbage
* Wed Mar 29 2006 sh@suse.de
- V 2.13.43
- Fixed bug #121872: segfault at program end if no Qt style defined
* Wed Mar 29 2006 gs@suse.de
- Show/set correct status information for packages in versions view
  (available packages)
- 2.13.16
* Wed Mar 29 2006 sh@suse.de
- V 2.13.42
- Fixed broken umlaut characters in pattern categories
* Tue Mar 28 2006 sh@suse.de
- V 2.13.41
- Show language specific packages in "languages" filter
* Tue Mar 28 2006 gs@suse.de
- YOU patch installation: avoid duplicate entries in package list,
  show download size, show scripts
- 2.13.15
* Mon Mar 27 2006 gs@suse.de
- make YOU patch installation work
- 2.13.14
* Mon Mar 27 2006 sh@suse.de
- V 2.13.40
- Fixed bug #156590: No way to reset ignored dependency problems
* Thu Mar 23 2006 sh@suse.de
- V 2.13.39
- Calculate and display patches total download size on the fly
* Thu Mar 23 2006 sh@suse.de
- V 2.13.38
- Enable auto-solving for patches
- Support for multi-arch patches: Prevent duplicate entries
  in pkg list
* Thu Mar 23 2006 sh@suse.de
- Fall back to search view if no multiple sources
* Thu Mar 23 2006 sh@suse.de
- V 2.13.37
- Enable starting up package selector in inst sources mode: Use
  `opt(`instSourcesMode)
* Wed Mar 22 2006 sh@suse.de
- V 2.13.36
- Small fixes
* Mon Mar 20 2006 visnov@suse.cz
- V 2.13.35
- adapt for latest libzypp
* Thu Mar 16 2006 sh@suse.de
- Fixed bug #158576: 'install -> all in this list' does not work
  for patterns
* Wed Mar 15 2006 sh@suse.de
- V 2.13.34
- Display patch content (packages and scripts)
- Moved solving for single current item to base class
* Tue Mar 14 2006 sh@suse.de
- V 2.13.33
- Fixed yast2-qt part of bug #151834: third party licenses
  (Acrobat reader, flash player, ...)
* Tue Mar 14 2006 sh@suse.de
- V 2.13.32
- Ported disk usage in package selector to ZYPP
* Mon Mar 13 2006 mvidner@suse.cz
- Added license confirmations (#151834).
- Show the list of automatically changed packages (#152700#c1).
- Show the list of update problems: Protected, Taboo, AutoDeleted.
- 2.13.13
* Fri Mar 10 2006 sh@suse.de
- V 2.13.31
- First version of patches view that can display patch contents
* Fri Mar 10 2006 sh@suse.de
- V 2.13.30
- Fixed bug #155799: Qt package selector does not recognize newer
  packages as newer
- Display patch category in patches view
* Fri Mar 10 2006 mvidner@suse.cz
- Messages for the package conflict dialog marked for translation.
* Thu Mar  9 2006 sh@suse.de
- V 2.13.29
- First (still crude) version of patches view for ZYPP
- Activate "patches" filter view in package selector upon F2 key
* Wed Mar  8 2006 sh@suse.de
- V 2.13.28
- Added "file list"  view to package selector
- Added "change log" view to package selector
* Tue Mar  7 2006 sh@suse.de
- V 2.13.27
- Allow searching in RPM requires / provides tags
* Mon Mar  6 2006 sh@suse.de
- V 2.13.26
- Ported "dependencies" details view to ZYPP
- No longer translating RPM tags "provides", ...
* Mon Mar  6 2006 sh@suse.de
- Ported "languages" filter view to ZYPP
  (no lang-specific packages displayed yet, missing in libzypp)
* Fri Mar  3 2006 sh@suse.de
- V 2.13.25
- Ported RPM groups filter view to ZYPP
* Fri Mar  3 2006 mvidner@suse.cz
- Disk usage display fixed (#152269).
- 2.13.12
* Thu Mar  2 2006 sh@suse.de
- V 2.13.24
- Display product name (if available) for package versions
  in "versions" details view
* Thu Mar  2 2006 sh@suse.de
- Yet another performance boost for "installation sources"
  filter view (~120 millisec per click instead of ~1.2 sec)
* Thu Mar  2 2006 sh@suse.de
- Performance boost for "installation sources" filter view (factor 10)
- V 2.13.23
* Tue Feb 28 2006 sh@suse.de
- Installation sources filter view migrated to ZYPP
- V 2.13.22
* Tue Feb 28 2006 sh@suse.de
- YQPkgVersionsView migrated to ZYPP
* Tue Feb 28 2006 sh@suse.de
- Removed beta warning upon insistence of our project managers
  despite the fact that the package manager GUI is still broken
  beyond recognition
- V 2.13.21
* Mon Feb 27 2006 sh@suse.de
- Fixed bug #153035
- Fixed bug #153032
- V 2.13.20
* Mon Feb 27 2006 mvidner@suse.cz
- Sort packages in a selection.
- No need to resolve the pool again before displaying the packages
  in a selection.
- Hid menu items of features that do not work:
  SRPMs, Selection Load/Save.
- Only show the Installed Version column if any packages are installed.
- Do not show '?' in the Source column.
- 2.13.11
* Mon Feb 27 2006 sh@suse.de
- Re-enabled TABOO and PROTECTED
* Fri Feb 24 2006 mvidner@suse.cz
- Tried to allow selecting one of the available package versions.
- When canceling the package selection, ask for confirmation
  only if the user has changed something (but see #152700).
* Wed Feb 22 2006 sh@suse.de
- V 2.13.19
- Removing patterns and selections now works as well as adding them
* Wed Feb 22 2006 mvidner@suse.cz
- When exiting the package dialog, show packages which are
  automatically selected for installation (but see #152700).
- Display the RPM group tree.
- Display package relations, enable search in requires and provides.
- Display the available versions of a package.
- 2.13.10
* Wed Feb 22 2006 mvidner@suse.cz
- Fixed displaying the shortcut keys for wide characters (#148380, tiwai).
* Tue Feb 21 2006 sh@suse.de
- V 2.13.18
- use new way to enable/disable autodocs by mvidner
* Tue Feb 21 2006 mvidner@suse.cz
- Do not package the doxygen documentation, it is only useful for the
  maintainer (#151370).
- 2.13.9
* Tue Feb 21 2006 sh@suse.de
- sort category-less patterns before any category
- no tree indentation for patterns
- disable closing pattern categories
- disable selecting pattern categories
* Mon Feb 20 2006 sh@suse.de
- V 2.13.17
- Added pattern categories
- Patterns now use their sort order field
* Fri Feb 17 2006 sh@suse.de
- Added pattern icons to pattern selector
* Fri Feb 17 2006 sh@suse.de
- Don't install and distribute autodocs (#151370)
* Fri Feb 17 2006 mvidner@suse.cz
- If patterns are available, display them instead of selections.
* Thu Feb 16 2006 mvidner@suse.cz
- Show something in the update problem list, for now
  just the deleted packages.
- Prepare for detecting whether the user has made any changes
  upon abort.
- 2.13.8
* Thu Feb 16 2006 mvidner@suse.cz
- Added the selection list.
- Most popups should work now, some with faked data though.
- Show also medium ID and RPM group.
- 2.13.7
* Thu Feb 16 2006 sh@suse.de
- V 2.13.15
- Use patterns in PatternSelector if there are any,
  but fall back to selections if there are none
  (and fall back to detailed selection if there are no selections,
  either)
* Thu Feb 16 2006 sh@suse.de
- First real pattern filter view
* Wed Feb 15 2006 sh@suse.de
- V 2.13.14
- Fixed package description formatting
- Migrated "automatic changes" dialog in PkgSel to ZYPP
- Workaround for incomplete selections packages handling
- Migrated pkg description popup (for hyperlinks) in PkgSel to ZYPP
* Wed Feb 15 2006 mvidner@suse.cz
- Show most package details.
- Search works, except in dependencies.
- 2.13.6.4
* Wed Feb 15 2006 mvidner@suse.cz
- Dependency solver ported.
- Reduced BuildReqs, libzypp-devel has them now.
- 2.13.6.3
* Tue Feb 14 2006 sh@suse.de
  Package selector changes:
- Display selections filter view only if there are any selections
- Display packages that belong to a selection in selections filter
- Propagate selection status change to corresponding packages
- Display separate columns for installed and available package only
  if there are any installed packages
- "Technical Details" view now (almost) complete
* Tue Feb 14 2006 mvidner@suse.cz
- Minimal zypp support:
  * One list with all packages.
  * Can change status. No popups and no details.
  * If there are package conflicts, they will be ignored by the UI
    and the actual installation will fail (with a misleading popup,
    but the logs have it right).
- 2.13.6.2
* Tue Feb 14 2006 sh@suse.de
- Applied mfabian's fix for bug #132577: SuSE Serif Italic font
* Fri Feb 10 2006 sh@suse.de
- V 2.13.13
- "Installation summary" filter view ported to ZYPP
- Re-enabled "Cancel" button (saveState / restoreState) in PkgSel
- Code cleanup
* Fri Feb 10 2006 mvidner@suse.cz
- Ripped out all package related stuff: y2pm out, zypp not yet in (#149879)
- 2.13.6
* Wed Feb  8 2006 sh@suse.de
- ZYPP resolver integrated and working
- "Search" view working in package selector
- V 2.13.12
* Wed Feb  8 2006 kkaempf@suse.de
- Initial libzypp integration
- V 2.13.11
* Fri Feb  3 2006 visnov@suse.cz
- Temporary fix for build
- V 2.13.10
* Thu Feb  2 2006 sh@suse.de
- Fixed bug #145189 (untranslated text): Added "Textdomain"
* Tue Jan 31 2006 sh@suse.de
- Fixed extra qualification
- V 2.13.9
* Mon Jan 30 2006 sh@suse.de
- V 2.13.8
- Implemented YQPatternSelector (feature #129)
* Tue Jan 24 2006 visnov@suse.cz
- Disable sorting in non-YTable (#143085)
- V 2.13.5
* Tue Jan 17 2006 sh@suse.de
- Fixed bug #77920: Not stripping shortcut from frame
  ("Network Address Setup dialog cannot be finished by a hotkey")
- V 2.13.4
* Thu Jan 12 2006 sh@suse.de
- V 2.13.7
- Now starting xterm in background upon Ctrl-Alt-Shift-X
* Mon Jan  9 2006 visnov@suse.cz
- Allow to set table order by Ctrl-O
- V 2.13.3
* Wed Jan  4 2006 sh@suse.de
- V 2.13.5
- Implemented feature #3476: Left-handed mouse during installation
  now asking the user if he wants his mouse buttons switched
  if he clicks the right mouse button on a push button or in a
  selection box
* Wed Jan  4 2006 sh@suse.de
- Open xterm upon Ctrl-Shift-Alt-X hotkey (for debugging in inst-sys)
* Tue Dec 20 2005 sh@suse.de
- V 2.13.4
- Fixed bug #114193: YQComboBox doesn't send valueChanged event
* Tue Dec 20 2005 visnov@suse.cz
- Don't link against libpy2stdio
- V 2.13.2
* Thu Nov 24 2005 visnov@suse.cz
- Fix strict aliasing warnings
- V 2.13.1
* Fri Nov 18 2005 sh@suse.de
- V 2.13.3
- Added new secondary filter view "summary" to inst src filter view
* Thu Nov 17 2005 sh@suse.de
- V 2.13.2
- Added secondary filter views to installation sources filter view:
  - All Packages
  - RPM groups
  - Search
* Wed Nov 16 2005 sh@suse.de
- V 2.13.2
- New filter view in package selector: installation sources
* Tue Oct 25 2005 sh@suse.de
- V 2.13.1
- Merged aj's patch to fix stricter gcc4 warnings
* Mon Oct 10 2005 visnov@suse.cz
- Fix compilation for GCC 4.1
- V 2.13.0
* Fri Sep  9 2005 sh@suse.de
- Fixed bug #114072: custom package selection lost
  No longer offering the user to delete his base selection in
  dependency problem dialog if he set a selection to "taboo"
  the base selection depends upon
- V 2.12.12
* Thu Aug 25 2005 sh@suse.de
- V 2.12.11
* Thu Aug 25 2005 mfabian@suse.de
- Bugzilla #102978: Japanese TrueType fonts are not used in first
  part of installation: fix typo in lang_conf.
* Thu Aug 18 2005 sh@suse.de
- V 2.12.10
- Now using llunak's updated qxembed.{cc,h} to fix bug #46495:
  Keyboard focus problems with YaST2 embedded into KControl
* Thu Aug 11 2005 visnov@suse.cz
- Resolve entities even in <pre> (#71718)
- V 2.12.6
* Wed Aug 10 2005 visnov@suse.cz
- Don't crash on pressing Esc in AskForExistingDirectory (#96141)
* Thu Jul 21 2005 sh@suse.de
- Now using `opt(`hvstretch) to restore old YQWizard layout behaviour
  (centering content by default)
- V 2.12.9
* Wed Jul 20 2005 sh@suse.de
- Prevent segfault if there is no steps heading in the side panel
- V 2.12.8
* Wed Jul 20 2005 jsrain@suse.cz
- added libxml2(-devel) to neededforbuild
- 2.12.7
* Mon Jul 18 2005 sh@suse.de
- Removed @plugindir@/libpy2qt.la from file list in .spec file
  (and removing it after "make install")
* Mon Jul 18 2005 sh@suse.de
- Enable font switching upon UI::SetLanguage()
- V 2.12.6
* Mon Jul 11 2005 sh@suse.de
- Fixed bug #95722: No items in NCurses MultiSelectionBox
- V 2.12.5
* Mon Jul 11 2005 visnov@suse.cz
- Fix build dependencies
- 2.12.4
* Tue Jul  5 2005 sh@suse.de
- Added support for background pixmaps in YQAlignment
- V 2.12.5
* Tue Jul  5 2005 sh@suse.de
- Fixed alignment in YQDumbTab to properly promote stretchability
- V 2.12.4
* Wed Jun 29 2005 sh@suse.de
- Support for `opt(`boldFont) for some widgets:
  - Label
  - ColoredLabel
  - CheckBox
  - RadioButton
* Tue Jun  7 2005 sh@suse.de
- Reverted wizard button order
  (postponed until changes can be done consistently)
- V 2.12.3
* Tue May 10 2005 mlazar@suse.cz
- 2.12.3
* Wed Apr 27 2005 sh@suse.de
- Added support for icons in selection box widget
* Thu Apr 21 2005 sh@suse.de
- Merged selection_widget_cleanups branch to trunk:
  selection widgets can now replace list items
  (SelectionBox, ComboBox, MultiSelectionBox, Tree)
* Fri Apr 15 2005 visnov@suse.cz
- gcc4 fixes
- 2.12.2
* Wed Apr 13 2005 mlazar@suse.cz
- fixed bug 75269 - Can't select different versions of available kernels packages
* Wed Apr  6 2005 visnov@suse.cz
- gcc4 fixes (missing include and forward declaration fix)
- V 2.12.2
* Tue Apr  5 2005 sh@suse.de
- Merged 9.3-branch 21937:22910 to to trunk
- V 2.12.1
* Tue Mar 22 2005 sh@suse.de
- Reverting back to old (SL 9.2) auto font sizes for bug #66498
  (Qt inst-sys default font is reverted to 9.2 font, too)
- V 2.11.13
* Mon Mar 21 2005 sh@suse.de
- One more fix for bug #72799: Help/Steps buttons not translated
- V 2.11.12
* Wed Mar 16 2005 sh@suse.de
- Fixed bug #72799: Help/Steps buttons not translated
  Added setTextdomain() call to YQWizard
- V 2.11.11
* Wed Mar 16 2005 mlazar@suse.cz
- 2.12.1
- implemented feature 100313: Allow switching of color palette at
  runtime in ncurses
* Mon Mar 14 2005 mlazar@suse.cz
- fixed Bug 71815 - yast: unnecessary warning in packager (ncurses)
* Mon Mar 14 2005 mlazar@suse.cz
- NCTextPad.cc: fixed bug 66104: off-by-one error in autoyast
- NCRichText.cc: silently discards all unknown tags (see bug 67319)
* Fri Mar 11 2005 sh@suse.de
- V 2.11.10
- Fixed bug #72174: Installation font too small in 800x600 and 1024x768
* Fri Mar 11 2005 sh@suse.de
- Fixed bug #72158: File selection box on screen shots
- V 2.11.9
* Mon Mar  7 2005 mlazar@suse.cz
- 2.12.0
- fixed bug 67350 - Can't change RPM group in NCurses package manager
  (reverted patch from Tue Nov 23 16:28:41 CET 2004; see also bug 46154)
* Fri Mar  4 2005 sh@suse.de
- Increased calculated font sizes in inst-sys to compensate
  for new (much smaller) default font
- Fixed bug #6649: Japanese, Chinese, Korean chars clipped
- V 2.11.8
* Wed Feb 23 2005 sh@suse.de
- Fallback rule for reverse layout for Arabic and Hebrew
  even if no translations for predefined Qt dialogs are available
* Thu Feb 17 2005 mlazar@suse.cz
- 2.11.3
- redirected stderr and stdout do log (see bug 42155)
* Wed Feb 16 2005 sh@suse.de
- Package selector: Keep width of left pane minimal
* Mon Feb 14 2005 sh@suse.de
- V 2.11.7
- Fixed bug #50468: Segfault if querying current item in empty
  MultiSelectionBox while recording macro
* Fri Feb  4 2005 sh@suse.de
- Fixed full-size dialog size for multihead
* Thu Feb  3 2005 sh@suse.de
- Added empty space below wizard side panel upon explicit request
- V 2.11.6
* Mon Jan 31 2005 sh@suse.de
- V 2.11.5
- Added "Release Notes" button + functions to YQWizard
* Mon Jan 24 2005 sh@suse.de
- Minor usability changes in wizard layout
- Added "add -debuginfo packages" menu action in pkg manager
* Fri Jan 21 2005 mlazar@suse.cz
- 2.11.2
* Wed Dec  8 2004 sh@suse.de
- Added hotkey to switch to a special high-contrast color
  palette for vision impaired users: Shift-F4
* Tue Nov 23 2004 mlazar@suse.cz
- KEY_RETURN open/close subtree in TreeWidget (#31154)
* Tue Nov 23 2004 mlazar@suse.cz
- KEY_SPACE open/close subtree in TreeWidget (#31154)
* Wed Nov 17 2004 sh@suse.de
- Improved YQWizard debugLabel() readability
- V 2.11.3
* Fri Nov  5 2004 sh@suse.de
- Changed save_y2logs key from plain F8 to Shift-F8
* Thu Nov  4 2004 sh@suse.de
- Added F8 hotkey to save y2logs
- V 2.11.2
* Tue Nov  2 2004 nashif@suse.de
- Added new special widgets: YDate / YTime
* Mon Nov  1 2004 mvidner@suse.cz
- Added pkgconfig support.
- 2.11.1
* Thu Oct 28 2004 sh@suse.de
- Fixed bug #46805: Error handling for TextEntry and ComboBox
  with restricted ValidChars
* Thu Oct 28 2004 sh@suse.de
- Fixed bug #43389: Tristate checkbox doesn't send events properly
* Thu Oct 28 2004 sh@suse.de
- Fixed bug #43410: Timer signals close screen shot file selector
* Mon Oct 25 2004 sh@suse.de
- Bumped version to 2.11.0 for 9.3
* Wed Oct  6 2004 sh@suse.de
- Dropped support for hardcoded images "suseheader" and "yast2"
  Use path names and/or the wizard instead!
* Wed Oct  6 2004 sh@suse.de
- Dropped support for hardcoded images "suseheader" and "yast2"
  Use path names and/or the wizard instead!
* Fri Oct  1 2004 sh@suse.de
- Fixed bug #46598: YOU layout broken with 800x600 default size
  Now using 0.7*screen_size as default size
- V 2.10.12
* Wed Sep 29 2004 sh@suse.de
- V 2.10.11
- Fixed bug #45111: Use arrow with clock as busy cursor
* Mon Sep 27 2004 sh@suse.de
- V 2.10.10
- (abauer) fixed bug #44926: Xinerama full screen handling
- (mfabian) fixed unicode fonts
* Fri Sep 24 2004 sh@suse.de
- V 2.10.9
- Fixed bug #45772: software manager segfaults
  Now catching WM_CLOSE events only for dialogs managed by the UI
* Fri Sep 24 2004 sh@suse.de
- V 2.10.8
- Fixed bug #46047: Table columns always too wide in Qt package selection
* Wed Sep 22 2004 sh@suse.de
- Changed yast2-devel-packages to yast2-core-devel-packages
  in neededforbuild
* Tue Sep 21 2004 mlazar@suse.cz
- don't display empty ComboBox (bug #45542)
* Mon Sep 20 2004 mlazar@suse.cz
- 2.10.5
* Fri Sep 17 2004 mlazar@suse.cz
- bug #27296 fixed again
* Wed Sep 15 2004 sh@suse.de
- V 2.10.7
- Added support for ProgressBar with huge numbers (long long)
- Exchanged Unicode font (mfabian)
* Wed Sep 15 2004 sh@suse.de
- V 2.10.4
- Added huge numbers (long long) support (YCPInteger is long long)
  (fix for bug #44680: Progress bar in NCurses UI shows bogus values)
* Tue Sep 14 2004 mlazar@suse.cz
- temporary reverted fix #27296 (not completly fixed)
- removed yast2 from needforbuild
- 2.10.3
* Fri Sep 10 2004 sh@suse.de
- V 2.10.6
- Fixes for right-to-left languages (Arabic/Hebrew)
* Tue Sep  7 2004 mlazar@suse.cz
- fixed nicesize in SelectionBox
* Tue Sep  7 2004 mlazar@suse.cz
- fixed Bugzilla Bug 27296 - provider name displayed wrong
* Tue Sep  7 2004 mlazar@suse.cz
- fixed Bugzilla Bug 44561 - ncurses: weird menu behavior
* Tue Sep  7 2004 mlazar@suse.cz
- fixed bug created during fixing previous bug
* Mon Sep  6 2004 mlazar@suse.cz
- fixed bug #44559 and #44575 - wizard menu in curses is not shown
- 2.10.2
* Mon Sep  6 2004 mlazar@suse.cz
- fixed bug when activate resized panel with new state same as old
  state (in this case panel was not showed)
* Mon Sep  6 2004 mlazar@suse.cz
- 2.10.1
* Mon Sep  6 2004 sh@suse.de
- V 2.10.5
- Applied patch for bug #44145: Package EULA
* Mon Sep  6 2004 mlazar@suse.cz
- patch for confirming license (Bugzilla Bug 44145)
* Fri Sep  3 2004 sh@suse.de
- V 2.10.4
- Fixed bug #44331: Sysconfig editor unusable from kcontrol
* Wed Sep  1 2004 sh@suse.de
- V 2.10.3
- Fixed bug #44579: YMultiProgressBar integer overflow
* Thu Aug 26 2004 sh@suse.de
- V 2.10.2
- Removed obsolete /usr/include/y2qt/ directory from files list
* Mon Aug 23 2004 sh@suse.de
- V 2.10.1
- New widget: MultiProgressMeter
* Wed Jul 21 2004 mlazar@suse.cz
- fixed Bugzilla Bug 35409 - `Top( `Frame() ) without top left corner
* Fri Jul 16 2004 mlazar@suse.cz
- fixed Bugzilla Bug 43005 - Hardware information not shown in ncurses mode
* Thu Jul  8 2004 sh@suse.de
- Fixed bug #42846: Installing unneeded header files
* Thu Jul  8 2004 mlazar@suse.cz
- fixed bug #42736: file selection dialog does not show large files (>1GB)
* Tue Jul  6 2004 sh@suse.de
- Added "Install all matching -devel packages" to pkg selection
  (mmj's idea)
* Tue Jun 29 2004 sh@suse.de
- Fixed bug #39227: Over-long pkg status column after pkg search
  with no results
* Mon Jun 28 2004 sh@suse.de
- Fixed bug #10524: Textentry label overflow
* Mon Jun 28 2004 sh@suse.de
- Fixed bug #40259: package selection hides search widgets
  now using a combo box instead of radio buttons
* Tue Jun 22 2004 mlazar@suse.cz
- fixed bug #42327 (yast2-ncurses abort when resizing window)
* Thu Jun 17 2004 mlazar@suse.cz
- V 2.10.0
- Merged the 9.1 branch
* Wed May 26 2004 sh@suse.de
- Improved support for low-color (<= 8 bit) displays (bug #40228):
  Only use complex wizard pixmaps in high color modes
* Wed May 26 2004 gs@suse.de
- V 2.9.26
- sort the list of package selections (bug #38766)
* Wed May 12 2004 sh@suse.de
- Workaround for bug #35612: Layout problems with 800x600
  Now using smaller fonts in 600x600: 12/14 instead of 14/16
* Wed May 12 2004 gs@suse.de
- V 2.9.25
- handle empty string correctly in NCstring recode methods (bug #40165)
* Fri May  7 2004 gs@suse.de
- V 2.9.24
- file selection: don't overwrite given file name (bug #39189)
* Thu May  6 2004 sh@suse.de
- Fixed bug #40071: Obsolete doc about making screen shots
* Tue May  4 2004 sh@suse.de
- Fixed bug #39846: Strange button layout after RestoreBackButton()
- Fixed bug #39692: Wizard tree and menu item IDs returned in wrong encoding
- V 2.9.24
* Tue May  4 2004 gs@suse.de
- messages from proof reading merged back
* Fri Apr 30 2004 sh@suse.de
- Added new DumbTab widget
- V 2.9.23
* Fri Apr 23 2004 gs@suse.de
- V 2.9.23
- file selection: get correct directory and file name (bug #39189)
- LogView widget: limited size for window (bug #39536)
- prevent the handling of invalid widgets (bug #38700, #37768)
* Tue Apr 20 2004 mvidner@suse.cz
- link against libyui to make loading from Perl work (#39192)
- 2.9.22
* Tue Apr 20 2004 mvidner@suse.cz
- link against libyui to make loading from Perl work (#39192)
- 2.9.22
* Tue Apr 13 2004 gs@suse.de
- V 2.9.21
- accept non-latin1 characters (bug #38348)
* Wed Apr  7 2004 sh@suse.de
- V 2.9.21
- Fixed bug #38603: Excessive wizard headings make buttons disappear
* Tue Apr  6 2004 sh@suse.de
- V 2.9.20
- Fixed bug #36908: Dynamic font sizes during installation
- Fixed bug #37001: Dynamic default window size based on resolution
* Tue Apr  6 2004 sh@suse.de
- V 2.9.19
- Fixed bug #38216: No shortcut check upon Wizard::Set???Button()
* Mon Apr  5 2004 sh@suse.de
- V 2.9.18
- Honor environment variable KCMYAST2_CALL for KControl embedding
  (no wizard decorations, suppress wizard help)
* Mon Apr  5 2004 gs@suse.de
- V 2.9.20
- ignore Ctrl C (bug #37960)
- show title help line correctly (bug #38173)
* Sun Apr  4 2004 adrian@suse.de
- the old (bad) qxembed solution is back .. :/
* Fri Apr  2 2004 sh@suse.de
- License change to GPL
* Fri Apr  2 2004 gs@suse.de
- V 2.9.19
- deactivate logging (bug #37768)
- bugfix in RichText for <pre> tag
- license changed to GPL
* Thu Apr  1 2004 sh@suse.de
- V 2.9.16
- Small fixes for wizard menus + trees
  patch verified by cschum
* Wed Mar 31 2004 sh@suse.de
- Fixed bug #37581: Inconsistent widgets in yast2 modules:
  Added wizard menus and trees
* Wed Mar 31 2004 sh@suse.de
- Implemented YQWizard::currentTreeSelection() for QueryWidget()
* Wed Mar 31 2004 cschum@suse.de
- Do UTF8 conversion for patch kind tooltips (#37584).
* Tue Mar 30 2004 sh@suse.de
- Added tree to wizard side panel (for autoyast, sysconfig-editor)
* Fri Mar 26 2004 gs@suse.de
- V 2.9.18
- YOU mode: bugfix filter for patch kind
- possibility to disable/enable RichText widget
* Mon Mar 22 2004 sh@suse.de
- Fixed bug #36218: Use YaST icons for YaST windows WM decorations
* Mon Mar 22 2004 sh@suse.de
- Fixed bug #35625: Wizard button order
  Restored old button order
* Mon Mar 22 2004 gs@suse.de
- V 2.9.17
- use correct encoding for title help (bug #36506)
* Fri Mar 19 2004 gs@suse.de
- V 2.9.16
- file selection: check for valid group and user (bug #36556)
* Fri Mar 19 2004 sh@suse.de
- Graceful handling for duplicate entries in combo box
* Wed Mar 17 2004 sh@suse.de
- Fixed bug #35645: Wizard layout looks strange
  added HVCenter() around ReplacePoint()
* Tue Mar 16 2004 nashif@suse.de
- #if 0 not working hasSmallDecorations completely
* Tue Mar 16 2004 sh@suse.de
- Minimal approach fix for bug #33584: Show license agreements
- V 2.9.12
* Tue Mar 16 2004 gs@suse.de
- package installation: improve license popup (bug #33584),
  check size of popups (bug #35873),
  bugfix package selections (bug #36541)
* Mon Mar 15 2004 gs@suse.de
- V 2.9.15
- show license (EULA), bug #33584
* Fri Mar 12 2004 sh@suse.de
- Enabled shortcut checking for wizard buttons
- Integrated wizard buttons in YQDialog default button handling
- Adapted to const ref fix in libyui for all widget constructors
- V 2.9.11
* Fri Mar 12 2004 sh@suse.de
- V 2.9.14
- Adapted to const ref fix in libyui for all widget constructors
* Fri Mar 12 2004 gs@suse.de
- V 2.9.13
- bugfix setfont options (YNCursesUI::setConsoleFont)
* Thu Mar 11 2004 sh@suse.de
- Fixed bug #35611: &product; macro not expanded
- Fixed bug #35623: Allow status "protected" for YOU patches
* Wed Mar 10 2004 lnussel@suse.de
- New conflict resolution remove referers (#24306)
- V 2.9.10
* Wed Mar 10 2004 lnussel@suse.de
- package installation: handle downgrade case in dependency popup
* Wed Mar 10 2004 sh@suse.de
- New wizard
- V 2.9.9
* Fri Mar  5 2004 gs@suse.de
- V 2.9.12
- missing #include <y2pm/InstSrcManager.h> added
* Thu Mar  4 2004 sh@suse.de
- Fixed bug #34909: Pkg Mgr "auto-changed pkgs" too large for screen
* Wed Mar  3 2004 gs@suse.de
- V 2.9.11
- messages from proofread merged back
- show text cursor correctly (bug #35055)
* Mon Mar  1 2004 sh@suse.de
- Save screen shot name if recording macro
* Mon Mar  1 2004 gs@suse.de
- V 2.9.10
- package installation: sort list of search results (bug #35060)
- RichText: change colors for bold text and headline (bug #34410)
* Sat Feb 28 2004 sh@suse.de
- V 2.9.5
- more fixes for improved GUI
* Fri Feb 27 2004 visnov@suse.cz
- V 2.9.9
- adapted for the new counted pointers in core
* Sun Feb 22 2004 kkaempf@suse.de
- dont redeclare package pointers
- 2.9.8
* Fri Feb 20 2004 gs@suse.de
- V 2.9.7
- enable the use of cursor keys in radio button boxes
* Tue Feb 10 2004 arvin@suse.de
- include YQWizard.h in tar-ball
* Tue Feb 10 2004 sh@suse.de
- V 2.9.3
- Merged wizard-widget-branch to HEAD with NI
- Misc small fixes
* Wed Feb  4 2004 sh@suse.de
- V 2.9.2
- New embedding: No more QXEmbed, now via KPart (external program)
* Wed Feb  4 2004 gs@suse.de
- V 2.9.6
- change layout files for package/patch installation to work with NI
- remove workaround for missing ACS chars
* Thu Jan 29 2004 sh@suse.de
- Fixed Y2Component handling
* Thu Jan 29 2004 sh@suse.de
- Fixed Y2Component handling (cmd line args etc.)
* Thu Jan 29 2004 arvin@suse.de
- V 2.9.5
- fixed for ncurses 5.4
* Tue Jan 27 2004 sh@suse.de
- V 2.9.1
- Adapted to new interpreter (visnov@suse.cz)
- Adapted to new libyui naming scheme
- Consistent naming scheme
* Tue Jan 27 2004 sh@suse.de
- V 2.9.4
- Reasonable and consistent naming (new interpreter components etc.)
* Fri Jan 16 2004 jsrain@suse.de
- merged the new interpreter branch
* Fri Dec 12 2003 msvec@suse.cz
- adapted for the logging changes in liby2util
- 2.9.3
* Fri Nov 21 2003 gs@suse.de
- V 2.9.2
- don't draw the outer frame in full screen mode
- package installation: show column headers for all package lists
* Fri Nov 14 2003 mvidner@suse.cz
- adapted to doxygen
* Wed Nov 12 2003 gs@suse.de
- V 2.9.1
- provide file selection widgets
- create KeyEvents
- switch to doxygen
* Tue Oct 21 2003 sh@suse.de
- Fixed bug #32510: Excess initial SelBox SelectionChanged event
* Fri Oct 10 2003 sh@suse.de
- V 2.9.0
- Applied cschum's fix for bug #31965:
  Wrong encoding in YOU "display raw package info" dialog
* Mon Sep 22 2003 gs@suse.de
- V 2.8.19
- remove blinking from progress bar (bug #31454)
- show correct patch size in YOU mode (bug #31522)
* Fri Sep 19 2003 sh@suse.de
- V 2.8.15
- Applied visnov's patch to fix bug #5547: IntField value
- Fixed bug #31015 thanks to llunak: "Solving dependencies"
  popup without WM decoreations
* Fri Sep 19 2003 gs@suse.de
- V 2.8.18
- Requires: glibc-locale added to spec-file
* Wed Sep 17 2003 sh@suse.de
- V 2.8.14
* Wed Sep 17 2003 sh@suse.de
- Fixed bug #30236: Bad fullscreen geometry for some window managers
* Wed Sep 17 2003 sh@suse.de
- Fixed bug #31155: Busy cursor in disk space warning dialog
* Wed Sep 17 2003 sh@suse.de
- Fixed bug #30513: Some PkgMgr popup dialogs too large in 640x480
* Wed Sep 17 2003 sh@suse.de
- Fixed bug #31047: File selection dialog untranslated
* Mon Sep 15 2003 sh@suse.de
- V 2.8.13
- Better fix for bug #30500 by jw@suse.de
* Fri Sep 12 2003 sh@suse.de
- V 2.8.12
- Interim fix for bug #30500
* Fri Sep 12 2003 gs@suse.de
- V 2.8.17
- bugfix in RichText widget (bug #30621)
- cut lines in LogView widget (don't allocate too much memory)
- don't use ACS chars on console if locale is not UTF-8 (bug #30512)
- new style for ProgressBar
* Mon Sep  8 2003 gs@suse.de
- V 2.8.16
- new style for not active selection box widget (bug #30035)
* Mon Sep  8 2003 sh@suse.de
- V 2.8.11
- Fixed bug #26494: Keyboard focus when embedded into KControl:
  Reimported the latest version of QXEmbed
* Fri Sep  5 2003 arvin@suse.de
- don't allocate tmp buffer on stack (can be too huge) (bug #29716)
* Fri Sep  5 2003 sh@suse.de
- V 2.8.10
- Fixed bug #30151: Enable starting pkg mgr in search mode
  by default in installed system
* Thu Sep  4 2003 sh@suse.de
- V 2.8.9
- Fixed bug #29529: Package links (again):
  Discard trailing slashes in URL
* Tue Sep  2 2003 gs@suse.de
- online udpate: show included scripts and files
- don't return `cancel after window resize (bug #29853)
* Tue Sep  2 2003 sh@suse.de
- Fixed bug #23660: RichText widget eats [Return]
* Mon Sep  1 2003 sh@suse.de
- Fixed bug #27336: Combo box for YOU patch selection
- Fixed bug #27437: Display YOU pre/post scripts / extra files
* Mon Sep  1 2003 sh@suse.de
- V 2.8.8
- Fixed bug #29529: Package links
* Fri Aug 29 2003 sh@suse.de
- V 2.8.7
- Fixed bug #29603 - fonts.dir should have %%verify in .spec file
* Thu Aug 28 2003 gs@suse.de
- V 2.8.15
- bugfix for wide character support in RichText widget
  (get correct width of text)
- online update: default is list of installable patches
* Wed Aug 27 2003 sh@suse.de
- V 2.8.6
- Removed qApp->unlock() at end of YUIQt constructor:
  No more QMutex warning in log
* Mon Aug 25 2003 gs@suse.de
- V 2.8.14
- package installation: support a link to a related package
  in the package description, bugfix two line messages
- Y2NCursesUI: set environment variable LC_CTYPE
* Mon Aug 18 2003 gs@suse.de
- V 2.8.13
- RichText: support <pre> tag
* Tue Aug 12 2003 gs@suse.de
- V 2.8.12
- bugfix in constructor of NCPopup...-classes (don't add child
  widgets twice)
* Tue Aug 12 2003 gs@suse.de
- V 2.8.5
- merge texts from proofread
* Mon Aug 11 2003 gs@suse.de
- V 2.8.11
- texts from proofread patched back
- SelectionBox returns ValueChanged event
- show patch/package description on KEY_PPAGE/KEY_NPAGE
* Tue Aug  5 2003 gs@suse.de
- V 2.8.10
- get correct encoding in setConsoleFont(),
- setKeyboard() added
* Mon Jul 28 2003 gs@suse.de
- V 2.8.9
- support &product; in RichText (automatically replace the product info)
* Fri Jul 25 2003 gs@suse.de
- V 2.8.8
- set terminal encoding in constructor Y2NCursesUI::Y2NCursesUI;
* Wed Jul 16 2003 gs@suse.de
- V 2.8.7
- fix RPM build error: Installed (but unpackaged) file(s) found:
  /usr/lib/YaST2/bin/y2ncurses
* Wed Jul 16 2003 gs@suse.de
- V 2.8.6
- remove obsolete enum from Y2NCursesUI.h
* Tue Jul 15 2003 sh@suse.de
- V 2.8.4
- Lots of internal reworking
- Completely reworked event handling
- No more self-generated events during widget creation / ChangeWidget
- Basic support for right-to-left languages like Arabic / Hebrew
  (not perfect yet)
* Wed Jul  9 2003 gs@suse.de
- V 2.8.5
- adapt ncurses-UI to UTF-8 support
- use advanced event handling
* Tue Jun 10 2003 sh@suse.de
- V 2.8.3
- Don't build obsolete standalone server component "qt" any more
- Don't install header files: they are not packaged anyway
* Wed Jun  4 2003 sh@suse.de
- V 2.8.2
- Fixed yet another ambituous overload due to changed Qt lib
* Wed May 28 2003 ma@suse.de
- V 2.8.4
- Fixes for creating and drawing dialogs on verry small terminals.
* Tue May 27 2003 ma@suse.de
- V 2.8.3
- Prettify dialog shaddows (#27018)
* Mon May 26 2003 ma@suse.de
- V 2.8.2
- Fixed handling of resize events (#13272)
* Fri May 23 2003 sh@suse.de
- Fixed build problems due to new Qt lib (ambiguous overload)
- V 2.8.1
* Tue May 20 2003 gs@suse.de
- package installation: additional filter view "Installed Packages",
  installation of source packages (SRPMs), improved dependency popup
* Wed Apr 30 2003 ma@suse.de
- Fixed list indentation in RichText widget (#18204)
* Thu Apr 10 2003 sh@suse.de
- Fixed bug #25419: Qt PkgMgr shows correct version downgrades red
* Tue Apr  8 2003 sh@suse.de
- Fixed bug #26155: Hiding YOU patches marked for update
* Wed Mar 12 2003 sh@suse.de
- Don't force *.sel extension for pkg lists
* Wed Mar 12 2003 sh@suse.de
- Enable mounting floppy for pkg list import / export
* Tue Mar 11 2003 gs@suse.de
- V 2.7.13
- package installation: check dependencies at startup (bug #25011),
  fixed typo in help text
* Mon Mar 10 2003 sh@suse.de
- Fixed bug #25011: Force dependency check on startup in PkgMgr
* Mon Mar 10 2003 sh@suse.de
- Update disk usage in PkgMgr after selection dependency solving
* Mon Mar 10 2003 sh@suse.de
- V 2.7.15
- Fixed bug #24981: Can't search for non-ASCII chars in Qt PkgMgr
* Fri Mar  7 2003 gs@suse.de
- V 2.7.12
- package installation: bugfix for not translated messages (#24834),
  update required diskspace after dependency solving
* Thu Mar  6 2003 sh@suse.de
- Fixed bug #24615: "checking dependencies" popup not centered
* Wed Mar  5 2003 sh@suse.de
- Fixed bug #24707: QListView tooltips only on right scroll bar
* Tue Mar  4 2003 gs@suse.de
- NCstyle.braille.h added to Makefile.am
* Mon Mar  3 2003 gs@suse.de
- V 2.7.11
- get the floppy device to save/load package selections (bug #23923)
* Fri Feb 28 2003 sh@suse.de
- V 2.7.14
* Fri Feb 28 2003 sh@suse.de
- Fixed bug #22513 - language selection loses some key events
* Fri Feb 28 2003 sh@suse.de
- Use new 'floppyDevice' parameter for PackageSelector
* Fri Feb 28 2003 sh@suse.de
- Fixed bug #24388: YQFrame repaint one pixel off in both dimensions
* Thu Feb 27 2003 sh@suse.de
- Fixed bug #24445: Missing status update when importing pkg list
* Thu Feb 27 2003 sh@suse.de
- Fixed bug #23368: kcontrol embedding fails if first dialog is a popup
* Wed Feb 26 2003 sh@suse.de
-  Fixed bug #23574: "Checking dependencies" popup
* Wed Feb 26 2003 ma@suse.de
- Support unsing a different styleset for Braille-Users. Activated, if
  environmentvariable Y2_BRAILLE is set.
* Wed Feb 26 2003 sh@suse.de
- Fixed bug #24274: Wrong disk initial usage display
* Tue Feb 25 2003 sh@suse.de
- Workaround for bug #24088: Leftover busy cursor in root window
* Tue Feb 25 2003 sh@suse.de
- Fixed bug #24255: Multiple search in yast2-qt package
* Tue Feb 25 2003 gs@suse.de
- package installation: restore the package manager state on Cancel,
  show a warning popup, show file list for installed packages
* Tue Feb 25 2003 sh@suse.de
- Fixed wrong tool tip "this version is installed in your system"
  (for all versions) in package manager "versions" view
* Tue Feb 25 2003 sh@suse.de
- Fixed bug #23855: Asking for loading Modules does not have focus
* Mon Feb 24 2003 ma@suse.de
- V 2.7.10
- Implemented opt(immediate) for SelectionBox. If set together with
  opt(notify), userInput is triggered on selection bar movement too.
- Do not trigger UserInput for empty SelectionBox/Table/Tree, if
  SPACE was pressed. (#24023)
* Mon Feb 24 2003 sh@suse.de
- V 2.7.13
- Fixed bug #23923: Can't save package selection
* Mon Feb 24 2003 gs@suse.de
- V 2.7.9
- package installation: save and load package selections (bug #23923)
* Fri Feb 21 2003 gs@suse.de
- package installation: display a list containing all packages which
  will be installed automatically (bug #23770)
* Thu Feb 20 2003 sh@suse.de
- Fixed bug #23868: Handle preformatted notify texts
* Thu Feb 20 2003 sh@suse.de
- "Obsolete" dependency conflicts cannot be ignored
  (RPM always deletes the obsoleted package)
* Thu Feb 20 2003 sh@suse.de
- Fixed bug #23914: Package manager crashes when opening "package"
  menu and package list is empty (e.g., empty search result)
* Thu Feb 20 2003 gs@suse.de
-- display correct formatted text in notify popups (bug #23868)
* Wed Feb 19 2003 sh@suse.de
- Fixed bug #23755: Busy cursor in file selection dialogs
* Wed Feb 19 2003 sh@suse.de
- Fixed bug #23654: Window partially invisible
* Wed Feb 19 2003 sh@suse.de
- Fixed bug #23770: Always show automatically selected pkgs, even
  during base installation
* Tue Feb 18 2003 gs@suse.de
- draw the progress bar correctly (bug #23189)
* Tue Feb 18 2003 ma@suse.de
- Filter character entities in richtext widget (&[amp|gt|lt|nbsp|quot];)
  (#23721)
* Tue Feb 18 2003 sh@suse.de
- New "protected" icons by Ken
* Mon Feb 17 2003 sh@suse.de
- V 2.7.12
- Fixed broken "protected" actions
- Fixed preliminary "protected" icons
* Mon Feb 17 2003 gs@suse.de
- V 2.7.8
- setLanguage: never set encoding to UTF-8 (bug #23348)
- package installation: show more package info, improved
  selection popup, show total download size in YOU mode
* Fri Feb 14 2003 sh@suse.de
- V 2.7.11
- Fixed bug #23577: Popups can be clicked into the background
* Fri Feb 14 2003 sh@suse.de
- Fixed bug #23650: Confusion about "Export List to Text File":
  Moved this function from "Extras" menu to package list context
  menu
- Disabled pkg status "protected" for selections / YOU patches
* Thu Feb 13 2003 ma@suse.de
- Let all widgets respond to UI enable/disable requests.
- Let Frames enable/disable all widgets in it (#22471)
* Thu Feb 13 2003 sh@suse.de
- Suppress "YaST2@linux" window title (bug #23584)
* Thu Feb 13 2003 sh@suse.de
- Improved default button behaviour
- Removed junk logging
* Mon Feb 10 2003 sh@suse.de
- V 2.7.10
- New package status "protected"
* Mon Feb 10 2003 sh@suse.de
- V 2.7.9
- Don't force Unicode font
- Show different icons in package manager for autoinstall etc. by
  selection and autoinstall etc. by dependencies
* Mon Feb 10 2003 gs@suse.de
- V 2.7.7
- package installation: allow status "Taboo" for installed packages,
  provide the save/load settings popup (not yet finished)
* Fri Jan 31 2003 sh@suse.de
- V 2.7.8
- Adapted to changed PkgDep::RelInfo API
* Fri Jan 31 2003 gs@suse.de
- V 2.7.6
- package installation: dependency popup improved (it is possible to
  ignore dependencies); show used/free/total disk space;
  show error popup if disk space is exhausted
* Thu Jan 30 2003 ma@suse.de
- Widgets beeping on illegal keyboard input (NCIntField|NCTextEntry|NCTextPad)
  must handle KEY_HOTKEY, otherwise they beep on hotkey activation. (#23198)
* Wed Jan 29 2003 sh@suse.de
- V 2.7.7
- User messages back from proofreading
- Show auto-packages on demand in package manager
* Mon Jan 27 2003 sh@suse.de
- V 2.7.6
- Added "rpm-devel" to "neededforbuild"
- Support enabling/disabling for container widgets as well
- Show "auto changes" popup in package manager
- YOU mode package manager changes:
  - Show total download size
  - Dropped "Packages" menu (pkgs are read-only there)
  - Added "YOU Patches" menu instead
  - Addes "Show raw patch info" dialog
* Mon Jan 27 2003 gs@suse.de
- V 2.7.5
- rpm-devel added to neededforbuild
- package installation: show dependencies between package selections
* Tue Jan 21 2003 sh@suse.de
- V 2.7.5
- Use textdomain "qt-packages" for all texts to avoid textdomain
  name clashes
- New command line options --fullscreen, --noborder
- Fixed busy cursors
* Mon Jan 20 2003 sh@suse.de
- Package manager enhancements:
  - Enhanced feedback while checking dependencies
  - Changed default to "off" for auto dependency check
  - Save/load ignored dependency conflicts to/from
    /var/adm/YaST/ignored-conflicts
- Bumped version to 2.7.4
* Tue Jan 14 2003 sh@suse.de
- Package manager enhancements:
  - Added menu bar
  - Added bubble help for all kinds of lists
  - Rearranged pkg list columns (moved summary left)
  - Re-enabled source RPM handling
  - Added currently installed version to "versions" view
    (non-editable)
  - Status change actions for "all in current list"
  - Show disk space for all available partitions
  - Added "installation summary" filter view
  - Dependency checking now for selections, too
  - Added symbols help
  - Added special keys help
  - Auto check is now "off" by default
- Bumped version to 2.7.3
* Tue Dec  3 2002 arvin@suse.de
- added curl-devel and openssl-devel to neededforbuild
* Tue Dec  3 2002 arvin@suse.de
- added curl-devel and openssl-devel to neededforbuild
* Fri Nov 29 2002 gs@suse.de
- V 2.7.3
- function key handling enabled
- improvements for package installation dialog
* Tue Nov 26 2002 gs@suse.de
- V 2.6.24
  online update: better format for patch descriptions
  (preserve newlines)
* Thu Nov 14 2002 ma@suse.de
- V 2.7.2
- Fixed bug that inhibits logging on big-endian architectures.
* Thu Nov 14 2002 ma@suse.de
- V 2.6.23
- Fixed bug that inhibits logging on big-endian architectures.
* Wed Nov 13 2002 gs@suse.de
- V 2.6.22
- package installation: package categories which will be installed
  are selected in Filter/Selections menu (bug #21700)
* Mon Nov 11 2002 sh@suse.de
- Support for buttons with icons and text
* Fri Nov  8 2002 sh@suse.de
- Fixed bug #20326: [Cancel] doesn't abandon changes in package mgr
* Thu Nov  7 2002 sh@suse.de
- Fixed bug #16339: [Space] doesn't trigger UserInput() in YTable
* Thu Nov  7 2002 sh@suse.de
- Fixed bug #20539: Screen shot function causes unnecessary exits
- Fixed bug #8362:  File selection box for screen shots
- Fixed possible security hole: Screen shots in /tmp by default
* Thu Nov  7 2002 sh@suse.de
- Fixed bug #19389: Frame widget shows keyboard shortcuts, but
  can't handle any
* Thu Nov  7 2002 sh@suse.de
- Fixed bug #19389: Frame widget shows keyboard shortcuts, but
  can't handle any
* Mon Oct 21 2002 gs@suse.de
- V 2.6.21
- package installation: show correct package dependencies in case of
  package conflicts (bug #21045/#21061), show the license
* Wed Oct  9 2002 gs@suse.de
- V 2.6.20
- package installation: show the source of installation in the list
  of available packages (bug #20734)
* Fri Sep 20 2002 msvec@suse.cz
- added missing textdomain
- added missing files to POTFILES
- 2.6.23
* Wed Sep 18 2002 gs@suse.de
- V 2.6.19
- package installation: update the required disk space info
  if selections are selected/deselected (bug #19770),
  show translated summary of installed packages and
  the selections, toggle the package status with space key,
  layout of search popup changed (headline was truncated)
  (bug #19725)
* Fri Sep 13 2002 sh@suse.de
- V 2.6.22
- Disabled selecting source RPMs until it works further down
* Thu Sep 12 2002 sh@suse.de
- V 2.6.21
- Show DelNotify popup even if pkg not installed yet
- Fixed bug #19333: Can't get out of pkg dialog with "Accept"
* Thu Sep 12 2002 gs@suse.de
- V 2.6.18
- package installation: show the delete notify also if a package
  is deselected or is set to status taboo
* Wed Sep 11 2002 sh@suse.de
- Fixed bug #19419: Y2Pkg hangs on middle mouse click
  This is really a Qt bug. Introduced workaround for that.
* Wed Sep 11 2002 sh@suse.de
- Fixed bug #19390: Sometimes no keyboard focus without a mouse
* Tue Sep 10 2002 sh@suse.de
- V 2.6.19
* Tue Sep 10 2002 sh@suse.de
- Fixed sort by source RPM status in pkg list
* Tue Sep 10 2002 sh@suse.de
- Change packager priorities: Prefer candidateObj over installedObj
  so the user gets to see his native language more often in pkg
  descriptions (RPM DB is English only)
* Tue Sep 10 2002 sh@suse.de
- V 2.6.18
- New details view: Dependencies
- Bugfix: No initial dependency check in YOU mode
- Show patch sizes in YOU mode
* Tue Sep 10 2002 gs@suse.de
- V 2.6.17
- package installation: bugfix duplicate search results (#19342)
- YOU: don't check package dependencies
* Tue Sep 10 2002 sh@suse.de
- V 2.6.17
- Fixed 'Accept doesn't leave pkg selection' bug
- New view for selecting different versions to install
* Tue Sep 10 2002 gs@suse.de
- V 2.6.16
- package installation: show the required disk space,
  do an initial dependency solving, allow status change autoinstall -> taboo
- bugfixes YOU: deselect works, don't check dependencies
* Mon Sep  9 2002 sh@suse.de
- V 2.6.16
- Prepared disk usage display (still disabled for internal reasons)
- Lots of small fixes
* Mon Sep  9 2002 sh@suse.de
- Fixed minimumSize() hints for YQPkg* - works now in 640x480
- Special icon for delete pkg conflict (tackat)
- Brighter colors for over-long conflict lists ("999 more...")
* Mon Sep  9 2002 gs@suse.de
- V 2.6.15
- package installation: improved dependency checking
* Mon Sep  9 2002 sh@suse.de
- V 2.6.15
  Package manager changes:
- Really ignore conflicts when user chooses so
- Auto dependency check on startup
- "Ignore All" button in dependency conflict dialog
- Show InsNotify / DelNotify
- Search for provides / requires
- Search immediately upon [Return]
- Show pkgs without any RPM group in "zzz All"
- Ignore WM_CLOSE for package selection
- Prepared translation stuff
* Sun Sep  8 2002 gs@suse.de
- V 2.6.14
- package installation: improved performance for large lists,
  search ignore case works, search in summary
* Sat Sep  7 2002 gs@suse.de
- V 2.6.13
- package installation: show a popup during dependency checking,
- search in package names
* Fri Sep  6 2002 gs@suse.de
- V 2.6.12
- package installation: dependencies popup improved,
- show the "update problem" list
* Fri Sep  6 2002 sh@suse.de
- V 2.6.14
- Search view
- Update problem list view
- Misc minor stuff
* Thu Sep  5 2002 sh@suse.de
- V 2.6.13
- Dependency resolving works - including conflicts
* Thu Sep  5 2002 gs@suse.de
- V 2.6.11
- package installation: show conflict dependencies (still not
  yet finished)
* Thu Sep  5 2002 gs@suse.de
- V 2.6.10
- package installation: return `cancel and `accept
- show the package dependencies (not yet completed)
- set status to taboo is possible now
* Tue Sep  3 2002 gs@suse.de
- V 2.6.9
- old behaviour of SelectionBox (notify only on return, space)
- package installation: status change respects previous status,
  toggle status enabled
- online udpate: new layout, correct status change
* Mon Sep  2 2002 sh@suse.de
- V 2.6.12
- Fixed crash with inconsistent YOU data
* Mon Sep  2 2002 sh@suse.de
- V 2.6.11
- Fixed confusing selection status handling
* Mon Sep  2 2002 sh@suse.de
- V 2.6.10
- Generalized internal pkg classes
- YOU UI now usable
- colorized lists
- context menus
- lots of small stuff
* Wed Aug 28 2002 gs@suse.de
- V 2.6.8
- SelectionBox respects `opt(`notify)
* Tue Aug 27 2002 sh@suse.de
- V 2.6.9
- Pkg selection now usable (no dependency checking/solving yet)
* Tue Aug 27 2002 gs@suse.de
- V 2.6.7
- package installation: show more package information,
  select/deselect selections
* Mon Aug 26 2002 gs@suse.de
- V 2.6.6
- package installation: set the package status
* Sat Aug 24 2002 gs@suse.de
- V 2.6.5
- package installation: get rpm goups and selections,
  enable YOU mode
* Wed Aug 21 2002 kkaempf@suse.de
- fix "make dist"
- V 2.6.8
* Wed Aug 21 2002 gs@suse.de
- V 2.6.4
- popup added (beta version), more logging
* Mon Aug 19 2002 sh@suse.de
- V 2.6.3
- New package management
* Mon Aug 19 2002 sh@suse.de
- V 2.6.7
- New package management
* Fri Aug  9 2002 sh@suse.de
- V 2.6.6
- Fixed table sorting with `opt(`keepSorting)
* Sat Aug  3 2002 arvin@suse.de
- write qt warnings to y2log (bug #17161)
* Mon Jul 15 2002 arvin@suse.de
- workaround for timing problem
* Mon Jul  8 2002 mvidner@suse.cz
- Provides/Obsoletes also the devel subpackage
* Wed Jul  3 2002 msvec@suse.cz
- devel sub-package not neeeded
* Wed Jul  3 2002 msvec@suse.cz
- devel sub-package not neeeded
* Mon Jun 24 2002 arvin@suse.de
- renamed from yast2-ui-ncurses to yast2-ncurses
* Mon Jun 24 2002 arvin@suse.de
- renamed from yast2-ui-qt to yast2-qt
* Thu Jun  6 2002 arvin@suse.de
- don't link -lstdc++ explicitly
* Fri May 24 2002 arvin@suse.de
- fixed locking so we can use multi threaded version of qt
* Wed Apr 24 2002 arvin@suse.de
- fixed paths for x86-64
* Mon Apr  8 2002 arvin@suse.de
- fixes for gcc 3.1
* Fri Mar 22 2002 kkaempf@suse.de
- pass callback information from component stub to interpreter
  (#15311).
* Fri Mar 22 2002 kkaempf@suse.de
- pass callback information from component stub to interpreter
  (#15311).
* Mon Mar 11 2002 ma@suse.de
- version to 2.5.14
- Prevent '<li><p>' from opening a new line. Disable first line
  indentation for indented paragraphs. (#14816)
* Fri Mar  8 2002 ma@suse.de
- version to 2.5.13
- fixed bad text layout in RichText (#14395)
- regard libyui hint, and supress screen upadtes while a ReplacePoints
  content is exchanged.
* Tue Mar  5 2002 kkaempf@suse.de
- Better vertical space usage in RichText widget:
  Suppress implicit <br> after </hX> (end header tag) if
  <ol> or <ul> (begin list tag) follows, since lists always
  start on a new line. This makes i.e the package installation
  widget display the package name and label in 4 lines instead
  of 6.
* Tue Mar  5 2002 kkaempf@suse.de
- Suppress "(none)" as hostname in title bar.
* Mon Feb 25 2002 sh@suse.de
- V 2.5.16
- Applied Michal Svec's security patch
* Mon Feb 25 2002 sh@suse.de
- V 2.5.15
- Fixed wish #13876: Host name in window title bar
* Mon Feb 25 2002 ma@suse.de
- version to 2.5.10
- show hostname in title line
* Sun Feb 24 2002 ma@suse.de
- version to 2.5.9
- Removed some superflous mention of of default arguments in
  function definitions. In addition one definition didn't
  comletely match the declaration. At least gcc3 is so kind to
  report this incident.
* Fri Feb 22 2002 ma@suse.de
- version to 2.5.8
- Revert behaviour of `opt(`notify). UserInput is triggered iff <SPACE>
  or <RETURN> ist pressed. There's too much ycp code, that otherwise breaks.
* Wed Feb 20 2002 ma@suse.de
- version to 2.5.7
- Changed `opt(`notify) for Table, Lists and Tree. Should behave
  more like qt now. UserInput is now triggered not only if you
  explicitly select an item by pressing <SPACE> or <RETURN>, but
  also if the highlighted item changes.
* Wed Feb 20 2002 ma@suse.de
- version to 2.5.6
- Fixed screen update. Some widgets changes became not immediatelty
  visible, if dialog is not waiting for userinput. (#13335)
* Wed Feb 20 2002 sh@suse.de
- V 2.5.14
- Fixed bug #13604: Change fallback title image to new design
* Mon Feb 18 2002 sh@suse.de
- V 2.5.13
- Fixed bug #13131: SetFocus on a TextEntry should select its contents
* Fri Feb 15 2002 kkaempf@suse.de
- "utf-8" -> "UTF-8" for iconv (#13276).
* Thu Feb 14 2002 schwab@suse.de
- Fix for gcc 3.1.
- Remove ia64 workaround.
* Thu Feb 14 2002 sh@suse.de
- V 2.5.12
- Fixed changed Qt-3 behaviour: Correct handling for tristate
  checkbox
* Wed Feb 13 2002 sh@suse.de
- V 2.5.11
- Fixed ColoredLabel alignment: Left and vertically centered
* Fri Feb  8 2002 sh@suse.de
- V 2.5.10
- New YQImage constructor: Load images locally from within the UI
- Support YQImage `opt(`tiled, `scaleToFit)
- Load images in background pixmap
* Fri Feb  8 2002 sh@suse.de
- version to 2.5.4
- added filename constructor to NCImage
* Thu Feb  7 2002 ma@suse.de
- version to 2.5.3
- fixed IntField: Number entry popup popped down too early.
- fixed CheckBox: Redwaw sometimes left vestiges.
- removed usage of BLINK attribute, as it realy blinks on some
  xterm's and normal VGA linux console.
* Thu Feb  7 2002 sh@suse.de
- V 2.5.9
- Better check for YaST2 special keys (Ctrl-Shift-Alt)
* Sat Jan 26 2002 ma@suse.de
- version to 2.5.2
- libyui now is able to tell that multiple drawing operations will
  be performed, so we can avoid superfluous screen updates. This
  speeds up building of large tables, as used in single package
  selection.
* Fri Jan 25 2002 sh@suse.de
- V 2.5.8
- Added MNG support for Image widget
* Thu Jan 24 2002 ma@suse.de
- version to 2.5.1
- fixed `opt(`notify) not working for TextEntry (#12237)
- fixed Frame widget discarding accelerator. Now a Frame activates
  the first appropriate child found. (#10458 )
- new: RichText now supports headlines, ordered and unorderd lists
  and hyperlinks.
- (almost) all widget attributes are now managed by NCStyle class.
  This makes it easier to create introduce new skins.
* Thu Jan 24 2002 sh@suse.de
- V 2.5.6
- New optional widget: ColoredLabel
* Tue Jan 22 2002 sh@suse.de
- V 2.5.6
- Support new `opt(`keepSorting) for YTable widget
* Tue Jan 22 2002 sh@suse.de
- Show initial selection (first item)
* Tue Jan 22 2002 sh@suse.de
- Fixed bug #12833: Arbitrary table sorting with Qt3
* Tue Jan  8 2002 sh@suse.de
- V 2.5.5
- Added qt3-non-mt to neededforbuild
* Fri Dec 14 2001 sh@suse.de
- V 2.5.4
- Ported to Qt 3.x
* Tue Dec 11 2001 sh@suse.de
- V 2.5.3
- Added hyperlink support to RichText widget
* Thu Nov 15 2001 sh@suse.de
- V 2.5.2
- added proper #include for tolower()
* Fri Nov  9 2001 ro@suse.de
- use qt-devel-packages in neededforbuild
* Tue Nov  6 2001 sh@suse.de
- V 2.5.1
- Fixed YQPushButton for automatic shortcut check / resolving
* Wed Oct 10 2001 ma@suse.de
- version to 2.5.0
- fix: usage of va_args on ppc caused segmentation fault.
* Thu Sep 27 2001 sh@suse.de
- Fixed bug #11350: WM close button closes win, but keeps app alive
* Mon Sep 24 2001 sh@suse.de
- Don't set root window cursor to busy cursor
- V 2.4.17
* Fri Sep 21 2001 sh@suse.de
- Fixed bug #11073: busy cursor unreliable
  The Qt UI now makes its own busy cursors rather than Qt's.
- V 2.4.16
* Tue Sep 18 2001 sh@suse.de
- Fixed bug #8534: Spurious <b> </b> in SuSEconfig protocoll
- V 2.4.15
* Mon Sep 17 2001 sh@suse.de
- Fixed bug #10754: Large popup windows partially invisible
- V 2.4.14
* Fri Sep 14 2001 sh@suse.de
- Fixed bug #10614: Ikea mode triggered on Alt-W
- Consistent default button handling even in selbox
- V 2.4.13
* Wed Sep 12 2001 sh@suse.de
- Only one window for all `opt(`defaultsize) dialogs
- Fixed bug #9915: Default button keyboard focus unreliable
- V 2.4.12
* Sun Sep  9 2001 ma@suse.de
- fix: setFocus reported an error if the widget already has the
  focus.
* Fri Sep  7 2001 ma@suse.de
- version to 2.4.5
- UI-specific getDisplayInfo() functions added
* Thu Sep  6 2001 sh@suse.de
- V 2.4.11
  Implemented new UI builtin: GetDisplayInfo()
* Wed Sep  5 2001 sh@suse.de
- V 2.4.10
  All headers "ydoc" compliant - fixed build problems
* Tue Sep  4 2001 sh@suse.de
- V 2.4.9
  improved focus handling - (possible) fix for bug #9915
* Tue Aug 21 2001 ma@suse.de
- fixes to compile with gcc 3.0
* Fri Aug 17 2001 ma@suse.de
- version to 2.4.4
- new: Hotkeys and BackTab (<ESC-key>/<ESC-TAB>) (#8448)
- new: May restrict input characters in TextEntry (#8357)
- new: MenuButton widgets
- fix: Comobox didn't send notify
- fix: Unused special keys (e.g. FKeys,Cursor) in MultiLineEdit
  produced garbage input.
- changed: No more auto disabling of nonscrollable (text fits in
  widget) RichText and LogView. Next step will be to provide zoom
  and collapse function.
- changed: Navigation in Tree. Curs-Left/Right either collapse/expand
  current entry if possible or move to previous/next item otherwise.
  Not both in on step.
* Wed Jul 11 2001 ma@suse.de
- version to 2.4.3
- fixed setConsoleFont(). 'setfont' and 'magic char echo' now
  explicitly use the same tty ncurses opened at startup.
* Wed Jul 11 2001 sh@suse.de
- V 2.4.8
  added glyph support (for new UI builtin Glyph() )
* Tue Jul 10 2001 ma@suse.de
- version to 2.4.2
- new widget: MultiSelectionBox
- fixes in font switching
* Sat Jul  7 2001 arvin@suse.de
- neededforbuild += freetype2
* Thu Jul  5 2001 kkaempf@suse.de
- drop yast2-core-translator from neededforbuild
* Wed Jun 27 2001 sh@suse.de
- V 2.4.5
  New widget: MultiSelectionBox
* Tue Jun 26 2001 sh@suse.de
- V 2.4.4
  New widget: MenuButton
* Tue Jun 19 2001 sh@suse.de
- Implemented wish #8357: Restrict input characters
  new widget property `ValidChars for TextEntry, ComboBox
* Tue Jun 19 2001 kkaempf@suse.de
- implement callback mechanism
- version 2.4.1
* Tue Jun 19 2001 kkaempf@suse.de
- implemented callback mechanism
* Tue Jun 12 2001 sh@suse.de
- V 2.4.2
  Changed BarGraph variable substitution from "%%d" to "%%1"
  to become sformat() compatible
* Fri Jun  8 2001 sh@suse.de
- V 2.4.1
- Implemented wish #7259: Automatically set `opt(`decorated)
  for non-defaultsize dialogs
- Implemented wish #8363: UserInput() returns special ID
  'debugHotkey when Ctrl-Alt-Shift-D is pressed
* Fri Jun  8 2001 sh@suse.de
- V 2.4.0
  Macro recorder
* Mon May 14 2001 sh@suse.de
- V 2.3.14: Fixed bug #8254, 2nd part: Bad czech charset in resizer
  Work around QString::sprintf() limitations (Latin1 compatible
  only), use QString::arg() instead
* Mon May 14 2001 sh@suse.de
- V 2.3.13: Fixed bug #8254: Bad czech charset in resizer
  Added fromUTF8() call for explicit string conversion
* Fri May 11 2001 kendy@suse.cz
- version 2.3.12
- fixed switching of fonts: czech language was unreadable
  (not reported bug)
* Fri May 11 2001 kkaempf@suse.de
- version to 2.3.11
- add split-alias entries to specfile (#8133)
* Fri May 11 2001 ma@suse.de
- version to 2.3.10
- fixed: ComboBox now shows 1st entry if no default provided (#8072)
- fixed: TextEntry en/disabling was unfunctional (#8072)
* Tue May  8 2001 kkaempf@suse.de
- provide split-alias entries for older versions
* Mon Apr 30 2001 kkaempf@suse.de
- provide "YaST2-UI"
* Mon Apr 30 2001 kkaempf@suse.de
- only -devel provides y2curses
* Mon Apr 30 2001 ma@suse.de
- let yast2-ui-ncurses provide 'YaST2-UI'
* Mon Apr 30 2001 ma@suse.de
- version to 2.3.8
- log tty detection in ncurses init as milestone
* Mon Apr 30 2001 sh@suse.de
- V 2.3.10
  (partial) fix for bug #7004:
  Top-left align image in YImage widgets
* Wed Apr 25 2001 ma@suse.de
- don't return an error if setfont fails, as the calling libyui
  function isn't able to make anything usefull out of it.
* Thu Apr 19 2001 sh@suse.de
- V 2.3.9
  Fixed bugs in RadioBox behaviour:
  - second click on the same button will no longer deactivate it
  - accept only one active RadioButton on RadioBox creation
    (all but the last will be deactivated)
* Tue Apr 17 2001 ma@suse.de
- version to 2.3.7
- new color scheme.
* Thu Apr 12 2001 sh@suse.de
- V 2.3.8
  Improved RadioBox keyboard navigation:
  No longer rely on QButtonGroup, own implementation of RadioBox
  behaviour -> no longer strange key mappings (cursor keys rather
  than tab as everybody expects)
* Wed Apr 11 2001 schwab@suse.de
- Fix ambiguous call to string::insert.
* Thu Apr  5 2001 sh@suse.de
- new options zeroWidth, zeroHeight for image widget
  to avoid complaints about title graphics not getting their
  "nice size" of 2000 pixels wide
- V 2.3.7
* Wed Apr  4 2001 ma@suse.de
- version to 2.3.6
- fixed tree widget to expand/hide subtrees
- fixed richtext widget to recognize html tags with arguments and
  handle '&nbsp;'
* Fri Mar 30 2001 kkaempf@suse.de
- dont install lib, only plugin is needed
* Thu Mar 29 2001 sh@suse.de
- moved shared libs from /usr/lib/YaST2/lib to /usr/lib
- V 2.3.5
* Thu Mar 29 2001 kkaempf@suse.de
- dont install lib, only plugin is needed
* Tue Mar 27 2001 kkaempf@suse.de
- minimize file list for yast2-ui-qt package
* Mon Mar 26 2001 ma@suse.de
- added missing 'const' in previous fix
* Fri Mar 23 2001 ma@suse.de
- version to 2.3.5
- fixed dirty hack in NCurses.cc, using NCursesPanel's private
  'typedef struct UserHook;'.
* Fri Mar 23 2001 arvin@suse.de
- moved documentation to packages/yast2-ui-qt
* Thu Mar 22 2001 ma@suse.de
- version to 2.3.4
- allow multiline labeltexts for RadioButton and PushButton (#6711)
- let ComboBox's list popup appear below value field (not centered
  on screen)
- provide a TextEntry popup in IntField, to manually enter a value
* Sun Mar 18 2001 ro@suse.de
- fixed neededforbuild
* Mon Mar 12 2001 arvin@suse.de
- version to 2.3.3
- Strip plugin in package.
* Mon Mar 12 2001 arvin@suse.de
- Strip plugin in package.
* Thu Mar  8 2001 arvin@suse.de
- Added unicode fonts (previously in y2base).
* Thu Mar  8 2001 ma@suse.de
- package name changed from y2curses(old) to yast2-ui-ncurses(new).
* Fri Feb 23 2001 ma@suse.de
- setLanguage now sets a proper defaultEncoding. At startup the
  defaultEncoding is set according to ${LANG}.
- The default 'language to encoding' mapping is stored in the
  script 'lang2encoding.tab' which generates 'lang2encoding.cc'.
- Evaluation of ${Y2NCURSES_ENCODING} has been removed.
* Fri Feb 23 2001 ma@suse.de
- version to 2.3.2
- moved class NCstring back from libyui.
* Thu Feb 22 2001 ma@suse.de
- initiate NCurses::Redraw for _all_ visible dialogs on encoding
  change.
- Y2NCursesUI constructor will set the defaultEncoding to the value
  of Y2NCURSES_ENCODING environment variable, if present. Might be
  helpfull for testing until some other y2 part sets the encoding
  according to the LANG variable.
* Wed Feb 21 2001 ma@suse.de
- version to 2.3.1
- adjustments to new libyui(NCstring) interface
- various changes to get a correct screen after font/encoding
  has been changed.
* Sat Jan 27 2001 arvin@suse.de
- package split y2curses / y2curses-devel
* Sat Jan 27 2001 arvin@suse.de
- package split y2qt / y2qt-devel
* Tue Jan 23 2001 sh@suse.de
- prevent crash upon window manager close
* Mon Jan 22 2001 sh@suse.de
- V2.2.10
- New default title graphics from <wimer@suse.de> that are
  no longer cut off at the right at 640x480
- Renamed suseheader.xpm to yast2.xpm
- Use yast2.xpm for both `Image(`suseheader) and `Image(`yast2)
- Removed obsolete XPM images that were never used anyway
* Sat Jan 20 2001 arvin@suse.de
- version to 2.2.19
- make package compile
* Fri Jan 19 2001 ma@suse.de
- version to 2.2.18
- Pass encoding as argument to NCstring::setDefaultEncoding()
* Thu Jan 18 2001 sh@suse.de
- version to 2.2.17
- added new parameter "encoding" to setConsoleFont()
* Tue Jan 16 2001 sh@suse.de
- V2.2.9
- New default image for Image(`suseheader): 2000 pixels wide
* Mon Jan 15 2001 ma@suse.de
- version to 2.2.16
- fixed IntField not responding to opt(notify) (#5636, no volume control
  in sound configuration due to missing callback)
- map UI-specific redrawScreen() to NCurses::Refresh()
* Fri Jan 12 2001 sh@suse.de
- V2.2.8
- Added module QXEmbed from Qt/KDE2 (TrollTech / LGPL)
  to enable reliable KDE2 control center integration:
  keyboard focus now works when running embedded in kcmshell
  (fix for bug #5475)
* Thu Jan 11 2001 ma@suse.de
- version to 2.2.15
- fixed attribute set for BW mode (list and table selection were
  not visible) (#3756)
* Thu Jan 11 2001 sh@suse.de
- V2.2.7
- Hide YQTextEntry label if empty label specified
  - > no empty space above TextEntry widgets without label
* Thu Jan 11 2001 ma@suse.de
- version to 2.2.14
- Do screen refresh on <Ctrl-L> to get rid of any messages that
  might have been writen to the console (e.g. network shutdown)
* Fri Jan  5 2001 ma@suse.de
- version to 2.2.13
- fixed missing caption in empty tables (#5192)
* Thu Jan  4 2001 ma@suse.de
- version to 2.2.12
- fixed incorrect display of 8bit chars in RichText widgets (#4967)
* Thu Jan  4 2001 kkaempf@suse.de
- version to 2.2.11
  move NCstring to libyui
* Tue Jan  2 2001 ma@suse.de
- fixed: whole passwd field filled with '*' (#5107)
* Fri Dec 22 2000 ma@suse.de
- version to 2.2.10
- new MultiLineEdit widget
* Wed Dec 20 2000 ma@suse.de
- version to 2.2.9
- new LogView widget
* Tue Dec 19 2000 ma@suse.de
- version to 2.2.8
- basic Tree (always expanded)
* Tue Dec 19 2000 ma@suse.de
- version to 2.2.7
- pass YCPstrings to ui specific widgets
* Tue Dec 19 2000 ma@suse.de
- V2.2.6
- pass YCPstrings to ui specific widgets
* Mon Dec 18 2000 sh@suse.de
- New optional widget: DownloadProgress
- V2.2.5
* Mon Dec 18 2000 ma@suse.de
- version to 2.2.6
- some more missing recodes fixed.
- changed behaviour of NCDialog if UI requests input from a dialog
  with no active items. Previous version missed to look for a widget
  that might have been enabeled since the last request, and thus may
  be activated now. If there's still no active widget, the request is
  ignored on pollInput() and idleLoop(). Previous version sent ET_CANCEL,
  causing the dialog to be closed.
* Thu Dec 14 2000 ma@suse.de
- version to 2.2.5
- fixed Table to show column separator and headline
- force recoding of utf8 strings where YUI provides them as
  'class string' (only YCPString is recoded automaticaly).
- separated table items and style from TablePad structure.
* Wed Dec 13 2000 ma@suse.de
- version to 2.2.4
- new NCPadWidget as base for all scrollable widgets.
- new NCPad's for plain and list style
* Fri Dec  8 2000 sh@suse.de
- More reliable nicesize() and setSize() behaviour for
  SelectionBox and TextEntry
  - > no more cut-off pixel lines at the bottom
- V2.2.4
* Wed Dec  6 2000 ma@suse.de
- version to 2.2.3
- provide ComboBox widget
- fix TextEntry (didn't scroll on long texts)
- fix RichText (avoid hscroll, support bold/it/tt and simple list)
- code, layout and debug stuff cleanup
- dummy Tree and LogView widgets
* Tue Dec  5 2000 sh@suse.de
- New widget: MultiLineEdit
- Dialogs can no longer exceed screen dimensions
- V2.2.3
* Tue Nov 28 2000 arvin@suse.de
- Fixed ComboBox layout errors on resize.
* Tue Nov 28 2000 arvin@suse.de
- version to 2.2.2
- plugin is linked against libncurses and libpanel.
* Tue Nov 28 2000 kkaempf@suse.de
- add libmng-devel to neededforbuild
* Thu Nov 16 2000 ma@suse.de
- version to 2.2.1
- provide IntField widget
* Thu Nov 16 2000 kkaempf@suse.de
- split library and plugin
* Thu Nov 16 2000 kkaempf@suse.de
- split library and plugin
* Mon Nov 13 2000 sh@suse.de
- Removed glx, glx-devel, mesa from .spec.in - Qt no longer needs it
- V2.1.8
* Thu Nov  9 2000 kkaempf@suse.de
- static plugin only
* Wed Nov  8 2000 kkaempf@suse.de
- link with libutil and libcrypt
* Tue Nov  7 2000 sh@suse.de
- re-enabled static libs
  new widgets: LogView, IntField
  moved completely to new logging
  version 2.1.6
* Fri Nov  3 2000 kkaempf@suse.de
- adapt neededforbuild for new qt
* Thu Nov  2 2000 kkaempf@suse.de
- fix runqt include file
* Tue Oct 31 2000 sh@suse.de
- Increased gcc warning level
  resolved minor warnings
  disabled static libs (speed up compilation)
  version 2.1.4
* Fri Oct 27 2000 kkaempf@suse.de
- provide correct library
* Wed Oct 25 2000 kkaempf@suse.de
- provide lib and plugin
* Wed Oct 25 2000 kkaempf@suse.de
- Group provided
* Wed Oct 25 2000 kkaempf@suse.de
- Group set
* Wed Oct 25 2000 sh@suse.de
- New widgets: BarGraph, Slider, PartitionSplitter
  version 2.1.2
* Wed Oct 25 2000 kkaempf@suse.de
- updated version, prepared for new libyui interface
  version 2.1.1
* Thu Aug 31 2000 sh@suse.de
- Added mesa and mesasoft to spec file
  (Qt 2.2+ now requires OpenGL)
  version 2.1.1
* Mon Jul 24 2000 ma@suse.de
- version to 2.0.8
- workaround another librecode memory leak (#3589)
* Thu Jul 20 2000 ma@suse.de
- version to 2.0.7
- fixed broken enable/disable items (#3550)
* Mon Jul 17 2000 ma@suse.de
- version to 2.0.6
- fixed `opt(`default) for Pushbuttons (#3071)
* Fri Jul 14 2000 ma@suse.de
- version to 2.0.5
- replaced dummy ComboBox by copy of TextEntry widget.
- hotkey indicator stripped from widget labels (#3511)
* Fri Jul 14 2000 ma@suse.de
- version to 2.0.4
- always(!) limit dialog size by screen size. There was one
  case missing, causing eg. package descriptions to abort because
  too large dialog sizes were requested (#3136)
* Thu Jul 13 2000 sh@suse.de
- Resize behaviour
  version 2.0.11
* Thu Jul 13 2000 ma@suse.de
- version to 2.0.3
- redraw screen immediately after any setfont request (#3220)
* Wed Jul 12 2000 ma@suse.de
- version to 2.0.2
- missing frames and frame labes added (#3133)
* Fri Jul  7 2000 sh@suse.de
- Change table widget sorting for the umpteenth time:
  Maintain insertion order but allow for user sort-by-click
  version 2.0.10
* Thu Jul  6 2000 sh@suse.de
- proper window close button handling (-> `cancel)
  version 2.0.9
* Tue Jul  4 2000 kkaempf@suse.de
- check argument in returnNow
  version 2.0.8
* Mon Jun 26 2000 sh@suse.de
- Changed default title image for SuSE 7.0
- increased version number to 2.0.7
* Mon Jun 19 2000 kkaempf@suse.de
- use xmset from new saxtools package
  version 2.0.6
* Mon Jun 19 2000 schwab@suse.de
- Add %%suse_update_config.
- Lower opt level on ia64.
* Mon Jun 19 2000 schwab@suse.de
- Add %%suse_update_config.
- Lower opt level on ia64.
* Mon Jun 19 2000 kkaempf@suse.de
- add xmset from SaX2
  version 2.0.5
* Thu Jun  8 2000 sh@suse.de
- Disabled X Input Method hack - this doesn't seem to work with
  XFree86 4.0
* Mon Jun  5 2000 sh@suse.de
- Added correct QTDIR and dependencies to qtlib2 to spec file
* Mon Jun  5 2000 kkaempf@suse.de
- fix include path
* Thu May 18 2000 kkaempf@suse.de
- pass includes to dist
  add tools to specfile
* Thu May 18 2000 kkaempf@suse.de
- install in plugin
  interface change for tree widget
  bump version to 2.0.1
* Mon May 15 2000 sh@suse.de
- New widget: ComboBox
* Wed Apr 26 2000 kkaempf@suse.de
- Initial version based on yast2 from SuSE 6.4
* Wed Apr 26 2000 kkaempf@suse.de
- Initial version based on yast2 from SuSE 6.4
